searchData={"items":[{"type":"module","title":"Fledex.Effect.Dimming","doc":"","ref":"Fledex.Effect.Dimming.html"},{"type":"behaviour","title":"Fledex.Effect.Interface","doc":"This module defines the interface for an LED effect. Effects can be used in Animations.\nExamples are:\n\n* Rotation\n* Dimming\n* Randomize\n* Wanishing\n* Blinking\n* etc.","ref":"Fledex.Effect.Interface.html"},{"type":"callback","title":"Fledex.Effect.Interface.apply/4","doc":"Applies an effect to the list of LEDs.\n\nEvery LED in the list can be modified at will, however, the amount should NOT be changed.\nThe function can either return a list of LEDs (color integers) or a tuple with the first\npart being the LEDs and the second being a modified triggers map. This allows to retain\nsome state between applying the filter in consecutive calls.\nThe `count` is the amount of LEDs in the list (to avoid that we have to traverse it unnecessarily)","ref":"Fledex.Effect.Interface.html#c:apply/4"},{"type":"module","title":"Fledex.Effect.Rotation","doc":"","ref":"Fledex.Effect.Rotation.html"},{"type":"function","title":"Fledex.Effect.Rotation.rotate/3","doc":"Helper function mainy intended for internal use to rotate the sequence of values by an `offset`.\n\nThe rotation can happen with the offset to the left or to the right.","ref":"Fledex.Effect.Rotation.html#rotate/3"},{"type":"module","title":"Fledex.Effect.Wanish","doc":"","ref":"Fledex.Effect.Wanish.html"},{"type":"module","title":"Fledex","doc":"This module should provide some simple macros that allow to define the\nled strip and to update it. The code you would write (in livebook) would\nlook something like the following:\n``` elixir\n  use Fledex\n  led_strip :strip_name, ;kino do\n    animation :john do\n      config = %{\n        num_leds: 50,\n        reversed: true\n      }\n\n      leds(50)\n        |> rainbow(config)\n    end\n  end\n```","ref":"Fledex.html"},{"type":"macro","title":"Fledex.__using__/1","doc":"By using this module, the `Fledex` macros are made available.\n\nThis macro does also include the `Fledex.Leds` and the `Fledex.Color.Names` and are\ntherefore available without namespace.\n\nTake a look at the various [livebook examples](readme-2.html) on how to use the Fledex macros","ref":"Fledex.html#__using__/1"},{"type":"macro","title":"Fledex.animation/3","doc":"This introduces a new `animation` (animation) that will be played over\n  and over again until it is changed.\n\n  Therefore we give it a name to know whether it changes","ref":"Fledex.html#animation/3"},{"type":"macro","title":"Fledex.component/4","doc":"NOT YET IMPLEMENTED (thus, those are just some thoughts)\n\nA component is a pre-defined animation that reacts to some input.\nWe might have a thermometer component that defines the display of\na thermometer:\n\n* input: single value\n* display is a range (positive, 0, negative)\n* ...\n\nThe `do: block` should retun the expected parameters for the component.\nFor our thermometer component the parameters might be:\n\n* the value,\n* the display colors,\n* the range of our scale\n\nThus, it might look something like the following:\n```elixir\ndo\n  %Thermometer{\n    value: 10,\n    negative: :blue,\n    positive: :red,\n    range: -10..30,\n    steps: 1,\n  }\nend\n```","ref":"Fledex.html#component/4"},{"type":"macro","title":"Fledex.effect/3","doc":"Add an effect to an animation\n\nThis macro allows to add an effect to an animation (or even a component\n(TODO: figure out whether an effect on a static component makes any sense,\nit would mean that the static component suddenly would need to be animated)\n\nYou simply warp the animation inside a effect block. It's possible to have\nsevereal nested effects. In that case they will all be executed in sequence.\n\nExample:\n```elixir\nuse Fledex\nalias Fledex.Effect.Wanish\nled_strip :john, :kino do\n  effect Wanish, trigger_name: :john do\n    animation :test do\n      _triggers ->\n        leds(1) |> light(:red) |> repeat(50)\n    end\n  end\nend\n```","ref":"Fledex.html#effect/3"},{"type":"function","title":"Fledex.fledex_config/0","doc":"This function returns the currently configured macros/functions that can be used in a fledex led_strip","ref":"Fledex.html#fledex_config/0"},{"type":"macro","title":"Fledex.led_strip/3","doc":"This introduces a new led_strip.","ref":"Fledex.html#led_strip/3"},{"type":"macro","title":"Fledex.static/3","doc":"The static macro is equal to the animation macro, but it will not receive any triggers.\n\nTherefore, there will not be any repainting and the `def_func` will not receive any\nparameter. It will only be painted once at definition time.","ref":"Fledex.html#static/3"},{"type":"module","title":"Fledex.Application","doc":"","ref":"Fledex.Application.html"},{"type":"function","title":"Fledex.Application.start/2","doc":"","ref":"Fledex.Application.html#start/2"},{"type":"module","title":"Fledex.LedStrip","doc":"This module defines a GenServer that manages the LED strip (be it a real one with the\n`Fledex.Driver.Impl.Spi` or a virtual one with e.g. the `Fledex.Driver.Impl.Kino`).\n\nYou would start an `LedStrip` for every led strip you have.\n\nThe `Fledex.LedStrip` will take several `Fledex.Leds` definitions and merge them\ntogether to be displayed on a single LED strip.\n\nThe role the LedStrip plays is similar to the one a window server  plays on a normal\ncomputer, except that a window server would manage several screens, whereas here each\nLED strip would get its own.","ref":"Fledex.LedStrip.html"},{"type":"function","title":"Fledex.LedStrip.change_config/3","doc":"Change some aspect of a configuration for a specific strip. The configuration\nwill be updated and the old value will be returned.\n\nCaution: No error checking is performed, so you might end up with a useless\nconfiguration","ref":"Fledex.LedStrip.html#change_config/3"},{"type":"function","title":"Fledex.LedStrip.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Fledex.LedStrip.html#child_spec/1"},{"type":"function","title":"Fledex.LedStrip.define_namespace/2","doc":"Define a new namespace","ref":"Fledex.LedStrip.html#define_namespace/2"},{"type":"function","title":"Fledex.LedStrip.drop_namespace/2","doc":"Drop a previously defined namespace.","ref":"Fledex.LedStrip.html#drop_namespace/2"},{"type":"function","title":"Fledex.LedStrip.exist_namespace/2","doc":"Checks whether the specified namespace already exists","ref":"Fledex.LedStrip.html#exist_namespace/2"},{"type":"function","title":"Fledex.LedStrip.reinit_drivers/1","doc":"In some circumstances it might be necessary to reinitialize a driver.\nMost of the time you don't need to call this. If you do, you will surely\nknow about it :)","ref":"Fledex.LedStrip.html#reinit_drivers/1"},{"type":"function","title":"Fledex.LedStrip.set_leds/3","doc":"Sets the leds in a specific strip and namespace.\n\nNote: repeated calls of this function will result in previously set leds\nwill be overwritten. We are passing a list of leds which means every led\nwill be rewritten, except if we define a 'shorter\" led sequence. In that\ncase some leds might retain their previously set value.","ref":"Fledex.LedStrip.html#set_leds/3"},{"type":"function","title":"Fledex.LedStrip.start_link/2","doc":"","ref":"Fledex.LedStrip.html#start_link/2"},{"type":"module","title":"Fledex.Leds","doc":"This module allows to define a sequence of Leds. You first create the new sequence of leds\nby calling one of the `leds` functions.\n\n**Note:** usually the `leds` function would rather be called `new` but when importing the `Leds`\nmodule, it becomes more natural to say\n\n```elixir\n  leds(10) |> light(:red)`\n```\n\nTo keep the classical semantics some delegates are defined, so you can use `new` as well.","ref":"Fledex.Leds.html"},{"type":"function","title":"Fledex.Leds.convert_to_leds_structure/2","doc":"Helper function to convert a list of colors to the correct map structure","ref":"Fledex.Leds.html#convert_to_leds_structure/2"},{"type":"function","title":"Fledex.Leds.count/1","doc":"This function checks how many leds are defined in the led sequence.\n\nNote: The color of an led outside that range can be defined, but it won't be\nsend to the `Fledex.LedStrip` when the `send/2` function is called. See also\n`set_count/2` for information.","ref":"Fledex.Leds.html#count/1"},{"type":"function","title":"Fledex.Leds.get_light/2","doc":"Retrieve the color of an led at a specific position","ref":"Fledex.Leds.html#get_light/2"},{"type":"function","title":"Fledex.Leds.gradient/4","doc":"Defines the leds through a gradient function.\n\nThe gradient function will create a smoot transition from a `start_color` to an\n`end_color`. The options that can be specified are the following:\n\n* `\"num_leds`: Over how many leds the transition should happen. (default: all)\n* `:offset`: The offset where to start the gardient at (default: 0)","ref":"Fledex.Leds.html#gradient/4"},{"type":"function","title":"Fledex.Leds.leds/0","doc":"Create a new led sequence of length 0.\n\nThis is rarely useful. Use the `leds/1` function instead (or change the count by using `set_count/2`)","ref":"Fledex.Leds.html#leds/0"},{"type":"function","title":"Fledex.Leds.leds/1","doc":"Creates a new led sequence with a set number of leds","ref":"Fledex.Leds.html#leds/1"},{"type":"function","title":"Fledex.Leds.leds/2","doc":"Create a new led sequence with a set number of leds and some options.\n\nCurrently two options are available:\n\n* `:server_name` and\n* `:namespace`.\n\nThose are important when you want to send your led sequence to an\n`Fledex.LedStrip`.\nYou should prefer to use the `set_driver_info/3` function instead.","ref":"Fledex.Leds.html#leds/2"},{"type":"function","title":"Fledex.Leds.leds/3","doc":"Create a new led sequence with a set number of leds, some set leds and options.\n\nThis function is similar to `leds/2`, but you  an specify some leds (between the `count`\nand the `opts`) through a map or a list.\n\nIf a map is used the key of the map (an integer) is the index (one-indexed) of the\nled and the value is the color.\nIf a list is used each entry in the list defines a color. Internally it will be converted\nto a map.\n\nLeds that are outside the `count` can be specified, but will be ignored when sent to\nan `Fledex.LedStrip` through the `send/2` function.","ref":"Fledex.Leds.html#leds/3"},{"type":"function","title":"Fledex.Leds.leds/4","doc":"Creates a led sequence with a set number of leds, some set leds, some options and some\nmeta information.\n\nThis function is similar to the `leds/3` function, but some additional meta information\ncan be specified. Currently the only  meta information is to keep track of an index\nthat specfies which led will be set when using the `light/2` function, i.e. without\nan offset. This way it's possible to have a sequence of updates like the following\nto specify the colors:\n\n```elixir\nleds(10) |> light(:red) |> light(:blue)\n```","ref":"Fledex.Leds.html#leds/4"},{"type":"function","title":"Fledex.Leds.light/2","doc":"Defines the color(s) of the next led\n\nIf there are no more leds, this function will virtually continue and define leds\noutside the scope, see also the note on `set_count/2`.\n\nNote: it is possible to use a sub sequence of leds and they all will be added to\nthe sequence.","ref":"Fledex.Leds.html#light/2"},{"type":"function","title":"Fledex.Leds.light/3","doc":"Defines the color of an led at `position` (one indexed)\n\nThe `offset` needs to be `> 0` if it's bigger than the count\nthen the led will be stored, but ignored (but see the description\nof `set_count/2`). The same note as for `light/2` applies.","ref":"Fledex.Leds.html#light/3"},{"type":"function","title":"Fledex.Leds.light/4","doc":"Defines the color of an led at `position` and repeats it `repeat` times.\n\nTHe `repeat` needs to be more than 1, otherwise it wouldn't make sense.\nIn adition the same note as for `light/2` applies.","ref":"Fledex.Leds.html#light/4"},{"type":"function","title":"Fledex.Leds.new/0","doc":"","ref":"Fledex.Leds.html#new/0"},{"type":"function","title":"Fledex.Leds.new/1","doc":"","ref":"Fledex.Leds.html#new/1"},{"type":"function","title":"Fledex.Leds.new/2","doc":"","ref":"Fledex.Leds.html#new/2"},{"type":"function","title":"Fledex.Leds.new/3","doc":"","ref":"Fledex.Leds.html#new/3"},{"type":"function","title":"Fledex.Leds.new/4","doc":"","ref":"Fledex.Leds.html#new/4"},{"type":"function","title":"Fledex.Leds.rainbow/2","doc":"Defines a rainbow over the leds. The options that can be specified are:\n\n*  `:num_leds`: how many leds should be part of the rainbow (by default all leds)\n* `:offset`: as from which led we want to start the  rainbow (default: 0, no offset)\n* `:reversed`: The rainbow can go from red (start color) to blue (end color) or the other\n    way around.\n* `:initial_hue`: The starting color in degree (`0..360`). (default: 0)\n\nNote: any led that has been defined before calling this function will be overwritten\nwith the rainbow value.","ref":"Fledex.Leds.html#rainbow/2"},{"type":"function","title":"Fledex.Leds.repeat/2","doc":"repeat teh existing sequence `amount` times\n\nThis way you can easily create a repetitive pattern\n\n**Note:** this will change the led sequence count  (`amount` times the initial `count`)","ref":"Fledex.Leds.html#repeat/2"},{"type":"function","title":"Fledex.Leds.send/2","doc":"Convenience function to send the led sequence to an `Fledex.LedStrip`.\n\nIn order for the function to succeed either `set_driver_info/3` needs to be\ncalled or the information needs to be passed as part of the opts. The opts can\nbe the following:\n\n* `:offset`: Move the led sequence to the side (see Note below)\n* `:rotate_left`: whether the offset should be appiled toward the right or the left\n* `:server_name`: The name of the server_name to which the led sequence should be send to\n    (default: `Fledex.LedStrip`)\n* `:namespace`: The name of the namespace within the LedStrip (default: `:default`)\n\nNote: the led sequence will always be applied in it's entirety, and will wrap around.\nThrough the `:offset` it is possible to create simple animations by simply counting up\nup the counter.\n\nNote2: If no `server_name` and/or no `namespace` are defined, then they will be defined\n(and started). A warning will be emitted to the concole.","ref":"Fledex.Leds.html#send/2"},{"type":"function","title":"Fledex.Leds.set_count/2","doc":"This function sets the count of leds of the led sequence.\n\nNote: Be careful if you redefine the count when some leds have\nbeen defined outside of the previous range; they might suddenly become\nvisible.","ref":"Fledex.Leds.html#set_count/2"},{"type":"function","title":"Fledex.Leds.set_driver_info/3","doc":"Define the server_name and the namespace\n\nThis is used when the led sequence is sent to the `Fledex.LedStrip` when the\n`send/2` function is called.","ref":"Fledex.Leds.html#set_driver_info/3"},{"type":"function","title":"Fledex.Leds.to_binary/1","doc":"Convert the sequence of leds to a binary sequence of `Fledex.Color.Types.colorint` colors.\n\nNote: Only the leds that are inside the `count` will be emitted into the binary sequence.","ref":"Fledex.Leds.html#to_binary/1"},{"type":"function","title":"Fledex.Leds.to_list/1","doc":"Convert the sequence of leds into an list of `Fledex.Color.Types.colorint` colors.\n\nNote: Only the leds that are inside the `count` will be added to the list.","ref":"Fledex.Leds.html#to_list/1"},{"type":"function","title":"Fledex.Leds.to_markdown/2","doc":"Convert the sequence of leds to a markdown representation.\n\nThe █ will be used to represent the leds and they will be colored in\nthe appropriate color. It then looks something like this:\n █ \n █ \n █ \nThe opts are currently not used, but are planned to\nbe used for potential color correction (similar to `Fledex.Driver.Impl.Kino`)","ref":"Fledex.Leds.html#to_markdown/2"},{"type":"type","title":"Fledex.Leds.t/0","doc":"","ref":"Fledex.Leds.html#t:t/0"},{"type":"module","title":"Fledex.Animation.Animator","doc":"The client often wants to run some animations. This can of course be done by\nrepeatedly updating the `Leds` definitions and calling\n`Leds.send()` to send it to the driver.\nThis often results in constructs like the following:application\n```\n  Enum.each(1..10, fn index ->\n  Leds\n    |> led_definition function(index)\n    |> Leds.send(config)\n    Process.sleep(600)\n  end)\n ```\n This creates a loop over some led definition, sends it to the LED strip and then\n waits for a while to do the next step.\n The index can be used for either influencing the led definition function,\n or the offset of the strip and thereby influencing the animation.\n\nThis approach is not really good, because of the following drawbacks:\n* it is difficult to update the animation while it's running,\n   because it would require to interrupt the loop\n* the sending to the LED strip can not be optimized, except by knowing\n   at which update frequency the driver is updating the strip. Of course it would be\n   possible for a client to figure this out, but who would do that?\n\n The idea of this module is to take care of those concerns by implementing a GenServer that\n runs the loop, but can be updated in-between.\n\n From the above example it can be seen that two things can be updated:\n * The led_definition_function and\n * The send config (even though we will have to implement that as a\n  function too due to the handling of the index)\n\n Note: the time is not something that can be specified, since the animator will\n be triggered by `Fledex.LedStrip` in it's update frequency. Thus to implement\n some wait pattern, the trigger counter (or some other timer logic) should be used\n\n Both of them can be set by defining an appropriate function and setting and resetting a reference at will\n\n This module does not define any functions on its own, because the interface is defined\n by `Fledex.Animation.Base`.","ref":"Fledex.Animation.Animator.html"},{"type":"function","title":"Fledex.Animation.Animator.apply_effects/3","doc":"","ref":"Fledex.Animation.Animator.html#apply_effects/3"},{"type":"function","title":"Fledex.Animation.Animator.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Fledex.Animation.Animator.html#child_spec/1"},{"type":"type","title":"Fledex.Animation.Animator.config_t/0","doc":"","ref":"Fledex.Animation.Animator.html#t:config_t/0"},{"type":"type","title":"Fledex.Animation.Animator.state_t/0","doc":"","ref":"Fledex.Animation.Animator.html#t:state_t/0"},{"type":"module","title":"Fledex.Animation.Base","doc":"","ref":"Fledex.Animation.Base.html"},{"type":"behaviour","title":"Fledex.Animation.Interface","doc":"The behaviour for animations.\n\nThis behaviour is the interface expected by the `Fledex.Animation.Manager`\nand should be implemented as a GenServer.\nIf  you implement an animation you will have to implement those functions\nbut you can use `Fledex.Animation.Base` to assist you.","ref":"Fledex.Animation.Interface.html"},{"type":"function","title":"Fledex.Animation.Interface.build_animator_name/2","doc":"This utility function will create an atomic name for the combination of strip name and\nanimation name. This is used to name the animator. It is important that we do\nhave a naming convention, because we would otherwise have a hard time to shutdown\nanimators that have been removed. We do not keep a reference, but only a config\nTherefore the animator needs to adhere to this naming convention to properly be shut down.\nIt is the responsibility of the Animator to set the servername correctly. The\n`Fledex.Animation.Base` is doing this by default.","ref":"Fledex.Animation.Interface.html#build_animator_name/2"},{"type":"callback","title":"Fledex.Animation.Interface.config/3","doc":"(Re-)Configure this animation. You will have to implement this function on server side.\nThis will look something like the following:\n```elixir\n  @spec handle_cast({:config, config_t}, state_t) :: {:noreply, state_t}\n  def handle_cast({:config, config}, state) do\n    # do something here\n    {:noreply, state}\n  end\n```","ref":"Fledex.Animation.Interface.html#c:config/3"},{"type":"callback","title":"Fledex.Animation.Interface.get_info/2","doc":"Retrieve infromation about this animation. This is mainly useful when running some\ntests. By default this function will return the animation state. This is one of the\nfew functions that does not need to be implemented","ref":"Fledex.Animation.Interface.html#c:get_info/2"},{"type":"callback","title":"Fledex.Animation.Interface.shutdown/2","doc":"When the animation is no long required, this function should be called. This will\ncall (by default) GenServer.stop. The animation can implement the `terminate/2`\nfunction if necessary.","ref":"Fledex.Animation.Interface.html#c:shutdown/2"},{"type":"callback","title":"Fledex.Animation.Interface.start_link/3","doc":"Create a new animation (with a given name and configuration) for the led strip\nwith the specified name.","ref":"Fledex.Animation.Interface.html#c:start_link/3"},{"type":"module","title":"Fledex.Animation.Manager","doc":"The animation manager manages several animations (and potentially\nserveral led strips at the same time.\nUsually you don't start the service yoursel, but it gets automatically\nstarted when calling `use Fledex` and gets used by the `Fledex` macros.\nThus, you rarely have to interact with it directly.\n\nThe 3 main functions are:\n\n* `regiseter_strip/2`: to add a new led strip. This will also create\nthe necessary `Fledex.LedStrip` and configures it.\n* `unregister_strip/1`: this will remove an led strip again\n* `register_animations/2`: this registers (or reregisters) a set of\n  animations. Any animation that is not part of a reregistration will\n  be dropped.","ref":"Fledex.Animation.Manager.html"},{"type":"function","title":"Fledex.Animation.Manager.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\nSee `Supervisor`.","ref":"Fledex.Animation.Manager.html#child_spec/1"},{"type":"function","title":"Fledex.Animation.Manager.get_info/1","doc":"In some circumstances it can be useful to get information on what has\nbeen configured and this function allows to retrieve this information.\nThe function can either be called with a strip name, or with `:all`\n(the default) to retrieve all configurations at the same time.","ref":"Fledex.Animation.Manager.html#get_info/1"},{"type":"function","title":"Fledex.Animation.Manager.register_animations/2","doc":"Register a set of animations for a specific led strip. This function can\nbe called as many times as desired to reconfigure the animations.\nIt should be noted that animations were defined before calling this function\nagain, will be stopped if they are not part of the configuration anymore.\nNewly defined animations will be started.\n\nDifferent types of animations exist, see `Fledex.fledex_config/0` for\nthe default configurations that will be used when using `use Fledex`.\n\nNote: the animation functions might get called quite frequently and\ntherefore any work within them should be kept to a minimum.","ref":"Fledex.Animation.Manager.html#register_animations/2"},{"type":"function","title":"Fledex.Animation.Manager.register_strip/2","doc":"Register a new LED strip with the specific `strip_name`. The LED strip\nneeds to be configured, either through a simple atom (for predefined\nconfigurations, or through a map with all the configurations (see\n[`LedStrip`](Fledex.LedStrip.html) for details).","ref":"Fledex.Animation.Manager.html#register_strip/2"},{"type":"function","title":"Fledex.Animation.Manager.start_link/1","doc":"This starts a new `Fledex.Animation.Manager`. Only a single animation manager will be started\neven if called serveral times (thus it's save to call it repeatedly).\nThe `type_config` specifies the list of supported animations and their module mapping\n(see `Fledex.fledex_config/0` for the configurations used by default.)","ref":"Fledex.Animation.Manager.html#start_link/1"},{"type":"function","title":"Fledex.Animation.Manager.unregister_strip/1","doc":"Unregisters a previously registered led strip. All resources related\nto the led strip will be freed.","ref":"Fledex.Animation.Manager.html#unregister_strip/1"},{"type":"module","title":"Fledex.Driver.Impl.Kino","doc":"","ref":"Fledex.Driver.Impl.Kino.html"},{"type":"module","title":"Fledex.Driver.Impl.Logger","doc":"This is a dummy implementation of the Driver that dumps\n  the binaries to IO. This can be useful if you want to run\n  some tests without real hardware.\n  The real implementatin probably opens a channel (if not already open)\n  to the bus (like SPI) sends the data to the bus.\n\n  Note: this module is allowed to store information in the state\n  (like the channel it has oppened), so that we don't have open/close it\n  all the time. Cleanup should happen in the terminate function","ref":"Fledex.Driver.Impl.Logger.html"},{"type":"module","title":"Fledex.Driver.Impl.Null","doc":"This is a dummy implementation of the Driver that doesn't do\n  anything (similar to a /dev/null device). This can be useful if you\n  want to run some tests without getting any output or sending it to hardware.","ref":"Fledex.Driver.Impl.Null.html"},{"type":"module","title":"Fledex.Driver.Impl.PubSub","doc":"","ref":"Fledex.Driver.Impl.PubSub.html"},{"type":"function","title":"Fledex.Driver.Impl.PubSub.init/1","doc":"","ref":"Fledex.Driver.Impl.PubSub.html#init/1"},{"type":"function","title":"Fledex.Driver.Impl.PubSub.reinit/1","doc":"","ref":"Fledex.Driver.Impl.PubSub.html#reinit/1"},{"type":"function","title":"Fledex.Driver.Impl.PubSub.terminate/2","doc":"","ref":"Fledex.Driver.Impl.PubSub.html#terminate/2"},{"type":"function","title":"Fledex.Driver.Impl.PubSub.transfer/3","doc":"","ref":"Fledex.Driver.Impl.PubSub.html#transfer/3"},{"type":"module","title":"Fledex.Driver.Impl.Spi","doc":"","ref":"Fledex.Driver.Impl.Spi.html"},{"type":"function","title":"Fledex.Driver.Impl.Spi.open_spi/1","doc":"","ref":"Fledex.Driver.Impl.Spi.html#open_spi/1"},{"type":"behaviour","title":"Fledex.Driver.Interface","doc":"A driver dispatches the \"real\" hardware. Differen types of\n  drivers exist. Currently the following drivers exist:\n\n  * [`Null`](Fledex.Driver.Impl.Null.html): a driver that doesn't do\n      anything. This is the default driver. It's also very practical for tests.\n  * [`Logger`](Fledex.Driver.Impl.Logger.html): a driver that logs the\n      led data to the terminal or to the logs\n  * [`Kino`](Fledex.Driver.Impl.Kino.html): a driver that can display\n      the LEDs in a [livebook](https://livebook.dev)\n  * [`Spi`](Fledex.Driver.Impl.Spi.html): a driver that can connect\n      to a real LED strip with a WS2801 chip.\n  * [`PubSub`](Fledex.Driver.Impl.PubSub.html): a driver that can transfer\n      the LED data via pubsub. This should also allow the data to be transferred to\n      a LED strip connected on another computer.\n\n  More Drivers can be created by implementing the simple behaviour","ref":"Fledex.Driver.Interface.html"},{"type":"callback","title":"Fledex.Driver.Interface.init/1","doc":"The init function will be called after the `Fledex.LedStrip` is initialized as part\nof the initialization process. A map of initalization arguments are passed to\nthe driver. The driver can decide what to do with them. The returned map is a\nconfiguration that gets passed to any of the other driver functions.","ref":"Fledex.Driver.Interface.html#c:init/1"},{"type":"callback","title":"Fledex.Driver.Interface.reinit/1","doc":"In some cases it is necessary to reinitialize the driver when a new LED strip\nis defined (see the `Fledex.Driver.Impl.Kino` as an example). The\ndriver should know whether it needs to do anything or not. If it does not need\nto do anything, then simply return the passed in map, i.e.:\n\n```elixir\ndef reinit(module_config), do: driver_config\n```","ref":"Fledex.Driver.Interface.html#c:reinit/1"},{"type":"callback","title":"Fledex.Driver.Interface.terminate/2","doc":"THe terminate functions gets called when we dispose of the led strip. This the place\nwhere the driver can perform some cleanup (e.g.: close some channels)","ref":"Fledex.Driver.Interface.html#c:terminate/2"},{"type":"callback","title":"Fledex.Driver.Interface.transfer/3","doc":"This is the main function where we transfer the LED information to the \"hardware\"\nThe `leds` is a list of integers, (color codes of the form `0xrrggbb` if written in\nhexadecimal format).\nThe `counter` is a counter that gets incremented in each update loop and thereby allows\nto transfer the data with a lower frequency by not transferring it in every loop.\nThe `module_config` is the config that got returned by the `init/1` or `reinit/1`\nfunctions","ref":"Fledex.Driver.Interface.html#c:transfer/3"},{"type":"module","title":"Fledex.Driver.Manager","doc":"","ref":"Fledex.Driver.Manager.html"},{"type":"type","title":"Fledex.Driver.Manager.driver_t/0","doc":"The structure to hold the driver related data.\n\nIt consists of:\n* `:driver_modules`: Which modules should get loaded. More than one module\n    can be loaded at the same time\n* `config`: a map with driver specific configurations. Each driver gets its\n    own configuration. The driver module name is used as key to separate\n    the drivers from each other. example:\n    ```elixir\n    %{Fledex.Driver.Impl.Kino: %{\n      update_freq: 10\n    }}\n    ```\n* `:merge_strategy`: The merge strategy that will be applied to","ref":"Fledex.Driver.Manager.html#t:driver_t/0"},{"type":"module","title":"Fledex.Utils.Cluster","doc":"","ref":"Fledex.Utils.Cluster.html"},{"type":"module","title":"Fledex.Utils.PubSub","doc":"","ref":"Fledex.Utils.PubSub.html"},{"type":"function","title":"Fledex.Utils.PubSub.broadcast/3","doc":"","ref":"Fledex.Utils.PubSub.html#broadcast/3"},{"type":"function","title":"Fledex.Utils.PubSub.subscribe/2","doc":"","ref":"Fledex.Utils.PubSub.html#subscribe/2"},{"type":"function","title":"Fledex.Utils.PubSub.unsubscribe/2","doc":"","ref":"Fledex.Utils.PubSub.html#unsubscribe/2"},{"type":"module","title":"Fledex.Color.Conversion.Approximate","doc":"","ref":"Fledex.Color.Conversion.Approximate.html"},{"type":"function","title":"Fledex.Color.Conversion.Approximate.rgb2hsv/1","doc":"","ref":"Fledex.Color.Conversion.Approximate.html#rgb2hsv/1"},{"type":"module","title":"Fledex.Color.Conversion.Rainbow","doc":"","ref":"Fledex.Color.Conversion.Rainbow.html"},{"type":"function","title":"Fledex.Color.Conversion.Rainbow.hsv2rgb/2","doc":"","ref":"Fledex.Color.Conversion.Rainbow.html#hsv2rgb/2"},{"type":"module","title":"Fledex.Color.Conversion.Raw","doc":"","ref":"Fledex.Color.Conversion.Raw.html"},{"type":"function","title":"Fledex.Color.Conversion.Raw.hsv2rgb/2","doc":"","ref":"Fledex.Color.Conversion.Raw.html#hsv2rgb/2"},{"type":"function","title":"Fledex.Color.Conversion.Raw.set_colors/4","doc":"","ref":"Fledex.Color.Conversion.Raw.html#set_colors/4"},{"type":"module","title":"Fledex.Color.Conversion.Spectrum","doc":"","ref":"Fledex.Color.Conversion.Spectrum.html"},{"type":"function","title":"Fledex.Color.Conversion.Spectrum.hsv2rgb/2","doc":"","ref":"Fledex.Color.Conversion.Spectrum.html#hsv2rgb/2"},{"type":"module","title":"Fledex.Color.Correction","doc":"","ref":"Fledex.Color.Correction.html"},{"type":"function","title":"Fledex.Color.Correction.apply_rgb_correction/2","doc":"","ref":"Fledex.Color.Correction.html#apply_rgb_correction/2"},{"type":"function","title":"Fledex.Color.Correction.calculate_color_correction/3","doc":"","ref":"Fledex.Color.Correction.html#calculate_color_correction/3"},{"type":"function","title":"Fledex.Color.Correction.color_correction_g2/1","doc":"","ref":"Fledex.Color.Correction.html#color_correction_g2/1"},{"type":"function","title":"Fledex.Color.Correction.color_correction_none/1","doc":"","ref":"Fledex.Color.Correction.html#color_correction_none/1"},{"type":"function","title":"Fledex.Color.Correction.define_correction/3","doc":"","ref":"Fledex.Color.Correction.html#define_correction/3"},{"type":"function","title":"Fledex.Color.Correction.no_color_correction/0","doc":"","ref":"Fledex.Color.Correction.html#no_color_correction/0"},{"type":"module","title":"Fledex.Color.Correction.Color","doc":"","ref":"Fledex.Color.Correction.Color.html"},{"type":"function","title":"Fledex.Color.Correction.Color.typical_8mm_pixel/0","doc":"","ref":"Fledex.Color.Correction.Color.html#typical_8mm_pixel/0"},{"type":"function","title":"Fledex.Color.Correction.Color.typical_led_strip/0","doc":"","ref":"Fledex.Color.Correction.Color.html#typical_led_strip/0"},{"type":"function","title":"Fledex.Color.Correction.Color.typical_pixel/0","doc":"","ref":"Fledex.Color.Correction.Color.html#typical_pixel/0"},{"type":"function","title":"Fledex.Color.Correction.Color.typical_smd5050/0","doc":"","ref":"Fledex.Color.Correction.Color.html#typical_smd5050/0"},{"type":"function","title":"Fledex.Color.Correction.Color.uncorrected_color/0","doc":"","ref":"Fledex.Color.Correction.Color.html#uncorrected_color/0"},{"type":"module","title":"Fledex.Color.Correction.Temperature","doc":"","ref":"Fledex.Color.Correction.Temperature.html"},{"type":"function","title":"Fledex.Color.Correction.Temperature.black_light_fluorescent/0","doc":"","ref":"Fledex.Color.Correction.Temperature.html#black_light_fluorescent/0"},{"type":"function","title":"Fledex.Color.Correction.Temperature.candle/0","doc":"","ref":"Fledex.Color.Correction.Temperature.html#candle/0"},{"type":"function","title":"Fledex.Color.Correction.Temperature.carbon_arc/0","doc":"","ref":"Fledex.Color.Correction.Temperature.html#carbon_arc/0"},{"type":"function","title":"Fledex.Color.Correction.Temperature.clear_blue_sky/0","doc":"","ref":"Fledex.Color.Correction.Temperature.html#clear_blue_sky/0"},{"type":"function","title":"Fledex.Color.Correction.Temperature.cool_white_fluorescent/0","doc":"","ref":"Fledex.Color.Correction.Temperature.html#cool_white_fluorescent/0"},{"type":"function","title":"Fledex.Color.Correction.Temperature.direct_sunlight/0","doc":"","ref":"Fledex.Color.Correction.Temperature.html#direct_sunlight/0"},{"type":"function","title":"Fledex.Color.Correction.Temperature.full_spectrum_fluorescent/0","doc":"","ref":"Fledex.Color.Correction.Temperature.html#full_spectrum_fluorescent/0"},{"type":"function","title":"Fledex.Color.Correction.Temperature.grow_light_fluorescent/0","doc":"","ref":"Fledex.Color.Correction.Temperature.html#grow_light_fluorescent/0"},{"type":"function","title":"Fledex.Color.Correction.Temperature.halogen/0","doc":"","ref":"Fledex.Color.Correction.Temperature.html#halogen/0"},{"type":"function","title":"Fledex.Color.Correction.Temperature.high_noon_sun/0","doc":"","ref":"Fledex.Color.Correction.Temperature.html#high_noon_sun/0"},{"type":"function","title":"Fledex.Color.Correction.Temperature.high_pressure_sodium/0","doc":"","ref":"Fledex.Color.Correction.Temperature.html#high_pressure_sodium/0"},{"type":"function","title":"Fledex.Color.Correction.Temperature.mercury_vapor/0","doc":"","ref":"Fledex.Color.Correction.Temperature.html#mercury_vapor/0"},{"type":"function","title":"Fledex.Color.Correction.Temperature.metal_halide/0","doc":"","ref":"Fledex.Color.Correction.Temperature.html#metal_halide/0"},{"type":"function","title":"Fledex.Color.Correction.Temperature.overcast_sky/0","doc":"","ref":"Fledex.Color.Correction.Temperature.html#overcast_sky/0"},{"type":"function","title":"Fledex.Color.Correction.Temperature.sodium_vapor/0","doc":"","ref":"Fledex.Color.Correction.Temperature.html#sodium_vapor/0"},{"type":"function","title":"Fledex.Color.Correction.Temperature.standard_fluorescent/0","doc":"","ref":"Fledex.Color.Correction.Temperature.html#standard_fluorescent/0"},{"type":"function","title":"Fledex.Color.Correction.Temperature.tungsten_40w/0","doc":"","ref":"Fledex.Color.Correction.Temperature.html#tungsten_40w/0"},{"type":"function","title":"Fledex.Color.Correction.Temperature.tungsten_100w/0","doc":"","ref":"Fledex.Color.Correction.Temperature.html#tungsten_100w/0"},{"type":"function","title":"Fledex.Color.Correction.Temperature.uncorrected_temperature/0","doc":"","ref":"Fledex.Color.Correction.Temperature.html#uncorrected_temperature/0"},{"type":"function","title":"Fledex.Color.Correction.Temperature.warm_fluorescent/0","doc":"","ref":"Fledex.Color.Correction.Temperature.html#warm_fluorescent/0"},{"type":"module","title":"Fledex.Color.Functions","doc":"","ref":"Fledex.Color.Functions.html"},{"type":"function","title":"Fledex.Color.Functions.create_gradient_rgb/3","doc":"","ref":"Fledex.Color.Functions.html#create_gradient_rgb/3"},{"type":"function","title":"Fledex.Color.Functions.create_rainbow_circular_hsv/3","doc":"","ref":"Fledex.Color.Functions.html#create_rainbow_circular_hsv/3"},{"type":"function","title":"Fledex.Color.Functions.create_rainbow_circular_rgb/3","doc":"","ref":"Fledex.Color.Functions.html#create_rainbow_circular_rgb/3"},{"type":"function","title":"Fledex.Color.Functions.hsv2rgb/3","doc":"","ref":"Fledex.Color.Functions.html#hsv2rgb/3"},{"type":"module","title":"Fledex.Color.KinoRender","doc":"","ref":"Fledex.Color.KinoRender.html"},{"type":"macro","title":"Fledex.Color.KinoRender.is_byte/1","doc":"","ref":"Fledex.Color.KinoRender.html#is_byte/1"},{"type":"function","title":"Fledex.Color.KinoRender.new/1","doc":"","ref":"Fledex.Color.KinoRender.html#new/1"},{"type":"function","title":"Fledex.Color.KinoRender.to_leds/1","doc":"","ref":"Fledex.Color.KinoRender.html#to_leds/1"},{"type":"function","title":"Fledex.Color.KinoRender.to_markdown/1","doc":"","ref":"Fledex.Color.KinoRender.html#to_markdown/1"},{"type":"type","title":"Fledex.Color.KinoRender.t/0","doc":"","ref":"Fledex.Color.KinoRender.html#t:t/0"},{"type":"module","title":"Fledex.Color.LoadUtils","doc":"","ref":"Fledex.Color.LoadUtils.html"},{"type":"function","title":"Fledex.Color.LoadUtils.load_color_file/1","doc":"","ref":"Fledex.Color.LoadUtils.html#load_color_file/1"},{"type":"function","title":"Fledex.Color.LoadUtils.names_file/0","doc":"","ref":"Fledex.Color.LoadUtils.html#names_file/0"},{"type":"function","title":"Fledex.Color.LoadUtils.parse_line/2","doc":"","ref":"Fledex.Color.LoadUtils.html#parse_line/2"},{"type":"module","title":"Fledex.Color.Names","doc":"Fledex has an extensive set of predefined colors from\n[Wikipedia](https://en.wikipedia.org/wiki/List_of_colors:_A%E2%80%93F). You can retrieve the information through this module\nby calling the different functions.\n\nYou can also retrieve the information from a specific color, like `:almond` by calling the function with the same name, i.e.\n`almond/1`. It should be noted, that the color functions in other modules (are often just approximations) and do not\nprovide the same results. The values returned here are the ones as defined on the Wikipedia page.\n\nThe additional parameter determines which additional information should be provided. The options are:\n\n  * `:all`: This retrieves the full data set\n  * `:desriptive_name`: a string with name (from this the Atom is derived)\n  * `:hex` (default): This is the same as `almond/0`\n  * `:hsl`: This retrieves an HSL struct, i.e. `{h, s, l}`\n  * `:hsv`: This retrieves an HSV struct, i.e. `{h, s, v}`\n  * `:index`: The index of this color in the list of all colors\n  * `:rgb`: This retrieves an RGB struct, i.e. `{r, g, b}`\n  * `:source`: Information where the color comes from, see Wikipedia for more details","ref":"Fledex.Color.Names.html"},{"type":"function","title":"Fledex.Color.Names.absolute_zero/1","doc":"Defines the color rgb(0, 71, 186).","ref":"Fledex.Color.Names.html#absolute_zero/1"},{"type":"function","title":"Fledex.Color.Names.absolute_zero/2","doc":"","ref":"Fledex.Color.Names.html#absolute_zero/2"},{"type":"function","title":"Fledex.Color.Names.acid_green/1","doc":"Defines the color rgb(175, 191, 25).","ref":"Fledex.Color.Names.html#acid_green/1"},{"type":"function","title":"Fledex.Color.Names.acid_green/2","doc":"","ref":"Fledex.Color.Names.html#acid_green/2"},{"type":"function","title":"Fledex.Color.Names.aero/1","doc":"Defines the color rgb(124, 186, 232).","ref":"Fledex.Color.Names.html#aero/1"},{"type":"function","title":"Fledex.Color.Names.aero/2","doc":"","ref":"Fledex.Color.Names.html#aero/2"},{"type":"function","title":"Fledex.Color.Names.african_violet/1","doc":"Defines the color rgb(178, 132, 191).","ref":"Fledex.Color.Names.html#african_violet/1"},{"type":"function","title":"Fledex.Color.Names.african_violet/2","doc":"","ref":"Fledex.Color.Names.html#african_violet/2"},{"type":"function","title":"Fledex.Color.Names.air_superiority_blue/1","doc":"Defines the color rgb(114, 160, 193).","ref":"Fledex.Color.Names.html#air_superiority_blue/1"},{"type":"function","title":"Fledex.Color.Names.air_superiority_blue/2","doc":"","ref":"Fledex.Color.Names.html#air_superiority_blue/2"},{"type":"function","title":"Fledex.Color.Names.alice_blue/1","doc":"Defines the color rgb(239, 247, 255).","ref":"Fledex.Color.Names.html#alice_blue/1"},{"type":"function","title":"Fledex.Color.Names.alice_blue/2","doc":"","ref":"Fledex.Color.Names.html#alice_blue/2"},{"type":"function","title":"Fledex.Color.Names.alizarin/1","doc":"Defines the color rgb(219, 45, 66).","ref":"Fledex.Color.Names.html#alizarin/1"},{"type":"function","title":"Fledex.Color.Names.alizarin/2","doc":"","ref":"Fledex.Color.Names.html#alizarin/2"},{"type":"function","title":"Fledex.Color.Names.alloy_orange/1","doc":"Defines the color rgb(196, 96, 15).","ref":"Fledex.Color.Names.html#alloy_orange/1"},{"type":"function","title":"Fledex.Color.Names.alloy_orange/2","doc":"","ref":"Fledex.Color.Names.html#alloy_orange/2"},{"type":"function","title":"Fledex.Color.Names.almond/1","doc":"Defines the color rgb(239, 221, 204).","ref":"Fledex.Color.Names.html#almond/1"},{"type":"function","title":"Fledex.Color.Names.almond/2","doc":"","ref":"Fledex.Color.Names.html#almond/2"},{"type":"function","title":"Fledex.Color.Names.amaranth_deep_purple/1","doc":"Defines the color rgb(158, 43, 104).","ref":"Fledex.Color.Names.html#amaranth_deep_purple/1"},{"type":"function","title":"Fledex.Color.Names.amaranth_deep_purple/2","doc":"","ref":"Fledex.Color.Names.html#amaranth_deep_purple/2"},{"type":"function","title":"Fledex.Color.Names.amaranth_pink/1","doc":"Defines the color rgb(242, 155, 186).","ref":"Fledex.Color.Names.html#amaranth_pink/1"},{"type":"function","title":"Fledex.Color.Names.amaranth_pink/2","doc":"","ref":"Fledex.Color.Names.html#amaranth_pink/2"},{"type":"function","title":"Fledex.Color.Names.amaranth_purple/1","doc":"Defines the color rgb(170, 38, 79).","ref":"Fledex.Color.Names.html#amaranth_purple/1"},{"type":"function","title":"Fledex.Color.Names.amaranth_purple/2","doc":"","ref":"Fledex.Color.Names.html#amaranth_purple/2"},{"type":"function","title":"Fledex.Color.Names.amazon/1","doc":"Defines the color rgb(58, 122, 86).","ref":"Fledex.Color.Names.html#amazon/1"},{"type":"function","title":"Fledex.Color.Names.amazon/2","doc":"","ref":"Fledex.Color.Names.html#amazon/2"},{"type":"function","title":"Fledex.Color.Names.amber/1","doc":"Defines the color rgb(255, 191, 0).","ref":"Fledex.Color.Names.html#amber/1"},{"type":"function","title":"Fledex.Color.Names.amber/2","doc":"","ref":"Fledex.Color.Names.html#amber/2"},{"type":"function","title":"Fledex.Color.Names.amethyst/1","doc":"Defines the color rgb(153, 102, 204).","ref":"Fledex.Color.Names.html#amethyst/1"},{"type":"function","title":"Fledex.Color.Names.amethyst/2","doc":"","ref":"Fledex.Color.Names.html#amethyst/2"},{"type":"function","title":"Fledex.Color.Names.android_green/1","doc":"Defines the color rgb(61, 219, 135).","ref":"Fledex.Color.Names.html#android_green/1"},{"type":"function","title":"Fledex.Color.Names.android_green/2","doc":"","ref":"Fledex.Color.Names.html#android_green/2"},{"type":"function","title":"Fledex.Color.Names.antique_brass/1","doc":"Defines the color rgb(204, 147, 117).","ref":"Fledex.Color.Names.html#antique_brass/1"},{"type":"function","title":"Fledex.Color.Names.antique_brass/2","doc":"","ref":"Fledex.Color.Names.html#antique_brass/2"},{"type":"function","title":"Fledex.Color.Names.antique_bronze/1","doc":"Defines the color rgb(102, 91, 30).","ref":"Fledex.Color.Names.html#antique_bronze/1"},{"type":"function","title":"Fledex.Color.Names.antique_bronze/2","doc":"","ref":"Fledex.Color.Names.html#antique_bronze/2"},{"type":"function","title":"Fledex.Color.Names.antique_fuchsia/1","doc":"Defines the color rgb(145, 91, 130).","ref":"Fledex.Color.Names.html#antique_fuchsia/1"},{"type":"function","title":"Fledex.Color.Names.antique_fuchsia/2","doc":"","ref":"Fledex.Color.Names.html#antique_fuchsia/2"},{"type":"function","title":"Fledex.Color.Names.antique_ruby/1","doc":"Defines the color rgb(132, 28, 45).","ref":"Fledex.Color.Names.html#antique_ruby/1"},{"type":"function","title":"Fledex.Color.Names.antique_ruby/2","doc":"","ref":"Fledex.Color.Names.html#antique_ruby/2"},{"type":"function","title":"Fledex.Color.Names.antique_white/1","doc":"Defines the color rgb(249, 234, 214).","ref":"Fledex.Color.Names.html#antique_white/1"},{"type":"function","title":"Fledex.Color.Names.antique_white/2","doc":"","ref":"Fledex.Color.Names.html#antique_white/2"},{"type":"function","title":"Fledex.Color.Names.apricot/1","doc":"Defines the color rgb(249, 206, 175).","ref":"Fledex.Color.Names.html#apricot/1"},{"type":"function","title":"Fledex.Color.Names.apricot/2","doc":"","ref":"Fledex.Color.Names.html#apricot/2"},{"type":"function","title":"Fledex.Color.Names.aqua/1","doc":"Defines the color rgb(0, 255, 255).","ref":"Fledex.Color.Names.html#aqua/1"},{"type":"function","title":"Fledex.Color.Names.aqua/2","doc":"","ref":"Fledex.Color.Names.html#aqua/2"},{"type":"function","title":"Fledex.Color.Names.aquamarine/1","doc":"Defines the color rgb(127, 255, 211).","ref":"Fledex.Color.Names.html#aquamarine/1"},{"type":"function","title":"Fledex.Color.Names.aquamarine/2","doc":"","ref":"Fledex.Color.Names.html#aquamarine/2"},{"type":"function","title":"Fledex.Color.Names.arctic_lime/1","doc":"Defines the color rgb(209, 255, 20).","ref":"Fledex.Color.Names.html#arctic_lime/1"},{"type":"function","title":"Fledex.Color.Names.arctic_lime/2","doc":"","ref":"Fledex.Color.Names.html#arctic_lime/2"},{"type":"function","title":"Fledex.Color.Names.artichoke_green/1","doc":"Defines the color rgb(73, 112, 68).","ref":"Fledex.Color.Names.html#artichoke_green/1"},{"type":"function","title":"Fledex.Color.Names.artichoke_green/2","doc":"","ref":"Fledex.Color.Names.html#artichoke_green/2"},{"type":"function","title":"Fledex.Color.Names.arylide_yellow/1","doc":"Defines the color rgb(232, 214, 107).","ref":"Fledex.Color.Names.html#arylide_yellow/1"},{"type":"function","title":"Fledex.Color.Names.arylide_yellow/2","doc":"","ref":"Fledex.Color.Names.html#arylide_yellow/2"},{"type":"function","title":"Fledex.Color.Names.ash_gray/1","doc":"Defines the color rgb(178, 191, 181).","ref":"Fledex.Color.Names.html#ash_gray/1"},{"type":"function","title":"Fledex.Color.Names.ash_gray/2","doc":"","ref":"Fledex.Color.Names.html#ash_gray/2"},{"type":"function","title":"Fledex.Color.Names.atomic_tangerine/1","doc":"Defines the color rgb(255, 153, 102).","ref":"Fledex.Color.Names.html#atomic_tangerine/1"},{"type":"function","title":"Fledex.Color.Names.atomic_tangerine/2","doc":"","ref":"Fledex.Color.Names.html#atomic_tangerine/2"},{"type":"function","title":"Fledex.Color.Names.aureolin/1","doc":"Defines the color rgb(252, 237, 0).","ref":"Fledex.Color.Names.html#aureolin/1"},{"type":"function","title":"Fledex.Color.Names.aureolin/2","doc":"","ref":"Fledex.Color.Names.html#aureolin/2"},{"type":"function","title":"Fledex.Color.Names.azure/1","doc":"Defines the color rgb(0, 127, 255).","ref":"Fledex.Color.Names.html#azure/1"},{"type":"function","title":"Fledex.Color.Names.azure/2","doc":"","ref":"Fledex.Color.Names.html#azure/2"},{"type":"function","title":"Fledex.Color.Names.azure_x11_web_color/1","doc":"Defines the color rgb(239, 255, 255).","ref":"Fledex.Color.Names.html#azure_x11_web_color/1"},{"type":"function","title":"Fledex.Color.Names.azure_x11_web_color/2","doc":"","ref":"Fledex.Color.Names.html#azure_x11_web_color/2"},{"type":"function","title":"Fledex.Color.Names.b_dazzled_blue/1","doc":"Defines the color rgb(45, 89, 147).","ref":"Fledex.Color.Names.html#b_dazzled_blue/1"},{"type":"function","title":"Fledex.Color.Names.b_dazzled_blue/2","doc":"","ref":"Fledex.Color.Names.html#b_dazzled_blue/2"},{"type":"function","title":"Fledex.Color.Names.baby_blue/1","doc":"Defines the color rgb(137, 206, 239).","ref":"Fledex.Color.Names.html#baby_blue/1"},{"type":"function","title":"Fledex.Color.Names.baby_blue/2","doc":"","ref":"Fledex.Color.Names.html#baby_blue/2"},{"type":"function","title":"Fledex.Color.Names.baby_blue_eyes/1","doc":"Defines the color rgb(160, 201, 242).","ref":"Fledex.Color.Names.html#baby_blue_eyes/1"},{"type":"function","title":"Fledex.Color.Names.baby_blue_eyes/2","doc":"","ref":"Fledex.Color.Names.html#baby_blue_eyes/2"},{"type":"function","title":"Fledex.Color.Names.baby_pink/1","doc":"Defines the color rgb(244, 193, 193).","ref":"Fledex.Color.Names.html#baby_pink/1"},{"type":"function","title":"Fledex.Color.Names.baby_pink/2","doc":"","ref":"Fledex.Color.Names.html#baby_pink/2"},{"type":"function","title":"Fledex.Color.Names.baby_powder/1","doc":"Defines the color rgb(255, 255, 249).","ref":"Fledex.Color.Names.html#baby_powder/1"},{"type":"function","title":"Fledex.Color.Names.baby_powder/2","doc":"","ref":"Fledex.Color.Names.html#baby_powder/2"},{"type":"function","title":"Fledex.Color.Names.baker_miller_pink/1","doc":"Defines the color rgb(255, 145, 175).","ref":"Fledex.Color.Names.html#baker_miller_pink/1"},{"type":"function","title":"Fledex.Color.Names.baker_miller_pink/2","doc":"","ref":"Fledex.Color.Names.html#baker_miller_pink/2"},{"type":"function","title":"Fledex.Color.Names.banana_mania/1","doc":"Defines the color rgb(249, 232, 181).","ref":"Fledex.Color.Names.html#banana_mania/1"},{"type":"function","title":"Fledex.Color.Names.banana_mania/2","doc":"","ref":"Fledex.Color.Names.html#banana_mania/2"},{"type":"function","title":"Fledex.Color.Names.barn_red/1","doc":"Defines the color rgb(124, 10, 2).","ref":"Fledex.Color.Names.html#barn_red/1"},{"type":"function","title":"Fledex.Color.Names.barn_red/2","doc":"","ref":"Fledex.Color.Names.html#barn_red/2"},{"type":"function","title":"Fledex.Color.Names.battleship_grey/1","doc":"Defines the color rgb(132, 132, 130).","ref":"Fledex.Color.Names.html#battleship_grey/1"},{"type":"function","title":"Fledex.Color.Names.battleship_grey/2","doc":"","ref":"Fledex.Color.Names.html#battleship_grey/2"},{"type":"function","title":"Fledex.Color.Names.beau_blue/1","doc":"Defines the color rgb(188, 211, 229).","ref":"Fledex.Color.Names.html#beau_blue/1"},{"type":"function","title":"Fledex.Color.Names.beau_blue/2","doc":"","ref":"Fledex.Color.Names.html#beau_blue/2"},{"type":"function","title":"Fledex.Color.Names.beaver/1","doc":"Defines the color rgb(158, 130, 112).","ref":"Fledex.Color.Names.html#beaver/1"},{"type":"function","title":"Fledex.Color.Names.beaver/2","doc":"","ref":"Fledex.Color.Names.html#beaver/2"},{"type":"function","title":"Fledex.Color.Names.beige/1","doc":"Defines the color rgb(244, 244, 219).","ref":"Fledex.Color.Names.html#beige/1"},{"type":"function","title":"Fledex.Color.Names.beige/2","doc":"","ref":"Fledex.Color.Names.html#beige/2"},{"type":"function","title":"Fledex.Color.Names.big_dip_o_ruby/1","doc":"Defines the color rgb(155, 38, 66).","ref":"Fledex.Color.Names.html#big_dip_o_ruby/1"},{"type":"function","title":"Fledex.Color.Names.big_dip_o_ruby/2","doc":"","ref":"Fledex.Color.Names.html#big_dip_o_ruby/2"},{"type":"function","title":"Fledex.Color.Names.bisque/1","doc":"Defines the color rgb(255, 226, 196).","ref":"Fledex.Color.Names.html#bisque/1"},{"type":"function","title":"Fledex.Color.Names.bisque/2","doc":"","ref":"Fledex.Color.Names.html#bisque/2"},{"type":"function","title":"Fledex.Color.Names.bistre/1","doc":"Defines the color rgb(61, 43, 30).","ref":"Fledex.Color.Names.html#bistre/1"},{"type":"function","title":"Fledex.Color.Names.bistre/2","doc":"","ref":"Fledex.Color.Names.html#bistre/2"},{"type":"function","title":"Fledex.Color.Names.bistre_brown/1","doc":"Defines the color rgb(150, 112, 22).","ref":"Fledex.Color.Names.html#bistre_brown/1"},{"type":"function","title":"Fledex.Color.Names.bistre_brown/2","doc":"","ref":"Fledex.Color.Names.html#bistre_brown/2"},{"type":"function","title":"Fledex.Color.Names.bitter_lemon/1","doc":"Defines the color rgb(201, 224, 12).","ref":"Fledex.Color.Names.html#bitter_lemon/1"},{"type":"function","title":"Fledex.Color.Names.bitter_lemon/2","doc":"","ref":"Fledex.Color.Names.html#bitter_lemon/2"},{"type":"function","title":"Fledex.Color.Names.black/1","doc":"Defines the color rgb(0, 0, 0).","ref":"Fledex.Color.Names.html#black/1"},{"type":"function","title":"Fledex.Color.Names.black/2","doc":"","ref":"Fledex.Color.Names.html#black/2"},{"type":"function","title":"Fledex.Color.Names.black_bean/1","doc":"Defines the color rgb(61, 12, 2).","ref":"Fledex.Color.Names.html#black_bean/1"},{"type":"function","title":"Fledex.Color.Names.black_bean/2","doc":"","ref":"Fledex.Color.Names.html#black_bean/2"},{"type":"function","title":"Fledex.Color.Names.black_coral/1","doc":"Defines the color rgb(84, 96, 112).","ref":"Fledex.Color.Names.html#black_coral/1"},{"type":"function","title":"Fledex.Color.Names.black_coral/2","doc":"","ref":"Fledex.Color.Names.html#black_coral/2"},{"type":"function","title":"Fledex.Color.Names.black_olive/1","doc":"Defines the color rgb(58, 61, 53).","ref":"Fledex.Color.Names.html#black_olive/1"},{"type":"function","title":"Fledex.Color.Names.black_olive/2","doc":"","ref":"Fledex.Color.Names.html#black_olive/2"},{"type":"function","title":"Fledex.Color.Names.black_shadows/1","doc":"Defines the color rgb(191, 175, 178).","ref":"Fledex.Color.Names.html#black_shadows/1"},{"type":"function","title":"Fledex.Color.Names.black_shadows/2","doc":"","ref":"Fledex.Color.Names.html#black_shadows/2"},{"type":"function","title":"Fledex.Color.Names.blanched_almond/1","doc":"Defines the color rgb(255, 234, 204).","ref":"Fledex.Color.Names.html#blanched_almond/1"},{"type":"function","title":"Fledex.Color.Names.blanched_almond/2","doc":"","ref":"Fledex.Color.Names.html#blanched_almond/2"},{"type":"function","title":"Fledex.Color.Names.blast_off_bronze/1","doc":"Defines the color rgb(165, 112, 99).","ref":"Fledex.Color.Names.html#blast_off_bronze/1"},{"type":"function","title":"Fledex.Color.Names.blast_off_bronze/2","doc":"","ref":"Fledex.Color.Names.html#blast_off_bronze/2"},{"type":"function","title":"Fledex.Color.Names.bleu_de_france/1","doc":"Defines the color rgb(48, 140, 232).","ref":"Fledex.Color.Names.html#bleu_de_france/1"},{"type":"function","title":"Fledex.Color.Names.bleu_de_france/2","doc":"","ref":"Fledex.Color.Names.html#bleu_de_france/2"},{"type":"function","title":"Fledex.Color.Names.blizzard_blue/1","doc":"Defines the color rgb(170, 229, 237).","ref":"Fledex.Color.Names.html#blizzard_blue/1"},{"type":"function","title":"Fledex.Color.Names.blizzard_blue/2","doc":"","ref":"Fledex.Color.Names.html#blizzard_blue/2"},{"type":"function","title":"Fledex.Color.Names.blood_red/1","doc":"Defines the color rgb(102, 0, 0).","ref":"Fledex.Color.Names.html#blood_red/1"},{"type":"function","title":"Fledex.Color.Names.blood_red/2","doc":"","ref":"Fledex.Color.Names.html#blood_red/2"},{"type":"function","title":"Fledex.Color.Names.blue/1","doc":"Defines the color rgb(0, 0, 255).","ref":"Fledex.Color.Names.html#blue/1"},{"type":"function","title":"Fledex.Color.Names.blue/2","doc":"","ref":"Fledex.Color.Names.html#blue/2"},{"type":"function","title":"Fledex.Color.Names.blue_bell/1","doc":"Defines the color rgb(163, 163, 209).","ref":"Fledex.Color.Names.html#blue_bell/1"},{"type":"function","title":"Fledex.Color.Names.blue_bell/2","doc":"","ref":"Fledex.Color.Names.html#blue_bell/2"},{"type":"function","title":"Fledex.Color.Names.blue_crayola/1","doc":"Defines the color rgb(30, 117, 255).","ref":"Fledex.Color.Names.html#blue_crayola/1"},{"type":"function","title":"Fledex.Color.Names.blue_crayola/2","doc":"","ref":"Fledex.Color.Names.html#blue_crayola/2"},{"type":"function","title":"Fledex.Color.Names.blue_gray_crayola/1","doc":"Defines the color rgb(102, 153, 204).","ref":"Fledex.Color.Names.html#blue_gray_crayola/1"},{"type":"function","title":"Fledex.Color.Names.blue_gray_crayola/2","doc":"","ref":"Fledex.Color.Names.html#blue_gray_crayola/2"},{"type":"function","title":"Fledex.Color.Names.blue_jeans/1","doc":"Defines the color rgb(91, 173, 237).","ref":"Fledex.Color.Names.html#blue_jeans/1"},{"type":"function","title":"Fledex.Color.Names.blue_jeans/2","doc":"","ref":"Fledex.Color.Names.html#blue_jeans/2"},{"type":"function","title":"Fledex.Color.Names.blue_munsell/1","doc":"Defines the color rgb(0, 147, 175).","ref":"Fledex.Color.Names.html#blue_munsell/1"},{"type":"function","title":"Fledex.Color.Names.blue_munsell/2","doc":"","ref":"Fledex.Color.Names.html#blue_munsell/2"},{"type":"function","title":"Fledex.Color.Names.blue_ncs/1","doc":"Defines the color rgb(0, 135, 188).","ref":"Fledex.Color.Names.html#blue_ncs/1"},{"type":"function","title":"Fledex.Color.Names.blue_ncs/2","doc":"","ref":"Fledex.Color.Names.html#blue_ncs/2"},{"type":"function","title":"Fledex.Color.Names.blue_pantone/1","doc":"Defines the color rgb(0, 22, 168).","ref":"Fledex.Color.Names.html#blue_pantone/1"},{"type":"function","title":"Fledex.Color.Names.blue_pantone/2","doc":"","ref":"Fledex.Color.Names.html#blue_pantone/2"},{"type":"function","title":"Fledex.Color.Names.blue_pigment/1","doc":"Defines the color rgb(51, 51, 153).","ref":"Fledex.Color.Names.html#blue_pigment/1"},{"type":"function","title":"Fledex.Color.Names.blue_pigment/2","doc":"","ref":"Fledex.Color.Names.html#blue_pigment/2"},{"type":"function","title":"Fledex.Color.Names.blue_sapphire/1","doc":"Defines the color rgb(17, 96, 127).","ref":"Fledex.Color.Names.html#blue_sapphire/1"},{"type":"function","title":"Fledex.Color.Names.blue_sapphire/2","doc":"","ref":"Fledex.Color.Names.html#blue_sapphire/2"},{"type":"function","title":"Fledex.Color.Names.blue_violet/1","doc":"Defines the color rgb(137, 43, 226).","ref":"Fledex.Color.Names.html#blue_violet/1"},{"type":"function","title":"Fledex.Color.Names.blue_violet/2","doc":"","ref":"Fledex.Color.Names.html#blue_violet/2"},{"type":"function","title":"Fledex.Color.Names.blue_yonder/1","doc":"Defines the color rgb(79, 114, 165).","ref":"Fledex.Color.Names.html#blue_yonder/1"},{"type":"function","title":"Fledex.Color.Names.blue_yonder/2","doc":"","ref":"Fledex.Color.Names.html#blue_yonder/2"},{"type":"function","title":"Fledex.Color.Names.bluetiful/1","doc":"Defines the color rgb(61, 104, 232).","ref":"Fledex.Color.Names.html#bluetiful/1"},{"type":"function","title":"Fledex.Color.Names.bluetiful/2","doc":"","ref":"Fledex.Color.Names.html#bluetiful/2"},{"type":"function","title":"Fledex.Color.Names.blush/1","doc":"Defines the color rgb(221, 91, 130).","ref":"Fledex.Color.Names.html#blush/1"},{"type":"function","title":"Fledex.Color.Names.blush/2","doc":"","ref":"Fledex.Color.Names.html#blush/2"},{"type":"function","title":"Fledex.Color.Names.bole/1","doc":"Defines the color rgb(119, 68, 58).","ref":"Fledex.Color.Names.html#bole/1"},{"type":"function","title":"Fledex.Color.Names.bole/2","doc":"","ref":"Fledex.Color.Names.html#bole/2"},{"type":"function","title":"Fledex.Color.Names.bone/1","doc":"Defines the color rgb(226, 216, 201).","ref":"Fledex.Color.Names.html#bone/1"},{"type":"function","title":"Fledex.Color.Names.bone/2","doc":"","ref":"Fledex.Color.Names.html#bone/2"},{"type":"function","title":"Fledex.Color.Names.brick_red/1","doc":"Defines the color rgb(204, 63, 84).","ref":"Fledex.Color.Names.html#brick_red/1"},{"type":"function","title":"Fledex.Color.Names.brick_red/2","doc":"","ref":"Fledex.Color.Names.html#brick_red/2"},{"type":"function","title":"Fledex.Color.Names.bright_lilac/1","doc":"Defines the color rgb(216, 145, 239).","ref":"Fledex.Color.Names.html#bright_lilac/1"},{"type":"function","title":"Fledex.Color.Names.bright_lilac/2","doc":"","ref":"Fledex.Color.Names.html#bright_lilac/2"},{"type":"function","title":"Fledex.Color.Names.bright_yellow_crayola/1","doc":"Defines the color rgb(255, 170, 28).","ref":"Fledex.Color.Names.html#bright_yellow_crayola/1"},{"type":"function","title":"Fledex.Color.Names.bright_yellow_crayola/2","doc":"","ref":"Fledex.Color.Names.html#bright_yellow_crayola/2"},{"type":"function","title":"Fledex.Color.Names.bronze/1","doc":"Defines the color rgb(204, 127, 51).","ref":"Fledex.Color.Names.html#bronze/1"},{"type":"function","title":"Fledex.Color.Names.bronze/2","doc":"","ref":"Fledex.Color.Names.html#bronze/2"},{"type":"function","title":"Fledex.Color.Names.brown_sugar/1","doc":"Defines the color rgb(175, 109, 76).","ref":"Fledex.Color.Names.html#brown_sugar/1"},{"type":"function","title":"Fledex.Color.Names.brown_sugar/2","doc":"","ref":"Fledex.Color.Names.html#brown_sugar/2"},{"type":"function","title":"Fledex.Color.Names.bud_green/1","doc":"Defines the color rgb(122, 181, 96).","ref":"Fledex.Color.Names.html#bud_green/1"},{"type":"function","title":"Fledex.Color.Names.bud_green/2","doc":"","ref":"Fledex.Color.Names.html#bud_green/2"},{"type":"function","title":"Fledex.Color.Names.buff/1","doc":"Defines the color rgb(255, 198, 127).","ref":"Fledex.Color.Names.html#buff/1"},{"type":"function","title":"Fledex.Color.Names.buff/2","doc":"","ref":"Fledex.Color.Names.html#buff/2"},{"type":"function","title":"Fledex.Color.Names.burgundy/1","doc":"Defines the color rgb(127, 0, 33).","ref":"Fledex.Color.Names.html#burgundy/1"},{"type":"function","title":"Fledex.Color.Names.burgundy/2","doc":"","ref":"Fledex.Color.Names.html#burgundy/2"},{"type":"function","title":"Fledex.Color.Names.burlywood/1","doc":"Defines the color rgb(221, 183, 135).","ref":"Fledex.Color.Names.html#burlywood/1"},{"type":"function","title":"Fledex.Color.Names.burlywood/2","doc":"","ref":"Fledex.Color.Names.html#burlywood/2"},{"type":"function","title":"Fledex.Color.Names.burnished_brown/1","doc":"Defines the color rgb(160, 122, 114).","ref":"Fledex.Color.Names.html#burnished_brown/1"},{"type":"function","title":"Fledex.Color.Names.burnished_brown/2","doc":"","ref":"Fledex.Color.Names.html#burnished_brown/2"},{"type":"function","title":"Fledex.Color.Names.burnt_orange/1","doc":"Defines the color rgb(204, 84, 0).","ref":"Fledex.Color.Names.html#burnt_orange/1"},{"type":"function","title":"Fledex.Color.Names.burnt_orange/2","doc":"","ref":"Fledex.Color.Names.html#burnt_orange/2"},{"type":"function","title":"Fledex.Color.Names.burnt_sienna/1","doc":"Defines the color rgb(232, 114, 81).","ref":"Fledex.Color.Names.html#burnt_sienna/1"},{"type":"function","title":"Fledex.Color.Names.burnt_sienna/2","doc":"","ref":"Fledex.Color.Names.html#burnt_sienna/2"},{"type":"function","title":"Fledex.Color.Names.burnt_umber/1","doc":"Defines the color rgb(137, 51, 35).","ref":"Fledex.Color.Names.html#burnt_umber/1"},{"type":"function","title":"Fledex.Color.Names.burnt_umber/2","doc":"","ref":"Fledex.Color.Names.html#burnt_umber/2"},{"type":"function","title":"Fledex.Color.Names.byzantine/1","doc":"Defines the color rgb(188, 51, 163).","ref":"Fledex.Color.Names.html#byzantine/1"},{"type":"function","title":"Fledex.Color.Names.byzantine/2","doc":"","ref":"Fledex.Color.Names.html#byzantine/2"},{"type":"function","title":"Fledex.Color.Names.byzantium/1","doc":"Defines the color rgb(112, 40, 99).","ref":"Fledex.Color.Names.html#byzantium/1"},{"type":"function","title":"Fledex.Color.Names.byzantium/2","doc":"","ref":"Fledex.Color.Names.html#byzantium/2"},{"type":"function","title":"Fledex.Color.Names.cadet_blue/1","doc":"Defines the color rgb(94, 158, 160).","ref":"Fledex.Color.Names.html#cadet_blue/1"},{"type":"function","title":"Fledex.Color.Names.cadet_blue/2","doc":"","ref":"Fledex.Color.Names.html#cadet_blue/2"},{"type":"function","title":"Fledex.Color.Names.cadet_grey/1","doc":"Defines the color rgb(145, 163, 175).","ref":"Fledex.Color.Names.html#cadet_grey/1"},{"type":"function","title":"Fledex.Color.Names.cadet_grey/2","doc":"","ref":"Fledex.Color.Names.html#cadet_grey/2"},{"type":"function","title":"Fledex.Color.Names.cadmium_green/1","doc":"Defines the color rgb(0, 107, 61).","ref":"Fledex.Color.Names.html#cadmium_green/1"},{"type":"function","title":"Fledex.Color.Names.cadmium_green/2","doc":"","ref":"Fledex.Color.Names.html#cadmium_green/2"},{"type":"function","title":"Fledex.Color.Names.cadmium_orange/1","doc":"Defines the color rgb(237, 135, 45).","ref":"Fledex.Color.Names.html#cadmium_orange/1"},{"type":"function","title":"Fledex.Color.Names.cadmium_orange/2","doc":"","ref":"Fledex.Color.Names.html#cadmium_orange/2"},{"type":"function","title":"Fledex.Color.Names.cafe_au_lait/1","doc":"Defines the color rgb(165, 122, 91).","ref":"Fledex.Color.Names.html#cafe_au_lait/1"},{"type":"function","title":"Fledex.Color.Names.cafe_au_lait/2","doc":"","ref":"Fledex.Color.Names.html#cafe_au_lait/2"},{"type":"function","title":"Fledex.Color.Names.cafe_noir/1","doc":"Defines the color rgb(73, 53, 33).","ref":"Fledex.Color.Names.html#cafe_noir/1"},{"type":"function","title":"Fledex.Color.Names.cafe_noir/2","doc":"","ref":"Fledex.Color.Names.html#cafe_noir/2"},{"type":"function","title":"Fledex.Color.Names.cambridge_blue/1","doc":"Defines the color rgb(163, 193, 173).","ref":"Fledex.Color.Names.html#cambridge_blue/1"},{"type":"function","title":"Fledex.Color.Names.cambridge_blue/2","doc":"","ref":"Fledex.Color.Names.html#cambridge_blue/2"},{"type":"function","title":"Fledex.Color.Names.camel/1","doc":"Defines the color rgb(193, 153, 107).","ref":"Fledex.Color.Names.html#camel/1"},{"type":"function","title":"Fledex.Color.Names.camel/2","doc":"","ref":"Fledex.Color.Names.html#camel/2"},{"type":"function","title":"Fledex.Color.Names.cameo_pink/1","doc":"Defines the color rgb(239, 186, 204).","ref":"Fledex.Color.Names.html#cameo_pink/1"},{"type":"function","title":"Fledex.Color.Names.cameo_pink/2","doc":"","ref":"Fledex.Color.Names.html#cameo_pink/2"},{"type":"function","title":"Fledex.Color.Names.canary/1","doc":"Defines the color rgb(255, 255, 153).","ref":"Fledex.Color.Names.html#canary/1"},{"type":"function","title":"Fledex.Color.Names.canary/2","doc":"","ref":"Fledex.Color.Names.html#canary/2"},{"type":"function","title":"Fledex.Color.Names.canary_yellow/1","doc":"Defines the color rgb(255, 239, 0).","ref":"Fledex.Color.Names.html#canary_yellow/1"},{"type":"function","title":"Fledex.Color.Names.canary_yellow/2","doc":"","ref":"Fledex.Color.Names.html#canary_yellow/2"},{"type":"function","title":"Fledex.Color.Names.candy_pink/1","doc":"Defines the color rgb(226, 112, 122).","ref":"Fledex.Color.Names.html#candy_pink/1"},{"type":"function","title":"Fledex.Color.Names.candy_pink/2","doc":"","ref":"Fledex.Color.Names.html#candy_pink/2"},{"type":"function","title":"Fledex.Color.Names.cardinal/1","doc":"Defines the color rgb(196, 30, 58).","ref":"Fledex.Color.Names.html#cardinal/1"},{"type":"function","title":"Fledex.Color.Names.cardinal/2","doc":"","ref":"Fledex.Color.Names.html#cardinal/2"},{"type":"function","title":"Fledex.Color.Names.caribbean_green/1","doc":"Defines the color rgb(0, 204, 153).","ref":"Fledex.Color.Names.html#caribbean_green/1"},{"type":"function","title":"Fledex.Color.Names.caribbean_green/2","doc":"","ref":"Fledex.Color.Names.html#caribbean_green/2"},{"type":"function","title":"Fledex.Color.Names.carmine/1","doc":"Defines the color rgb(150, 0, 22).","ref":"Fledex.Color.Names.html#carmine/1"},{"type":"function","title":"Fledex.Color.Names.carmine/2","doc":"","ref":"Fledex.Color.Names.html#carmine/2"},{"type":"function","title":"Fledex.Color.Names.carmine_m_p/1","doc":"Defines the color rgb(214, 0, 63).","ref":"Fledex.Color.Names.html#carmine_m_p/1"},{"type":"function","title":"Fledex.Color.Names.carmine_m_p/2","doc":"","ref":"Fledex.Color.Names.html#carmine_m_p/2"},{"type":"function","title":"Fledex.Color.Names.carnation_pink/1","doc":"Defines the color rgb(255, 165, 201).","ref":"Fledex.Color.Names.html#carnation_pink/1"},{"type":"function","title":"Fledex.Color.Names.carnation_pink/2","doc":"","ref":"Fledex.Color.Names.html#carnation_pink/2"},{"type":"function","title":"Fledex.Color.Names.carnelian/1","doc":"Defines the color rgb(178, 28, 28).","ref":"Fledex.Color.Names.html#carnelian/1"},{"type":"function","title":"Fledex.Color.Names.carnelian/2","doc":"","ref":"Fledex.Color.Names.html#carnelian/2"},{"type":"function","title":"Fledex.Color.Names.carolina_blue/1","doc":"Defines the color rgb(86, 160, 211).","ref":"Fledex.Color.Names.html#carolina_blue/1"},{"type":"function","title":"Fledex.Color.Names.carolina_blue/2","doc":"","ref":"Fledex.Color.Names.html#carolina_blue/2"},{"type":"function","title":"Fledex.Color.Names.carrot_orange/1","doc":"Defines the color rgb(237, 145, 33).","ref":"Fledex.Color.Names.html#carrot_orange/1"},{"type":"function","title":"Fledex.Color.Names.carrot_orange/2","doc":"","ref":"Fledex.Color.Names.html#carrot_orange/2"},{"type":"function","title":"Fledex.Color.Names.catawba/1","doc":"Defines the color rgb(112, 53, 66).","ref":"Fledex.Color.Names.html#catawba/1"},{"type":"function","title":"Fledex.Color.Names.catawba/2","doc":"","ref":"Fledex.Color.Names.html#catawba/2"},{"type":"function","title":"Fledex.Color.Names.cedar_chest/1","doc":"Defines the color rgb(201, 89, 73).","ref":"Fledex.Color.Names.html#cedar_chest/1"},{"type":"function","title":"Fledex.Color.Names.cedar_chest/2","doc":"","ref":"Fledex.Color.Names.html#cedar_chest/2"},{"type":"function","title":"Fledex.Color.Names.celadon/1","doc":"Defines the color rgb(170, 224, 175).","ref":"Fledex.Color.Names.html#celadon/1"},{"type":"function","title":"Fledex.Color.Names.celadon/2","doc":"","ref":"Fledex.Color.Names.html#celadon/2"},{"type":"function","title":"Fledex.Color.Names.celeste/1","doc":"Defines the color rgb(178, 255, 255).","ref":"Fledex.Color.Names.html#celeste/1"},{"type":"function","title":"Fledex.Color.Names.celeste/2","doc":"","ref":"Fledex.Color.Names.html#celeste/2"},{"type":"function","title":"Fledex.Color.Names.cerise/1","doc":"Defines the color rgb(221, 48, 99).","ref":"Fledex.Color.Names.html#cerise/1"},{"type":"function","title":"Fledex.Color.Names.cerise/2","doc":"","ref":"Fledex.Color.Names.html#cerise/2"},{"type":"function","title":"Fledex.Color.Names.cerulean/1","doc":"Defines the color rgb(0, 122, 165).","ref":"Fledex.Color.Names.html#cerulean/1"},{"type":"function","title":"Fledex.Color.Names.cerulean/2","doc":"","ref":"Fledex.Color.Names.html#cerulean/2"},{"type":"function","title":"Fledex.Color.Names.cerulean_blue/1","doc":"Defines the color rgb(40, 81, 191).","ref":"Fledex.Color.Names.html#cerulean_blue/1"},{"type":"function","title":"Fledex.Color.Names.cerulean_blue/2","doc":"","ref":"Fledex.Color.Names.html#cerulean_blue/2"},{"type":"function","title":"Fledex.Color.Names.cerulean_crayola/1","doc":"Defines the color rgb(28, 170, 214).","ref":"Fledex.Color.Names.html#cerulean_crayola/1"},{"type":"function","title":"Fledex.Color.Names.cerulean_crayola/2","doc":"","ref":"Fledex.Color.Names.html#cerulean_crayola/2"},{"type":"function","title":"Fledex.Color.Names.cerulean_frost/1","doc":"Defines the color rgb(109, 155, 193).","ref":"Fledex.Color.Names.html#cerulean_frost/1"},{"type":"function","title":"Fledex.Color.Names.cerulean_frost/2","doc":"","ref":"Fledex.Color.Names.html#cerulean_frost/2"},{"type":"function","title":"Fledex.Color.Names.champagne/1","doc":"Defines the color rgb(247, 232, 206).","ref":"Fledex.Color.Names.html#champagne/1"},{"type":"function","title":"Fledex.Color.Names.champagne/2","doc":"","ref":"Fledex.Color.Names.html#champagne/2"},{"type":"function","title":"Fledex.Color.Names.champagne_pink/1","doc":"Defines the color rgb(242, 221, 206).","ref":"Fledex.Color.Names.html#champagne_pink/1"},{"type":"function","title":"Fledex.Color.Names.champagne_pink/2","doc":"","ref":"Fledex.Color.Names.html#champagne_pink/2"},{"type":"function","title":"Fledex.Color.Names.charcoal/1","doc":"Defines the color rgb(53, 68, 79).","ref":"Fledex.Color.Names.html#charcoal/1"},{"type":"function","title":"Fledex.Color.Names.charcoal/2","doc":"","ref":"Fledex.Color.Names.html#charcoal/2"},{"type":"function","title":"Fledex.Color.Names.charm_pink/1","doc":"Defines the color rgb(229, 142, 170).","ref":"Fledex.Color.Names.html#charm_pink/1"},{"type":"function","title":"Fledex.Color.Names.charm_pink/2","doc":"","ref":"Fledex.Color.Names.html#charm_pink/2"},{"type":"function","title":"Fledex.Color.Names.chartreuse_web/1","doc":"Defines the color rgb(127, 255, 0).","ref":"Fledex.Color.Names.html#chartreuse_web/1"},{"type":"function","title":"Fledex.Color.Names.chartreuse_web/2","doc":"","ref":"Fledex.Color.Names.html#chartreuse_web/2"},{"type":"function","title":"Fledex.Color.Names.cherry_blossom_pink/1","doc":"Defines the color rgb(255, 183, 196).","ref":"Fledex.Color.Names.html#cherry_blossom_pink/1"},{"type":"function","title":"Fledex.Color.Names.cherry_blossom_pink/2","doc":"","ref":"Fledex.Color.Names.html#cherry_blossom_pink/2"},{"type":"function","title":"Fledex.Color.Names.chestnut/1","doc":"Defines the color rgb(147, 68, 53).","ref":"Fledex.Color.Names.html#chestnut/1"},{"type":"function","title":"Fledex.Color.Names.chestnut/2","doc":"","ref":"Fledex.Color.Names.html#chestnut/2"},{"type":"function","title":"Fledex.Color.Names.chili_red/1","doc":"Defines the color rgb(226, 61, 40).","ref":"Fledex.Color.Names.html#chili_red/1"},{"type":"function","title":"Fledex.Color.Names.chili_red/2","doc":"","ref":"Fledex.Color.Names.html#chili_red/2"},{"type":"function","title":"Fledex.Color.Names.china_pink/1","doc":"Defines the color rgb(221, 112, 160).","ref":"Fledex.Color.Names.html#china_pink/1"},{"type":"function","title":"Fledex.Color.Names.china_pink/2","doc":"","ref":"Fledex.Color.Names.html#china_pink/2"},{"type":"function","title":"Fledex.Color.Names.chinese_red/1","doc":"Defines the color rgb(170, 56, 30).","ref":"Fledex.Color.Names.html#chinese_red/1"},{"type":"function","title":"Fledex.Color.Names.chinese_red/2","doc":"","ref":"Fledex.Color.Names.html#chinese_red/2"},{"type":"function","title":"Fledex.Color.Names.chinese_violet/1","doc":"Defines the color rgb(132, 96, 135).","ref":"Fledex.Color.Names.html#chinese_violet/1"},{"type":"function","title":"Fledex.Color.Names.chinese_violet/2","doc":"","ref":"Fledex.Color.Names.html#chinese_violet/2"},{"type":"function","title":"Fledex.Color.Names.chinese_yellow/1","doc":"Defines the color rgb(255, 178, 0).","ref":"Fledex.Color.Names.html#chinese_yellow/1"},{"type":"function","title":"Fledex.Color.Names.chinese_yellow/2","doc":"","ref":"Fledex.Color.Names.html#chinese_yellow/2"},{"type":"function","title":"Fledex.Color.Names.chocolate_traditional/1","doc":"Defines the color rgb(122, 63, 0).","ref":"Fledex.Color.Names.html#chocolate_traditional/1"},{"type":"function","title":"Fledex.Color.Names.chocolate_traditional/2","doc":"","ref":"Fledex.Color.Names.html#chocolate_traditional/2"},{"type":"function","title":"Fledex.Color.Names.chocolate_web/1","doc":"Defines the color rgb(209, 104, 30).","ref":"Fledex.Color.Names.html#chocolate_web/1"},{"type":"function","title":"Fledex.Color.Names.chocolate_web/2","doc":"","ref":"Fledex.Color.Names.html#chocolate_web/2"},{"type":"function","title":"Fledex.Color.Names.cinereous/1","doc":"Defines the color rgb(153, 130, 122).","ref":"Fledex.Color.Names.html#cinereous/1"},{"type":"function","title":"Fledex.Color.Names.cinereous/2","doc":"","ref":"Fledex.Color.Names.html#cinereous/2"},{"type":"function","title":"Fledex.Color.Names.cinnabar/1","doc":"Defines the color rgb(226, 66, 51).","ref":"Fledex.Color.Names.html#cinnabar/1"},{"type":"function","title":"Fledex.Color.Names.cinnabar/2","doc":"","ref":"Fledex.Color.Names.html#cinnabar/2"},{"type":"function","title":"Fledex.Color.Names.cinnamon_satin/1","doc":"Defines the color rgb(204, 96, 124).","ref":"Fledex.Color.Names.html#cinnamon_satin/1"},{"type":"function","title":"Fledex.Color.Names.cinnamon_satin/2","doc":"","ref":"Fledex.Color.Names.html#cinnamon_satin/2"},{"type":"function","title":"Fledex.Color.Names.citrine/1","doc":"Defines the color rgb(226, 209, 10).","ref":"Fledex.Color.Names.html#citrine/1"},{"type":"function","title":"Fledex.Color.Names.citrine/2","doc":"","ref":"Fledex.Color.Names.html#citrine/2"},{"type":"function","title":"Fledex.Color.Names.citron/1","doc":"Defines the color rgb(158, 168, 30).","ref":"Fledex.Color.Names.html#citron/1"},{"type":"function","title":"Fledex.Color.Names.citron/2","doc":"","ref":"Fledex.Color.Names.html#citron/2"},{"type":"function","title":"Fledex.Color.Names.claret/1","doc":"Defines the color rgb(127, 22, 51).","ref":"Fledex.Color.Names.html#claret/1"},{"type":"function","title":"Fledex.Color.Names.claret/2","doc":"","ref":"Fledex.Color.Names.html#claret/2"},{"type":"function","title":"Fledex.Color.Names.coffee/1","doc":"Defines the color rgb(112, 79, 56).","ref":"Fledex.Color.Names.html#coffee/1"},{"type":"function","title":"Fledex.Color.Names.coffee/2","doc":"","ref":"Fledex.Color.Names.html#coffee/2"},{"type":"function","title":"Fledex.Color.Names.colors/0","doc":"Get all the data about the predefined colors","ref":"Fledex.Color.Names.html#colors/0"},{"type":"function","title":"Fledex.Color.Names.columbia_blue/1","doc":"Defines the color rgb(186, 216, 234).","ref":"Fledex.Color.Names.html#columbia_blue/1"},{"type":"function","title":"Fledex.Color.Names.columbia_blue/2","doc":"","ref":"Fledex.Color.Names.html#columbia_blue/2"},{"type":"function","title":"Fledex.Color.Names.congo_pink/1","doc":"Defines the color rgb(247, 130, 119).","ref":"Fledex.Color.Names.html#congo_pink/1"},{"type":"function","title":"Fledex.Color.Names.congo_pink/2","doc":"","ref":"Fledex.Color.Names.html#congo_pink/2"},{"type":"function","title":"Fledex.Color.Names.cool_grey/1","doc":"Defines the color rgb(140, 145, 170).","ref":"Fledex.Color.Names.html#cool_grey/1"},{"type":"function","title":"Fledex.Color.Names.cool_grey/2","doc":"","ref":"Fledex.Color.Names.html#cool_grey/2"},{"type":"function","title":"Fledex.Color.Names.copper/1","doc":"Defines the color rgb(183, 114, 51).","ref":"Fledex.Color.Names.html#copper/1"},{"type":"function","title":"Fledex.Color.Names.copper/2","doc":"","ref":"Fledex.Color.Names.html#copper/2"},{"type":"function","title":"Fledex.Color.Names.copper_crayola/1","doc":"Defines the color rgb(216, 137, 102).","ref":"Fledex.Color.Names.html#copper_crayola/1"},{"type":"function","title":"Fledex.Color.Names.copper_crayola/2","doc":"","ref":"Fledex.Color.Names.html#copper_crayola/2"},{"type":"function","title":"Fledex.Color.Names.copper_penny/1","doc":"Defines the color rgb(173, 112, 104).","ref":"Fledex.Color.Names.html#copper_penny/1"},{"type":"function","title":"Fledex.Color.Names.copper_penny/2","doc":"","ref":"Fledex.Color.Names.html#copper_penny/2"},{"type":"function","title":"Fledex.Color.Names.copper_red/1","doc":"Defines the color rgb(204, 109, 81).","ref":"Fledex.Color.Names.html#copper_red/1"},{"type":"function","title":"Fledex.Color.Names.copper_red/2","doc":"","ref":"Fledex.Color.Names.html#copper_red/2"},{"type":"function","title":"Fledex.Color.Names.copper_rose/1","doc":"Defines the color rgb(153, 102, 102).","ref":"Fledex.Color.Names.html#copper_rose/1"},{"type":"function","title":"Fledex.Color.Names.copper_rose/2","doc":"","ref":"Fledex.Color.Names.html#copper_rose/2"},{"type":"function","title":"Fledex.Color.Names.coquelicot/1","doc":"Defines the color rgb(255, 56, 0).","ref":"Fledex.Color.Names.html#coquelicot/1"},{"type":"function","title":"Fledex.Color.Names.coquelicot/2","doc":"","ref":"Fledex.Color.Names.html#coquelicot/2"},{"type":"function","title":"Fledex.Color.Names.coral/1","doc":"Defines the color rgb(255, 127, 79).","ref":"Fledex.Color.Names.html#coral/1"},{"type":"function","title":"Fledex.Color.Names.coral/2","doc":"","ref":"Fledex.Color.Names.html#coral/2"},{"type":"function","title":"Fledex.Color.Names.coral_pink/1","doc":"Defines the color rgb(247, 130, 119).","ref":"Fledex.Color.Names.html#coral_pink/1"},{"type":"function","title":"Fledex.Color.Names.coral_pink/2","doc":"","ref":"Fledex.Color.Names.html#coral_pink/2"},{"type":"function","title":"Fledex.Color.Names.cordovan/1","doc":"Defines the color rgb(137, 63, 68).","ref":"Fledex.Color.Names.html#cordovan/1"},{"type":"function","title":"Fledex.Color.Names.cordovan/2","doc":"","ref":"Fledex.Color.Names.html#cordovan/2"},{"type":"function","title":"Fledex.Color.Names.corn/1","doc":"Defines the color rgb(249, 237, 91).","ref":"Fledex.Color.Names.html#corn/1"},{"type":"function","title":"Fledex.Color.Names.corn/2","doc":"","ref":"Fledex.Color.Names.html#corn/2"},{"type":"function","title":"Fledex.Color.Names.cornflower_blue/1","doc":"Defines the color rgb(99, 147, 237).","ref":"Fledex.Color.Names.html#cornflower_blue/1"},{"type":"function","title":"Fledex.Color.Names.cornflower_blue/2","doc":"","ref":"Fledex.Color.Names.html#cornflower_blue/2"},{"type":"function","title":"Fledex.Color.Names.cornsilk/1","doc":"Defines the color rgb(255, 247, 219).","ref":"Fledex.Color.Names.html#cornsilk/1"},{"type":"function","title":"Fledex.Color.Names.cornsilk/2","doc":"","ref":"Fledex.Color.Names.html#cornsilk/2"},{"type":"function","title":"Fledex.Color.Names.cosmic_cobalt/1","doc":"Defines the color rgb(45, 45, 135).","ref":"Fledex.Color.Names.html#cosmic_cobalt/1"},{"type":"function","title":"Fledex.Color.Names.cosmic_cobalt/2","doc":"","ref":"Fledex.Color.Names.html#cosmic_cobalt/2"},{"type":"function","title":"Fledex.Color.Names.cosmic_latte/1","doc":"Defines the color rgb(255, 247, 232).","ref":"Fledex.Color.Names.html#cosmic_latte/1"},{"type":"function","title":"Fledex.Color.Names.cosmic_latte/2","doc":"","ref":"Fledex.Color.Names.html#cosmic_latte/2"},{"type":"function","title":"Fledex.Color.Names.cotton_candy/1","doc":"Defines the color rgb(255, 188, 216).","ref":"Fledex.Color.Names.html#cotton_candy/1"},{"type":"function","title":"Fledex.Color.Names.cotton_candy/2","doc":"","ref":"Fledex.Color.Names.html#cotton_candy/2"},{"type":"function","title":"Fledex.Color.Names.coyote_brown/1","doc":"Defines the color rgb(130, 96, 61).","ref":"Fledex.Color.Names.html#coyote_brown/1"},{"type":"function","title":"Fledex.Color.Names.coyote_brown/2","doc":"","ref":"Fledex.Color.Names.html#coyote_brown/2"},{"type":"function","title":"Fledex.Color.Names.cream/1","doc":"Defines the color rgb(255, 252, 209).","ref":"Fledex.Color.Names.html#cream/1"},{"type":"function","title":"Fledex.Color.Names.cream/2","doc":"","ref":"Fledex.Color.Names.html#cream/2"},{"type":"function","title":"Fledex.Color.Names.crimson/1","doc":"Defines the color rgb(219, 20, 61).","ref":"Fledex.Color.Names.html#crimson/1"},{"type":"function","title":"Fledex.Color.Names.crimson/2","doc":"","ref":"Fledex.Color.Names.html#crimson/2"},{"type":"function","title":"Fledex.Color.Names.crimson_ua/1","doc":"Defines the color rgb(158, 28, 51).","ref":"Fledex.Color.Names.html#crimson_ua/1"},{"type":"function","title":"Fledex.Color.Names.crimson_ua/2","doc":"","ref":"Fledex.Color.Names.html#crimson_ua/2"},{"type":"function","title":"Fledex.Color.Names.cultured_pearl/1","doc":"Defines the color rgb(244, 244, 244).","ref":"Fledex.Color.Names.html#cultured_pearl/1"},{"type":"function","title":"Fledex.Color.Names.cultured_pearl/2","doc":"","ref":"Fledex.Color.Names.html#cultured_pearl/2"},{"type":"function","title":"Fledex.Color.Names.cyan/1","doc":"Defines the color rgb(0, 255, 255).","ref":"Fledex.Color.Names.html#cyan/1"},{"type":"function","title":"Fledex.Color.Names.cyan/2","doc":"","ref":"Fledex.Color.Names.html#cyan/2"},{"type":"function","title":"Fledex.Color.Names.cyan_process/1","doc":"Defines the color rgb(0, 183, 234).","ref":"Fledex.Color.Names.html#cyan_process/1"},{"type":"function","title":"Fledex.Color.Names.cyan_process/2","doc":"","ref":"Fledex.Color.Names.html#cyan_process/2"},{"type":"function","title":"Fledex.Color.Names.cyber_grape/1","doc":"Defines the color rgb(89, 66, 124).","ref":"Fledex.Color.Names.html#cyber_grape/1"},{"type":"function","title":"Fledex.Color.Names.cyber_grape/2","doc":"","ref":"Fledex.Color.Names.html#cyber_grape/2"},{"type":"function","title":"Fledex.Color.Names.cyber_yellow/1","doc":"Defines the color rgb(255, 211, 0).","ref":"Fledex.Color.Names.html#cyber_yellow/1"},{"type":"function","title":"Fledex.Color.Names.cyber_yellow/2","doc":"","ref":"Fledex.Color.Names.html#cyber_yellow/2"},{"type":"function","title":"Fledex.Color.Names.cyclamen/1","doc":"Defines the color rgb(244, 112, 160).","ref":"Fledex.Color.Names.html#cyclamen/1"},{"type":"function","title":"Fledex.Color.Names.cyclamen/2","doc":"","ref":"Fledex.Color.Names.html#cyclamen/2"},{"type":"function","title":"Fledex.Color.Names.dark_brown/1","doc":"Defines the color rgb(102, 66, 33).","ref":"Fledex.Color.Names.html#dark_brown/1"},{"type":"function","title":"Fledex.Color.Names.dark_brown/2","doc":"","ref":"Fledex.Color.Names.html#dark_brown/2"},{"type":"function","title":"Fledex.Color.Names.dark_byzantium/1","doc":"Defines the color rgb(91, 56, 84).","ref":"Fledex.Color.Names.html#dark_byzantium/1"},{"type":"function","title":"Fledex.Color.Names.dark_byzantium/2","doc":"","ref":"Fledex.Color.Names.html#dark_byzantium/2"},{"type":"function","title":"Fledex.Color.Names.dark_cyan/1","doc":"Defines the color rgb(0, 140, 140).","ref":"Fledex.Color.Names.html#dark_cyan/1"},{"type":"function","title":"Fledex.Color.Names.dark_cyan/2","doc":"","ref":"Fledex.Color.Names.html#dark_cyan/2"},{"type":"function","title":"Fledex.Color.Names.dark_electric_blue/1","doc":"Defines the color rgb(84, 104, 119).","ref":"Fledex.Color.Names.html#dark_electric_blue/1"},{"type":"function","title":"Fledex.Color.Names.dark_electric_blue/2","doc":"","ref":"Fledex.Color.Names.html#dark_electric_blue/2"},{"type":"function","title":"Fledex.Color.Names.dark_goldenrod/1","doc":"Defines the color rgb(183, 135, 10).","ref":"Fledex.Color.Names.html#dark_goldenrod/1"},{"type":"function","title":"Fledex.Color.Names.dark_goldenrod/2","doc":"","ref":"Fledex.Color.Names.html#dark_goldenrod/2"},{"type":"function","title":"Fledex.Color.Names.dark_green_x11/1","doc":"Defines the color rgb(0, 99, 0).","ref":"Fledex.Color.Names.html#dark_green_x11/1"},{"type":"function","title":"Fledex.Color.Names.dark_green_x11/2","doc":"","ref":"Fledex.Color.Names.html#dark_green_x11/2"},{"type":"function","title":"Fledex.Color.Names.dark_jungle_green/1","doc":"Defines the color rgb(25, 35, 33).","ref":"Fledex.Color.Names.html#dark_jungle_green/1"},{"type":"function","title":"Fledex.Color.Names.dark_jungle_green/2","doc":"","ref":"Fledex.Color.Names.html#dark_jungle_green/2"},{"type":"function","title":"Fledex.Color.Names.dark_khaki/1","doc":"Defines the color rgb(188, 183, 107).","ref":"Fledex.Color.Names.html#dark_khaki/1"},{"type":"function","title":"Fledex.Color.Names.dark_khaki/2","doc":"","ref":"Fledex.Color.Names.html#dark_khaki/2"},{"type":"function","title":"Fledex.Color.Names.dark_lava/1","doc":"Defines the color rgb(71, 61, 51).","ref":"Fledex.Color.Names.html#dark_lava/1"},{"type":"function","title":"Fledex.Color.Names.dark_lava/2","doc":"","ref":"Fledex.Color.Names.html#dark_lava/2"},{"type":"function","title":"Fledex.Color.Names.dark_liver_horses/1","doc":"Defines the color rgb(84, 61, 56).","ref":"Fledex.Color.Names.html#dark_liver_horses/1"},{"type":"function","title":"Fledex.Color.Names.dark_liver_horses/2","doc":"","ref":"Fledex.Color.Names.html#dark_liver_horses/2"},{"type":"function","title":"Fledex.Color.Names.dark_magenta/1","doc":"Defines the color rgb(140, 0, 140).","ref":"Fledex.Color.Names.html#dark_magenta/1"},{"type":"function","title":"Fledex.Color.Names.dark_magenta/2","doc":"","ref":"Fledex.Color.Names.html#dark_magenta/2"},{"type":"function","title":"Fledex.Color.Names.dark_olive_green/1","doc":"Defines the color rgb(84, 107, 45).","ref":"Fledex.Color.Names.html#dark_olive_green/1"},{"type":"function","title":"Fledex.Color.Names.dark_olive_green/2","doc":"","ref":"Fledex.Color.Names.html#dark_olive_green/2"},{"type":"function","title":"Fledex.Color.Names.dark_orange/1","doc":"Defines the color rgb(255, 140, 0).","ref":"Fledex.Color.Names.html#dark_orange/1"},{"type":"function","title":"Fledex.Color.Names.dark_orange/2","doc":"","ref":"Fledex.Color.Names.html#dark_orange/2"},{"type":"function","title":"Fledex.Color.Names.dark_orchid/1","doc":"Defines the color rgb(153, 51, 204).","ref":"Fledex.Color.Names.html#dark_orchid/1"},{"type":"function","title":"Fledex.Color.Names.dark_orchid/2","doc":"","ref":"Fledex.Color.Names.html#dark_orchid/2"},{"type":"function","title":"Fledex.Color.Names.dark_purple/1","doc":"Defines the color rgb(48, 25, 51).","ref":"Fledex.Color.Names.html#dark_purple/1"},{"type":"function","title":"Fledex.Color.Names.dark_purple/2","doc":"","ref":"Fledex.Color.Names.html#dark_purple/2"},{"type":"function","title":"Fledex.Color.Names.dark_red/1","doc":"Defines the color rgb(140, 0, 0).","ref":"Fledex.Color.Names.html#dark_red/1"},{"type":"function","title":"Fledex.Color.Names.dark_red/2","doc":"","ref":"Fledex.Color.Names.html#dark_red/2"},{"type":"function","title":"Fledex.Color.Names.dark_salmon/1","doc":"Defines the color rgb(232, 150, 122).","ref":"Fledex.Color.Names.html#dark_salmon/1"},{"type":"function","title":"Fledex.Color.Names.dark_salmon/2","doc":"","ref":"Fledex.Color.Names.html#dark_salmon/2"},{"type":"function","title":"Fledex.Color.Names.dark_sea_green/1","doc":"Defines the color rgb(142, 188, 142).","ref":"Fledex.Color.Names.html#dark_sea_green/1"},{"type":"function","title":"Fledex.Color.Names.dark_sea_green/2","doc":"","ref":"Fledex.Color.Names.html#dark_sea_green/2"},{"type":"function","title":"Fledex.Color.Names.dark_sienna/1","doc":"Defines the color rgb(61, 20, 20).","ref":"Fledex.Color.Names.html#dark_sienna/1"},{"type":"function","title":"Fledex.Color.Names.dark_sienna/2","doc":"","ref":"Fledex.Color.Names.html#dark_sienna/2"},{"type":"function","title":"Fledex.Color.Names.dark_sky_blue/1","doc":"Defines the color rgb(140, 191, 214).","ref":"Fledex.Color.Names.html#dark_sky_blue/1"},{"type":"function","title":"Fledex.Color.Names.dark_sky_blue/2","doc":"","ref":"Fledex.Color.Names.html#dark_sky_blue/2"},{"type":"function","title":"Fledex.Color.Names.dark_slate_blue/1","doc":"Defines the color rgb(71, 61, 140).","ref":"Fledex.Color.Names.html#dark_slate_blue/1"},{"type":"function","title":"Fledex.Color.Names.dark_slate_blue/2","doc":"","ref":"Fledex.Color.Names.html#dark_slate_blue/2"},{"type":"function","title":"Fledex.Color.Names.dark_slate_gray/1","doc":"Defines the color rgb(45, 79, 79).","ref":"Fledex.Color.Names.html#dark_slate_gray/1"},{"type":"function","title":"Fledex.Color.Names.dark_slate_gray/2","doc":"","ref":"Fledex.Color.Names.html#dark_slate_gray/2"},{"type":"function","title":"Fledex.Color.Names.dark_spring_green/1","doc":"Defines the color rgb(22, 114, 68).","ref":"Fledex.Color.Names.html#dark_spring_green/1"},{"type":"function","title":"Fledex.Color.Names.dark_spring_green/2","doc":"","ref":"Fledex.Color.Names.html#dark_spring_green/2"},{"type":"function","title":"Fledex.Color.Names.dark_turquoise/1","doc":"Defines the color rgb(0, 206, 209).","ref":"Fledex.Color.Names.html#dark_turquoise/1"},{"type":"function","title":"Fledex.Color.Names.dark_turquoise/2","doc":"","ref":"Fledex.Color.Names.html#dark_turquoise/2"},{"type":"function","title":"Fledex.Color.Names.dark_violet/1","doc":"Defines the color rgb(147, 0, 211).","ref":"Fledex.Color.Names.html#dark_violet/1"},{"type":"function","title":"Fledex.Color.Names.dark_violet/2","doc":"","ref":"Fledex.Color.Names.html#dark_violet/2"},{"type":"function","title":"Fledex.Color.Names.davy_s_grey/1","doc":"Defines the color rgb(84, 84, 84).","ref":"Fledex.Color.Names.html#davy_s_grey/1"},{"type":"function","title":"Fledex.Color.Names.davy_s_grey/2","doc":"","ref":"Fledex.Color.Names.html#davy_s_grey/2"},{"type":"function","title":"Fledex.Color.Names.deep_cerise/1","doc":"Defines the color rgb(216, 51, 135).","ref":"Fledex.Color.Names.html#deep_cerise/1"},{"type":"function","title":"Fledex.Color.Names.deep_cerise/2","doc":"","ref":"Fledex.Color.Names.html#deep_cerise/2"},{"type":"function","title":"Fledex.Color.Names.deep_champagne/1","doc":"Defines the color rgb(249, 214, 165).","ref":"Fledex.Color.Names.html#deep_champagne/1"},{"type":"function","title":"Fledex.Color.Names.deep_champagne/2","doc":"","ref":"Fledex.Color.Names.html#deep_champagne/2"},{"type":"function","title":"Fledex.Color.Names.deep_chestnut/1","doc":"Defines the color rgb(186, 79, 71).","ref":"Fledex.Color.Names.html#deep_chestnut/1"},{"type":"function","title":"Fledex.Color.Names.deep_chestnut/2","doc":"","ref":"Fledex.Color.Names.html#deep_chestnut/2"},{"type":"function","title":"Fledex.Color.Names.deep_jungle_green/1","doc":"Defines the color rgb(0, 73, 73).","ref":"Fledex.Color.Names.html#deep_jungle_green/1"},{"type":"function","title":"Fledex.Color.Names.deep_jungle_green/2","doc":"","ref":"Fledex.Color.Names.html#deep_jungle_green/2"},{"type":"function","title":"Fledex.Color.Names.deep_pink/1","doc":"Defines the color rgb(255, 20, 147).","ref":"Fledex.Color.Names.html#deep_pink/1"},{"type":"function","title":"Fledex.Color.Names.deep_pink/2","doc":"","ref":"Fledex.Color.Names.html#deep_pink/2"},{"type":"function","title":"Fledex.Color.Names.deep_saffron/1","doc":"Defines the color rgb(255, 153, 51).","ref":"Fledex.Color.Names.html#deep_saffron/1"},{"type":"function","title":"Fledex.Color.Names.deep_saffron/2","doc":"","ref":"Fledex.Color.Names.html#deep_saffron/2"},{"type":"function","title":"Fledex.Color.Names.deep_sky_blue/1","doc":"Defines the color rgb(0, 191, 255).","ref":"Fledex.Color.Names.html#deep_sky_blue/1"},{"type":"function","title":"Fledex.Color.Names.deep_sky_blue/2","doc":"","ref":"Fledex.Color.Names.html#deep_sky_blue/2"},{"type":"function","title":"Fledex.Color.Names.deep_space_sparkle/1","doc":"Defines the color rgb(73, 99, 107).","ref":"Fledex.Color.Names.html#deep_space_sparkle/1"},{"type":"function","title":"Fledex.Color.Names.deep_space_sparkle/2","doc":"","ref":"Fledex.Color.Names.html#deep_space_sparkle/2"},{"type":"function","title":"Fledex.Color.Names.deep_taupe/1","doc":"Defines the color rgb(124, 94, 96).","ref":"Fledex.Color.Names.html#deep_taupe/1"},{"type":"function","title":"Fledex.Color.Names.deep_taupe/2","doc":"","ref":"Fledex.Color.Names.html#deep_taupe/2"},{"type":"function","title":"Fledex.Color.Names.denim/1","doc":"Defines the color rgb(20, 96, 188).","ref":"Fledex.Color.Names.html#denim/1"},{"type":"function","title":"Fledex.Color.Names.denim/2","doc":"","ref":"Fledex.Color.Names.html#denim/2"},{"type":"function","title":"Fledex.Color.Names.denim_blue/1","doc":"Defines the color rgb(33, 66, 181).","ref":"Fledex.Color.Names.html#denim_blue/1"},{"type":"function","title":"Fledex.Color.Names.denim_blue/2","doc":"","ref":"Fledex.Color.Names.html#denim_blue/2"},{"type":"function","title":"Fledex.Color.Names.desert/1","doc":"Defines the color rgb(193, 153, 107).","ref":"Fledex.Color.Names.html#desert/1"},{"type":"function","title":"Fledex.Color.Names.desert/2","doc":"","ref":"Fledex.Color.Names.html#desert/2"},{"type":"function","title":"Fledex.Color.Names.desert_sand/1","doc":"Defines the color rgb(237, 201, 175).","ref":"Fledex.Color.Names.html#desert_sand/1"},{"type":"function","title":"Fledex.Color.Names.desert_sand/2","doc":"","ref":"Fledex.Color.Names.html#desert_sand/2"},{"type":"function","title":"Fledex.Color.Names.dim_gray/1","doc":"Defines the color rgb(104, 104, 104).","ref":"Fledex.Color.Names.html#dim_gray/1"},{"type":"function","title":"Fledex.Color.Names.dim_gray/2","doc":"","ref":"Fledex.Color.Names.html#dim_gray/2"},{"type":"function","title":"Fledex.Color.Names.dodger_blue/1","doc":"Defines the color rgb(30, 142, 255).","ref":"Fledex.Color.Names.html#dodger_blue/1"},{"type":"function","title":"Fledex.Color.Names.dodger_blue/2","doc":"","ref":"Fledex.Color.Names.html#dodger_blue/2"},{"type":"function","title":"Fledex.Color.Names.drab_dark_brown/1","doc":"Defines the color rgb(73, 63, 40).","ref":"Fledex.Color.Names.html#drab_dark_brown/1"},{"type":"function","title":"Fledex.Color.Names.drab_dark_brown/2","doc":"","ref":"Fledex.Color.Names.html#drab_dark_brown/2"},{"type":"function","title":"Fledex.Color.Names.duke_blue/1","doc":"Defines the color rgb(0, 0, 155).","ref":"Fledex.Color.Names.html#duke_blue/1"},{"type":"function","title":"Fledex.Color.Names.duke_blue/2","doc":"","ref":"Fledex.Color.Names.html#duke_blue/2"},{"type":"function","title":"Fledex.Color.Names.dutch_white/1","doc":"Defines the color rgb(239, 221, 186).","ref":"Fledex.Color.Names.html#dutch_white/1"},{"type":"function","title":"Fledex.Color.Names.dutch_white/2","doc":"","ref":"Fledex.Color.Names.html#dutch_white/2"},{"type":"function","title":"Fledex.Color.Names.ebony/1","doc":"Defines the color rgb(84, 91, 79).","ref":"Fledex.Color.Names.html#ebony/1"},{"type":"function","title":"Fledex.Color.Names.ebony/2","doc":"","ref":"Fledex.Color.Names.html#ebony/2"},{"type":"function","title":"Fledex.Color.Names.ecru/1","doc":"Defines the color rgb(193, 178, 127).","ref":"Fledex.Color.Names.html#ecru/1"},{"type":"function","title":"Fledex.Color.Names.ecru/2","doc":"","ref":"Fledex.Color.Names.html#ecru/2"},{"type":"function","title":"Fledex.Color.Names.eerie_black/1","doc":"Defines the color rgb(28, 28, 28).","ref":"Fledex.Color.Names.html#eerie_black/1"},{"type":"function","title":"Fledex.Color.Names.eerie_black/2","doc":"","ref":"Fledex.Color.Names.html#eerie_black/2"},{"type":"function","title":"Fledex.Color.Names.eggplant/1","doc":"Defines the color rgb(96, 63, 81).","ref":"Fledex.Color.Names.html#eggplant/1"},{"type":"function","title":"Fledex.Color.Names.eggplant/2","doc":"","ref":"Fledex.Color.Names.html#eggplant/2"},{"type":"function","title":"Fledex.Color.Names.eggshell/1","doc":"Defines the color rgb(239, 234, 214).","ref":"Fledex.Color.Names.html#eggshell/1"},{"type":"function","title":"Fledex.Color.Names.eggshell/2","doc":"","ref":"Fledex.Color.Names.html#eggshell/2"},{"type":"function","title":"Fledex.Color.Names.electric_lime/1","doc":"Defines the color rgb(204, 255, 0).","ref":"Fledex.Color.Names.html#electric_lime/1"},{"type":"function","title":"Fledex.Color.Names.electric_lime/2","doc":"","ref":"Fledex.Color.Names.html#electric_lime/2"},{"type":"function","title":"Fledex.Color.Names.electric_purple/1","doc":"Defines the color rgb(191, 0, 255).","ref":"Fledex.Color.Names.html#electric_purple/1"},{"type":"function","title":"Fledex.Color.Names.electric_purple/2","doc":"","ref":"Fledex.Color.Names.html#electric_purple/2"},{"type":"function","title":"Fledex.Color.Names.electric_violet/1","doc":"Defines the color rgb(142, 0, 255).","ref":"Fledex.Color.Names.html#electric_violet/1"},{"type":"function","title":"Fledex.Color.Names.electric_violet/2","doc":"","ref":"Fledex.Color.Names.html#electric_violet/2"},{"type":"function","title":"Fledex.Color.Names.emerald/1","doc":"Defines the color rgb(79, 198, 119).","ref":"Fledex.Color.Names.html#emerald/1"},{"type":"function","title":"Fledex.Color.Names.emerald/2","doc":"","ref":"Fledex.Color.Names.html#emerald/2"},{"type":"function","title":"Fledex.Color.Names.eminence/1","doc":"Defines the color rgb(107, 48, 130).","ref":"Fledex.Color.Names.html#eminence/1"},{"type":"function","title":"Fledex.Color.Names.eminence/2","doc":"","ref":"Fledex.Color.Names.html#eminence/2"},{"type":"function","title":"Fledex.Color.Names.english_lavender/1","doc":"Defines the color rgb(181, 130, 147).","ref":"Fledex.Color.Names.html#english_lavender/1"},{"type":"function","title":"Fledex.Color.Names.english_lavender/2","doc":"","ref":"Fledex.Color.Names.html#english_lavender/2"},{"type":"function","title":"Fledex.Color.Names.english_red/1","doc":"Defines the color rgb(170, 73, 81).","ref":"Fledex.Color.Names.html#english_red/1"},{"type":"function","title":"Fledex.Color.Names.english_red/2","doc":"","ref":"Fledex.Color.Names.html#english_red/2"},{"type":"function","title":"Fledex.Color.Names.english_vermillion/1","doc":"Defines the color rgb(204, 71, 73).","ref":"Fledex.Color.Names.html#english_vermillion/1"},{"type":"function","title":"Fledex.Color.Names.english_vermillion/2","doc":"","ref":"Fledex.Color.Names.html#english_vermillion/2"},{"type":"function","title":"Fledex.Color.Names.english_violet/1","doc":"Defines the color rgb(86, 61, 91).","ref":"Fledex.Color.Names.html#english_violet/1"},{"type":"function","title":"Fledex.Color.Names.english_violet/2","doc":"","ref":"Fledex.Color.Names.html#english_violet/2"},{"type":"function","title":"Fledex.Color.Names.erin/1","doc":"Defines the color rgb(0, 255, 63).","ref":"Fledex.Color.Names.html#erin/1"},{"type":"function","title":"Fledex.Color.Names.erin/2","doc":"","ref":"Fledex.Color.Names.html#erin/2"},{"type":"function","title":"Fledex.Color.Names.eton_blue/1","doc":"Defines the color rgb(150, 198, 163).","ref":"Fledex.Color.Names.html#eton_blue/1"},{"type":"function","title":"Fledex.Color.Names.eton_blue/2","doc":"","ref":"Fledex.Color.Names.html#eton_blue/2"},{"type":"function","title":"Fledex.Color.Names.fallow/1","doc":"Defines the color rgb(193, 153, 107).","ref":"Fledex.Color.Names.html#fallow/1"},{"type":"function","title":"Fledex.Color.Names.fallow/2","doc":"","ref":"Fledex.Color.Names.html#fallow/2"},{"type":"function","title":"Fledex.Color.Names.falu_red/1","doc":"Defines the color rgb(127, 22, 22).","ref":"Fledex.Color.Names.html#falu_red/1"},{"type":"function","title":"Fledex.Color.Names.falu_red/2","doc":"","ref":"Fledex.Color.Names.html#falu_red/2"},{"type":"function","title":"Fledex.Color.Names.fandango/1","doc":"Defines the color rgb(181, 51, 137).","ref":"Fledex.Color.Names.html#fandango/1"},{"type":"function","title":"Fledex.Color.Names.fandango/2","doc":"","ref":"Fledex.Color.Names.html#fandango/2"},{"type":"function","title":"Fledex.Color.Names.fandango_pink/1","doc":"Defines the color rgb(221, 81, 132).","ref":"Fledex.Color.Names.html#fandango_pink/1"},{"type":"function","title":"Fledex.Color.Names.fandango_pink/2","doc":"","ref":"Fledex.Color.Names.html#fandango_pink/2"},{"type":"function","title":"Fledex.Color.Names.fawn/1","doc":"Defines the color rgb(229, 170, 112).","ref":"Fledex.Color.Names.html#fawn/1"},{"type":"function","title":"Fledex.Color.Names.fawn/2","doc":"","ref":"Fledex.Color.Names.html#fawn/2"},{"type":"function","title":"Fledex.Color.Names.fern_green/1","doc":"Defines the color rgb(79, 119, 66).","ref":"Fledex.Color.Names.html#fern_green/1"},{"type":"function","title":"Fledex.Color.Names.fern_green/2","doc":"","ref":"Fledex.Color.Names.html#fern_green/2"},{"type":"function","title":"Fledex.Color.Names.field_drab/1","doc":"Defines the color rgb(107, 84, 30).","ref":"Fledex.Color.Names.html#field_drab/1"},{"type":"function","title":"Fledex.Color.Names.field_drab/2","doc":"","ref":"Fledex.Color.Names.html#field_drab/2"},{"type":"function","title":"Fledex.Color.Names.fiery_rose/1","doc":"Defines the color rgb(255, 84, 112).","ref":"Fledex.Color.Names.html#fiery_rose/1"},{"type":"function","title":"Fledex.Color.Names.fiery_rose/2","doc":"","ref":"Fledex.Color.Names.html#fiery_rose/2"},{"type":"function","title":"Fledex.Color.Names.finn/1","doc":"Defines the color rgb(104, 48, 104).","ref":"Fledex.Color.Names.html#finn/1"},{"type":"function","title":"Fledex.Color.Names.finn/2","doc":"","ref":"Fledex.Color.Names.html#finn/2"},{"type":"function","title":"Fledex.Color.Names.fire_engine_red/1","doc":"Defines the color rgb(206, 33, 40).","ref":"Fledex.Color.Names.html#fire_engine_red/1"},{"type":"function","title":"Fledex.Color.Names.fire_engine_red/2","doc":"","ref":"Fledex.Color.Names.html#fire_engine_red/2"},{"type":"function","title":"Fledex.Color.Names.firebrick/1","doc":"Defines the color rgb(178, 33, 33).","ref":"Fledex.Color.Names.html#firebrick/1"},{"type":"function","title":"Fledex.Color.Names.firebrick/2","doc":"","ref":"Fledex.Color.Names.html#firebrick/2"},{"type":"function","title":"Fledex.Color.Names.flame/1","doc":"Defines the color rgb(226, 89, 33).","ref":"Fledex.Color.Names.html#flame/1"},{"type":"function","title":"Fledex.Color.Names.flame/2","doc":"","ref":"Fledex.Color.Names.html#flame/2"},{"type":"function","title":"Fledex.Color.Names.flax/1","doc":"Defines the color rgb(237, 219, 130).","ref":"Fledex.Color.Names.html#flax/1"},{"type":"function","title":"Fledex.Color.Names.flax/2","doc":"","ref":"Fledex.Color.Names.html#flax/2"},{"type":"function","title":"Fledex.Color.Names.flirt/1","doc":"Defines the color rgb(163, 0, 109).","ref":"Fledex.Color.Names.html#flirt/1"},{"type":"function","title":"Fledex.Color.Names.flirt/2","doc":"","ref":"Fledex.Color.Names.html#flirt/2"},{"type":"function","title":"Fledex.Color.Names.floral_white/1","doc":"Defines the color rgb(255, 249, 239).","ref":"Fledex.Color.Names.html#floral_white/1"},{"type":"function","title":"Fledex.Color.Names.floral_white/2","doc":"","ref":"Fledex.Color.Names.html#floral_white/2"},{"type":"function","title":"Fledex.Color.Names.forest_green_web/1","doc":"Defines the color rgb(33, 140, 33).","ref":"Fledex.Color.Names.html#forest_green_web/1"},{"type":"function","title":"Fledex.Color.Names.forest_green_web/2","doc":"","ref":"Fledex.Color.Names.html#forest_green_web/2"},{"type":"function","title":"Fledex.Color.Names.french_beige/1","doc":"Defines the color rgb(165, 122, 91).","ref":"Fledex.Color.Names.html#french_beige/1"},{"type":"function","title":"Fledex.Color.Names.french_beige/2","doc":"","ref":"Fledex.Color.Names.html#french_beige/2"},{"type":"function","title":"Fledex.Color.Names.french_bistre/1","doc":"Defines the color rgb(132, 109, 76).","ref":"Fledex.Color.Names.html#french_bistre/1"},{"type":"function","title":"Fledex.Color.Names.french_bistre/2","doc":"","ref":"Fledex.Color.Names.html#french_bistre/2"},{"type":"function","title":"Fledex.Color.Names.french_blue/1","doc":"Defines the color rgb(0, 114, 186).","ref":"Fledex.Color.Names.html#french_blue/1"},{"type":"function","title":"Fledex.Color.Names.french_blue/2","doc":"","ref":"Fledex.Color.Names.html#french_blue/2"},{"type":"function","title":"Fledex.Color.Names.french_fuchsia/1","doc":"Defines the color rgb(252, 63, 145).","ref":"Fledex.Color.Names.html#french_fuchsia/1"},{"type":"function","title":"Fledex.Color.Names.french_fuchsia/2","doc":"","ref":"Fledex.Color.Names.html#french_fuchsia/2"},{"type":"function","title":"Fledex.Color.Names.french_lilac/1","doc":"Defines the color rgb(135, 96, 142).","ref":"Fledex.Color.Names.html#french_lilac/1"},{"type":"function","title":"Fledex.Color.Names.french_lilac/2","doc":"","ref":"Fledex.Color.Names.html#french_lilac/2"},{"type":"function","title":"Fledex.Color.Names.french_lime/1","doc":"Defines the color rgb(158, 252, 56).","ref":"Fledex.Color.Names.html#french_lime/1"},{"type":"function","title":"Fledex.Color.Names.french_lime/2","doc":"","ref":"Fledex.Color.Names.html#french_lime/2"},{"type":"function","title":"Fledex.Color.Names.french_mauve/1","doc":"Defines the color rgb(211, 114, 211).","ref":"Fledex.Color.Names.html#french_mauve/1"},{"type":"function","title":"Fledex.Color.Names.french_mauve/2","doc":"","ref":"Fledex.Color.Names.html#french_mauve/2"},{"type":"function","title":"Fledex.Color.Names.french_pink/1","doc":"Defines the color rgb(252, 107, 158).","ref":"Fledex.Color.Names.html#french_pink/1"},{"type":"function","title":"Fledex.Color.Names.french_pink/2","doc":"","ref":"Fledex.Color.Names.html#french_pink/2"},{"type":"function","title":"Fledex.Color.Names.french_raspberry/1","doc":"Defines the color rgb(198, 43, 71).","ref":"Fledex.Color.Names.html#french_raspberry/1"},{"type":"function","title":"Fledex.Color.Names.french_raspberry/2","doc":"","ref":"Fledex.Color.Names.html#french_raspberry/2"},{"type":"function","title":"Fledex.Color.Names.french_sky_blue/1","doc":"Defines the color rgb(119, 181, 255).","ref":"Fledex.Color.Names.html#french_sky_blue/1"},{"type":"function","title":"Fledex.Color.Names.french_sky_blue/2","doc":"","ref":"Fledex.Color.Names.html#french_sky_blue/2"},{"type":"function","title":"Fledex.Color.Names.french_violet/1","doc":"Defines the color rgb(135, 5, 206).","ref":"Fledex.Color.Names.html#french_violet/1"},{"type":"function","title":"Fledex.Color.Names.french_violet/2","doc":"","ref":"Fledex.Color.Names.html#french_violet/2"},{"type":"function","title":"Fledex.Color.Names.frostbite/1","doc":"Defines the color rgb(232, 53, 165).","ref":"Fledex.Color.Names.html#frostbite/1"},{"type":"function","title":"Fledex.Color.Names.frostbite/2","doc":"","ref":"Fledex.Color.Names.html#frostbite/2"},{"type":"function","title":"Fledex.Color.Names.fuchsia/1","doc":"Defines the color rgb(255, 0, 255).","ref":"Fledex.Color.Names.html#fuchsia/1"},{"type":"function","title":"Fledex.Color.Names.fuchsia/2","doc":"","ref":"Fledex.Color.Names.html#fuchsia/2"},{"type":"function","title":"Fledex.Color.Names.fuchsia_crayola/1","doc":"Defines the color rgb(193, 84, 193).","ref":"Fledex.Color.Names.html#fuchsia_crayola/1"},{"type":"function","title":"Fledex.Color.Names.fuchsia_crayola/2","doc":"","ref":"Fledex.Color.Names.html#fuchsia_crayola/2"},{"type":"function","title":"Fledex.Color.Names.fulvous/1","doc":"Defines the color rgb(226, 132, 0).","ref":"Fledex.Color.Names.html#fulvous/1"},{"type":"function","title":"Fledex.Color.Names.fulvous/2","doc":"","ref":"Fledex.Color.Names.html#fulvous/2"},{"type":"function","title":"Fledex.Color.Names.fuzzy_wuzzy/1","doc":"Defines the color rgb(135, 66, 30).","ref":"Fledex.Color.Names.html#fuzzy_wuzzy/1"},{"type":"function","title":"Fledex.Color.Names.fuzzy_wuzzy/2","doc":"","ref":"Fledex.Color.Names.html#fuzzy_wuzzy/2"},{"type":"function","title":"Fledex.Color.Names.gainsboro/1","doc":"Defines the color rgb(219, 219, 219).","ref":"Fledex.Color.Names.html#gainsboro/1"},{"type":"function","title":"Fledex.Color.Names.gainsboro/2","doc":"","ref":"Fledex.Color.Names.html#gainsboro/2"},{"type":"function","title":"Fledex.Color.Names.gamboge/1","doc":"Defines the color rgb(226, 155, 15).","ref":"Fledex.Color.Names.html#gamboge/1"},{"type":"function","title":"Fledex.Color.Names.gamboge/2","doc":"","ref":"Fledex.Color.Names.html#gamboge/2"},{"type":"function","title":"Fledex.Color.Names.generic_viridian/1","doc":"Defines the color rgb(0, 127, 102).","ref":"Fledex.Color.Names.html#generic_viridian/1"},{"type":"function","title":"Fledex.Color.Names.generic_viridian/2","doc":"","ref":"Fledex.Color.Names.html#generic_viridian/2"},{"type":"function","title":"Fledex.Color.Names.ghost_white/1","doc":"Defines the color rgb(247, 247, 255).","ref":"Fledex.Color.Names.html#ghost_white/1"},{"type":"function","title":"Fledex.Color.Names.ghost_white/2","doc":"","ref":"Fledex.Color.Names.html#ghost_white/2"},{"type":"function","title":"Fledex.Color.Names.glaucous/1","doc":"Defines the color rgb(96, 130, 181).","ref":"Fledex.Color.Names.html#glaucous/1"},{"type":"function","title":"Fledex.Color.Names.glaucous/2","doc":"","ref":"Fledex.Color.Names.html#glaucous/2"},{"type":"function","title":"Fledex.Color.Names.glossy_grape/1","doc":"Defines the color rgb(170, 145, 178).","ref":"Fledex.Color.Names.html#glossy_grape/1"},{"type":"function","title":"Fledex.Color.Names.glossy_grape/2","doc":"","ref":"Fledex.Color.Names.html#glossy_grape/2"},{"type":"function","title":"Fledex.Color.Names.go_green/1","doc":"Defines the color rgb(0, 170, 102).","ref":"Fledex.Color.Names.html#go_green/1"},{"type":"function","title":"Fledex.Color.Names.go_green/2","doc":"","ref":"Fledex.Color.Names.html#go_green/2"},{"type":"function","title":"Fledex.Color.Names.gold_crayola/1","doc":"Defines the color rgb(229, 191, 137).","ref":"Fledex.Color.Names.html#gold_crayola/1"},{"type":"function","title":"Fledex.Color.Names.gold_crayola/2","doc":"","ref":"Fledex.Color.Names.html#gold_crayola/2"},{"type":"function","title":"Fledex.Color.Names.gold_fusion/1","doc":"Defines the color rgb(132, 117, 79).","ref":"Fledex.Color.Names.html#gold_fusion/1"},{"type":"function","title":"Fledex.Color.Names.gold_fusion/2","doc":"","ref":"Fledex.Color.Names.html#gold_fusion/2"},{"type":"function","title":"Fledex.Color.Names.gold_metallic/1","doc":"Defines the color rgb(211, 175, 56).","ref":"Fledex.Color.Names.html#gold_metallic/1"},{"type":"function","title":"Fledex.Color.Names.gold_metallic/2","doc":"","ref":"Fledex.Color.Names.html#gold_metallic/2"},{"type":"function","title":"Fledex.Color.Names.gold_web_golden/1","doc":"Defines the color rgb(255, 214, 0).","ref":"Fledex.Color.Names.html#gold_web_golden/1"},{"type":"function","title":"Fledex.Color.Names.gold_web_golden/2","doc":"","ref":"Fledex.Color.Names.html#gold_web_golden/2"},{"type":"function","title":"Fledex.Color.Names.golden_brown/1","doc":"Defines the color rgb(153, 102, 20).","ref":"Fledex.Color.Names.html#golden_brown/1"},{"type":"function","title":"Fledex.Color.Names.golden_brown/2","doc":"","ref":"Fledex.Color.Names.html#golden_brown/2"},{"type":"function","title":"Fledex.Color.Names.golden_poppy/1","doc":"Defines the color rgb(252, 193, 0).","ref":"Fledex.Color.Names.html#golden_poppy/1"},{"type":"function","title":"Fledex.Color.Names.golden_poppy/2","doc":"","ref":"Fledex.Color.Names.html#golden_poppy/2"},{"type":"function","title":"Fledex.Color.Names.golden_yellow/1","doc":"Defines the color rgb(255, 221, 0).","ref":"Fledex.Color.Names.html#golden_yellow/1"},{"type":"function","title":"Fledex.Color.Names.golden_yellow/2","doc":"","ref":"Fledex.Color.Names.html#golden_yellow/2"},{"type":"function","title":"Fledex.Color.Names.goldenrod/1","doc":"Defines the color rgb(216, 165, 33).","ref":"Fledex.Color.Names.html#goldenrod/1"},{"type":"function","title":"Fledex.Color.Names.goldenrod/2","doc":"","ref":"Fledex.Color.Names.html#goldenrod/2"},{"type":"function","title":"Fledex.Color.Names.gotham_green/1","doc":"Defines the color rgb(0, 86, 63).","ref":"Fledex.Color.Names.html#gotham_green/1"},{"type":"function","title":"Fledex.Color.Names.gotham_green/2","doc":"","ref":"Fledex.Color.Names.html#gotham_green/2"},{"type":"function","title":"Fledex.Color.Names.granite_gray/1","doc":"Defines the color rgb(102, 102, 102).","ref":"Fledex.Color.Names.html#granite_gray/1"},{"type":"function","title":"Fledex.Color.Names.granite_gray/2","doc":"","ref":"Fledex.Color.Names.html#granite_gray/2"},{"type":"function","title":"Fledex.Color.Names.granny_smith_apple/1","doc":"Defines the color rgb(168, 226, 160).","ref":"Fledex.Color.Names.html#granny_smith_apple/1"},{"type":"function","title":"Fledex.Color.Names.granny_smith_apple/2","doc":"","ref":"Fledex.Color.Names.html#granny_smith_apple/2"},{"type":"function","title":"Fledex.Color.Names.gray_web/1","doc":"Defines the color rgb(127, 127, 127).","ref":"Fledex.Color.Names.html#gray_web/1"},{"type":"function","title":"Fledex.Color.Names.gray_web/2","doc":"","ref":"Fledex.Color.Names.html#gray_web/2"},{"type":"function","title":"Fledex.Color.Names.gray_x11_gray/1","doc":"Defines the color rgb(191, 191, 191).","ref":"Fledex.Color.Names.html#gray_x11_gray/1"},{"type":"function","title":"Fledex.Color.Names.gray_x11_gray/2","doc":"","ref":"Fledex.Color.Names.html#gray_x11_gray/2"},{"type":"function","title":"Fledex.Color.Names.green/1","doc":"Defines the color rgb(0, 255, 0).","ref":"Fledex.Color.Names.html#green/1"},{"type":"function","title":"Fledex.Color.Names.green/2","doc":"","ref":"Fledex.Color.Names.html#green/2"},{"type":"function","title":"Fledex.Color.Names.green_blue/1","doc":"Defines the color rgb(17, 99, 181).","ref":"Fledex.Color.Names.html#green_blue/1"},{"type":"function","title":"Fledex.Color.Names.green_blue/2","doc":"","ref":"Fledex.Color.Names.html#green_blue/2"},{"type":"function","title":"Fledex.Color.Names.green_crayola/1","doc":"Defines the color rgb(28, 170, 119).","ref":"Fledex.Color.Names.html#green_crayola/1"},{"type":"function","title":"Fledex.Color.Names.green_crayola/2","doc":"","ref":"Fledex.Color.Names.html#green_crayola/2"},{"type":"function","title":"Fledex.Color.Names.green_lizard/1","doc":"Defines the color rgb(165, 244, 51).","ref":"Fledex.Color.Names.html#green_lizard/1"},{"type":"function","title":"Fledex.Color.Names.green_lizard/2","doc":"","ref":"Fledex.Color.Names.html#green_lizard/2"},{"type":"function","title":"Fledex.Color.Names.green_munsell/1","doc":"Defines the color rgb(0, 168, 119).","ref":"Fledex.Color.Names.html#green_munsell/1"},{"type":"function","title":"Fledex.Color.Names.green_munsell/2","doc":"","ref":"Fledex.Color.Names.html#green_munsell/2"},{"type":"function","title":"Fledex.Color.Names.green_ncs/1","doc":"Defines the color rgb(0, 158, 107).","ref":"Fledex.Color.Names.html#green_ncs/1"},{"type":"function","title":"Fledex.Color.Names.green_ncs/2","doc":"","ref":"Fledex.Color.Names.html#green_ncs/2"},{"type":"function","title":"Fledex.Color.Names.green_pantone/1","doc":"Defines the color rgb(0, 173, 66).","ref":"Fledex.Color.Names.html#green_pantone/1"},{"type":"function","title":"Fledex.Color.Names.green_pantone/2","doc":"","ref":"Fledex.Color.Names.html#green_pantone/2"},{"type":"function","title":"Fledex.Color.Names.green_pigment/1","doc":"Defines the color rgb(0, 165, 79).","ref":"Fledex.Color.Names.html#green_pigment/1"},{"type":"function","title":"Fledex.Color.Names.green_pigment/2","doc":"","ref":"Fledex.Color.Names.html#green_pigment/2"},{"type":"function","title":"Fledex.Color.Names.green_sheen/1","doc":"Defines the color rgb(109, 173, 160).","ref":"Fledex.Color.Names.html#green_sheen/1"},{"type":"function","title":"Fledex.Color.Names.green_sheen/2","doc":"","ref":"Fledex.Color.Names.html#green_sheen/2"},{"type":"function","title":"Fledex.Color.Names.green_web/1","doc":"Defines the color rgb(0, 127, 0).","ref":"Fledex.Color.Names.html#green_web/1"},{"type":"function","title":"Fledex.Color.Names.green_web/2","doc":"","ref":"Fledex.Color.Names.html#green_web/2"},{"type":"function","title":"Fledex.Color.Names.gunmetal/1","doc":"Defines the color rgb(40, 51, 56).","ref":"Fledex.Color.Names.html#gunmetal/1"},{"type":"function","title":"Fledex.Color.Names.gunmetal/2","doc":"","ref":"Fledex.Color.Names.html#gunmetal/2"},{"type":"function","title":"Fledex.Color.Names.hansa_yellow/1","doc":"Defines the color rgb(232, 214, 107).","ref":"Fledex.Color.Names.html#hansa_yellow/1"},{"type":"function","title":"Fledex.Color.Names.hansa_yellow/2","doc":"","ref":"Fledex.Color.Names.html#hansa_yellow/2"},{"type":"function","title":"Fledex.Color.Names.harlequin/1","doc":"Defines the color rgb(63, 255, 0).","ref":"Fledex.Color.Names.html#harlequin/1"},{"type":"function","title":"Fledex.Color.Names.harlequin/2","doc":"","ref":"Fledex.Color.Names.html#harlequin/2"},{"type":"function","title":"Fledex.Color.Names.harvest_gold/1","doc":"Defines the color rgb(216, 145, 0).","ref":"Fledex.Color.Names.html#harvest_gold/1"},{"type":"function","title":"Fledex.Color.Names.harvest_gold/2","doc":"","ref":"Fledex.Color.Names.html#harvest_gold/2"},{"type":"function","title":"Fledex.Color.Names.heat_wave/1","doc":"Defines the color rgb(255, 122, 0).","ref":"Fledex.Color.Names.html#heat_wave/1"},{"type":"function","title":"Fledex.Color.Names.heat_wave/2","doc":"","ref":"Fledex.Color.Names.html#heat_wave/2"},{"type":"function","title":"Fledex.Color.Names.heliotrope/1","doc":"Defines the color rgb(221, 114, 255).","ref":"Fledex.Color.Names.html#heliotrope/1"},{"type":"function","title":"Fledex.Color.Names.heliotrope/2","doc":"","ref":"Fledex.Color.Names.html#heliotrope/2"},{"type":"function","title":"Fledex.Color.Names.heliotrope_gray/1","doc":"Defines the color rgb(170, 153, 168).","ref":"Fledex.Color.Names.html#heliotrope_gray/1"},{"type":"function","title":"Fledex.Color.Names.heliotrope_gray/2","doc":"","ref":"Fledex.Color.Names.html#heliotrope_gray/2"},{"type":"function","title":"Fledex.Color.Names.hollywood_cerise/1","doc":"Defines the color rgb(244, 0, 160).","ref":"Fledex.Color.Names.html#hollywood_cerise/1"},{"type":"function","title":"Fledex.Color.Names.hollywood_cerise/2","doc":"","ref":"Fledex.Color.Names.html#hollywood_cerise/2"},{"type":"function","title":"Fledex.Color.Names.honolulu_blue/1","doc":"Defines the color rgb(0, 109, 175).","ref":"Fledex.Color.Names.html#honolulu_blue/1"},{"type":"function","title":"Fledex.Color.Names.honolulu_blue/2","doc":"","ref":"Fledex.Color.Names.html#honolulu_blue/2"},{"type":"function","title":"Fledex.Color.Names.hooker_s_green/1","doc":"Defines the color rgb(73, 119, 107).","ref":"Fledex.Color.Names.html#hooker_s_green/1"},{"type":"function","title":"Fledex.Color.Names.hooker_s_green/2","doc":"","ref":"Fledex.Color.Names.html#hooker_s_green/2"},{"type":"function","title":"Fledex.Color.Names.hot_magenta/1","doc":"Defines the color rgb(255, 28, 206).","ref":"Fledex.Color.Names.html#hot_magenta/1"},{"type":"function","title":"Fledex.Color.Names.hot_magenta/2","doc":"","ref":"Fledex.Color.Names.html#hot_magenta/2"},{"type":"function","title":"Fledex.Color.Names.hot_pink/1","doc":"Defines the color rgb(255, 104, 181).","ref":"Fledex.Color.Names.html#hot_pink/1"},{"type":"function","title":"Fledex.Color.Names.hot_pink/2","doc":"","ref":"Fledex.Color.Names.html#hot_pink/2"},{"type":"function","title":"Fledex.Color.Names.hunter_green/1","doc":"Defines the color rgb(53, 94, 58).","ref":"Fledex.Color.Names.html#hunter_green/1"},{"type":"function","title":"Fledex.Color.Names.hunter_green/2","doc":"","ref":"Fledex.Color.Names.html#hunter_green/2"},{"type":"function","title":"Fledex.Color.Names.iceberg/1","doc":"Defines the color rgb(112, 165, 209).","ref":"Fledex.Color.Names.html#iceberg/1"},{"type":"function","title":"Fledex.Color.Names.iceberg/2","doc":"","ref":"Fledex.Color.Names.html#iceberg/2"},{"type":"function","title":"Fledex.Color.Names.illuminating_emerald/1","doc":"Defines the color rgb(48, 145, 119).","ref":"Fledex.Color.Names.html#illuminating_emerald/1"},{"type":"function","title":"Fledex.Color.Names.illuminating_emerald/2","doc":"","ref":"Fledex.Color.Names.html#illuminating_emerald/2"},{"type":"function","title":"Fledex.Color.Names.imperial_red/1","doc":"Defines the color rgb(237, 40, 56).","ref":"Fledex.Color.Names.html#imperial_red/1"},{"type":"function","title":"Fledex.Color.Names.imperial_red/2","doc":"","ref":"Fledex.Color.Names.html#imperial_red/2"},{"type":"function","title":"Fledex.Color.Names.inchworm/1","doc":"Defines the color rgb(178, 237, 91).","ref":"Fledex.Color.Names.html#inchworm/1"},{"type":"function","title":"Fledex.Color.Names.inchworm/2","doc":"","ref":"Fledex.Color.Names.html#inchworm/2"},{"type":"function","title":"Fledex.Color.Names.independence/1","doc":"Defines the color rgb(76, 81, 109).","ref":"Fledex.Color.Names.html#independence/1"},{"type":"function","title":"Fledex.Color.Names.independence/2","doc":"","ref":"Fledex.Color.Names.html#independence/2"},{"type":"function","title":"Fledex.Color.Names.india_green/1","doc":"Defines the color rgb(17, 135, 7).","ref":"Fledex.Color.Names.html#india_green/1"},{"type":"function","title":"Fledex.Color.Names.india_green/2","doc":"","ref":"Fledex.Color.Names.html#india_green/2"},{"type":"function","title":"Fledex.Color.Names.indian_red/1","doc":"Defines the color rgb(204, 91, 91).","ref":"Fledex.Color.Names.html#indian_red/1"},{"type":"function","title":"Fledex.Color.Names.indian_red/2","doc":"","ref":"Fledex.Color.Names.html#indian_red/2"},{"type":"function","title":"Fledex.Color.Names.indian_yellow/1","doc":"Defines the color rgb(226, 168, 86).","ref":"Fledex.Color.Names.html#indian_yellow/1"},{"type":"function","title":"Fledex.Color.Names.indian_yellow/2","doc":"","ref":"Fledex.Color.Names.html#indian_yellow/2"},{"type":"function","title":"Fledex.Color.Names.indigo/1","doc":"Defines the color rgb(73, 0, 130).","ref":"Fledex.Color.Names.html#indigo/1"},{"type":"function","title":"Fledex.Color.Names.indigo/2","doc":"","ref":"Fledex.Color.Names.html#indigo/2"},{"type":"function","title":"Fledex.Color.Names.indigo_dye/1","doc":"Defines the color rgb(0, 63, 107).","ref":"Fledex.Color.Names.html#indigo_dye/1"},{"type":"function","title":"Fledex.Color.Names.indigo_dye/2","doc":"","ref":"Fledex.Color.Names.html#indigo_dye/2"},{"type":"function","title":"Fledex.Color.Names.info/2","doc":"Retrieve information about the color with the given name","ref":"Fledex.Color.Names.html#info/2"},{"type":"function","title":"Fledex.Color.Names.international_klein_blue/1","doc":"Defines the color rgb(17, 10, 142).","ref":"Fledex.Color.Names.html#international_klein_blue/1"},{"type":"function","title":"Fledex.Color.Names.international_klein_blue/2","doc":"","ref":"Fledex.Color.Names.html#international_klein_blue/2"},{"type":"function","title":"Fledex.Color.Names.international_orange_engineering/1","doc":"Defines the color rgb(186, 22, 12).","ref":"Fledex.Color.Names.html#international_orange_engineering/1"},{"type":"function","title":"Fledex.Color.Names.international_orange_engineering/2","doc":"","ref":"Fledex.Color.Names.html#international_orange_engineering/2"},{"type":"function","title":"Fledex.Color.Names.international_orange_golden_gate_bridge/1","doc":"Defines the color rgb(191, 53, 43).","ref":"Fledex.Color.Names.html#international_orange_golden_gate_bridge/1"},{"type":"function","title":"Fledex.Color.Names.international_orange_golden_gate_bridge/2","doc":"","ref":"Fledex.Color.Names.html#international_orange_golden_gate_bridge/2"},{"type":"function","title":"Fledex.Color.Names.irresistible/1","doc":"Defines the color rgb(178, 68, 107).","ref":"Fledex.Color.Names.html#irresistible/1"},{"type":"function","title":"Fledex.Color.Names.irresistible/2","doc":"","ref":"Fledex.Color.Names.html#irresistible/2"},{"type":"macro","title":"Fledex.Color.Names.is_color_name/1","doc":"","ref":"Fledex.Color.Names.html#is_color_name/1"},{"type":"function","title":"Fledex.Color.Names.isabelline/1","doc":"Defines the color rgb(244, 239, 237).","ref":"Fledex.Color.Names.html#isabelline/1"},{"type":"function","title":"Fledex.Color.Names.isabelline/2","doc":"","ref":"Fledex.Color.Names.html#isabelline/2"},{"type":"function","title":"Fledex.Color.Names.italian_sky_blue/1","doc":"Defines the color rgb(178, 255, 255).","ref":"Fledex.Color.Names.html#italian_sky_blue/1"},{"type":"function","title":"Fledex.Color.Names.italian_sky_blue/2","doc":"","ref":"Fledex.Color.Names.html#italian_sky_blue/2"},{"type":"function","title":"Fledex.Color.Names.ivory/1","doc":"Defines the color rgb(255, 255, 239).","ref":"Fledex.Color.Names.html#ivory/1"},{"type":"function","title":"Fledex.Color.Names.ivory/2","doc":"","ref":"Fledex.Color.Names.html#ivory/2"},{"type":"function","title":"Fledex.Color.Names.japanese_carmine/1","doc":"Defines the color rgb(158, 40, 51).","ref":"Fledex.Color.Names.html#japanese_carmine/1"},{"type":"function","title":"Fledex.Color.Names.japanese_carmine/2","doc":"","ref":"Fledex.Color.Names.html#japanese_carmine/2"},{"type":"function","title":"Fledex.Color.Names.japanese_violet/1","doc":"Defines the color rgb(91, 51, 86).","ref":"Fledex.Color.Names.html#japanese_violet/1"},{"type":"function","title":"Fledex.Color.Names.japanese_violet/2","doc":"","ref":"Fledex.Color.Names.html#japanese_violet/2"},{"type":"function","title":"Fledex.Color.Names.jasmine/1","doc":"Defines the color rgb(247, 221, 124).","ref":"Fledex.Color.Names.html#jasmine/1"},{"type":"function","title":"Fledex.Color.Names.jasmine/2","doc":"","ref":"Fledex.Color.Names.html#jasmine/2"},{"type":"function","title":"Fledex.Color.Names.jazzberry_jam/1","doc":"Defines the color rgb(165, 10, 94).","ref":"Fledex.Color.Names.html#jazzberry_jam/1"},{"type":"function","title":"Fledex.Color.Names.jazzberry_jam/2","doc":"","ref":"Fledex.Color.Names.html#jazzberry_jam/2"},{"type":"function","title":"Fledex.Color.Names.jet/1","doc":"Defines the color rgb(51, 51, 51).","ref":"Fledex.Color.Names.html#jet/1"},{"type":"function","title":"Fledex.Color.Names.jet/2","doc":"","ref":"Fledex.Color.Names.html#jet/2"},{"type":"function","title":"Fledex.Color.Names.jonquil/1","doc":"Defines the color rgb(244, 201, 22).","ref":"Fledex.Color.Names.html#jonquil/1"},{"type":"function","title":"Fledex.Color.Names.jonquil/2","doc":"","ref":"Fledex.Color.Names.html#jonquil/2"},{"type":"function","title":"Fledex.Color.Names.june_bud/1","doc":"Defines the color rgb(188, 216, 86).","ref":"Fledex.Color.Names.html#june_bud/1"},{"type":"function","title":"Fledex.Color.Names.june_bud/2","doc":"","ref":"Fledex.Color.Names.html#june_bud/2"},{"type":"function","title":"Fledex.Color.Names.jungle_green/1","doc":"Defines the color rgb(40, 170, 135).","ref":"Fledex.Color.Names.html#jungle_green/1"},{"type":"function","title":"Fledex.Color.Names.jungle_green/2","doc":"","ref":"Fledex.Color.Names.html#jungle_green/2"},{"type":"function","title":"Fledex.Color.Names.kelly_green/1","doc":"Defines the color rgb(76, 186, 22).","ref":"Fledex.Color.Names.html#kelly_green/1"},{"type":"function","title":"Fledex.Color.Names.kelly_green/2","doc":"","ref":"Fledex.Color.Names.html#kelly_green/2"},{"type":"function","title":"Fledex.Color.Names.keppel/1","doc":"Defines the color rgb(58, 175, 158).","ref":"Fledex.Color.Names.html#keppel/1"},{"type":"function","title":"Fledex.Color.Names.keppel/2","doc":"","ref":"Fledex.Color.Names.html#keppel/2"},{"type":"function","title":"Fledex.Color.Names.key_lime/1","doc":"Defines the color rgb(232, 244, 140).","ref":"Fledex.Color.Names.html#key_lime/1"},{"type":"function","title":"Fledex.Color.Names.key_lime/2","doc":"","ref":"Fledex.Color.Names.html#key_lime/2"},{"type":"function","title":"Fledex.Color.Names.khaki_web/1","doc":"Defines the color rgb(193, 175, 145).","ref":"Fledex.Color.Names.html#khaki_web/1"},{"type":"function","title":"Fledex.Color.Names.khaki_web/2","doc":"","ref":"Fledex.Color.Names.html#khaki_web/2"},{"type":"function","title":"Fledex.Color.Names.khaki_x11_light_khaki/1","doc":"Defines the color rgb(239, 229, 140).","ref":"Fledex.Color.Names.html#khaki_x11_light_khaki/1"},{"type":"function","title":"Fledex.Color.Names.khaki_x11_light_khaki/2","doc":"","ref":"Fledex.Color.Names.html#khaki_x11_light_khaki/2"},{"type":"function","title":"Fledex.Color.Names.kobe/1","doc":"Defines the color rgb(135, 45, 22).","ref":"Fledex.Color.Names.html#kobe/1"},{"type":"function","title":"Fledex.Color.Names.kobe/2","doc":"","ref":"Fledex.Color.Names.html#kobe/2"},{"type":"function","title":"Fledex.Color.Names.kobi/1","doc":"Defines the color rgb(232, 158, 196).","ref":"Fledex.Color.Names.html#kobi/1"},{"type":"function","title":"Fledex.Color.Names.kobi/2","doc":"","ref":"Fledex.Color.Names.html#kobi/2"},{"type":"function","title":"Fledex.Color.Names.kobicha/1","doc":"Defines the color rgb(107, 68, 35).","ref":"Fledex.Color.Names.html#kobicha/1"},{"type":"function","title":"Fledex.Color.Names.kobicha/2","doc":"","ref":"Fledex.Color.Names.html#kobicha/2"},{"type":"function","title":"Fledex.Color.Names.ksu_purple/1","doc":"Defines the color rgb(79, 38, 130).","ref":"Fledex.Color.Names.html#ksu_purple/1"},{"type":"function","title":"Fledex.Color.Names.ksu_purple/2","doc":"","ref":"Fledex.Color.Names.html#ksu_purple/2"},{"type":"function","title":"Fledex.Color.Names.languid_lavender/1","doc":"Defines the color rgb(214, 201, 221).","ref":"Fledex.Color.Names.html#languid_lavender/1"},{"type":"function","title":"Fledex.Color.Names.languid_lavender/2","doc":"","ref":"Fledex.Color.Names.html#languid_lavender/2"},{"type":"function","title":"Fledex.Color.Names.lapis_lazuli/1","doc":"Defines the color rgb(38, 96, 155).","ref":"Fledex.Color.Names.html#lapis_lazuli/1"},{"type":"function","title":"Fledex.Color.Names.lapis_lazuli/2","doc":"","ref":"Fledex.Color.Names.html#lapis_lazuli/2"},{"type":"function","title":"Fledex.Color.Names.laser_lemon/1","doc":"Defines the color rgb(255, 255, 102).","ref":"Fledex.Color.Names.html#laser_lemon/1"},{"type":"function","title":"Fledex.Color.Names.laser_lemon/2","doc":"","ref":"Fledex.Color.Names.html#laser_lemon/2"},{"type":"function","title":"Fledex.Color.Names.laurel_green/1","doc":"Defines the color rgb(168, 186, 158).","ref":"Fledex.Color.Names.html#laurel_green/1"},{"type":"function","title":"Fledex.Color.Names.laurel_green/2","doc":"","ref":"Fledex.Color.Names.html#laurel_green/2"},{"type":"function","title":"Fledex.Color.Names.lava/1","doc":"Defines the color rgb(206, 15, 33).","ref":"Fledex.Color.Names.html#lava/1"},{"type":"function","title":"Fledex.Color.Names.lava/2","doc":"","ref":"Fledex.Color.Names.html#lava/2"},{"type":"function","title":"Fledex.Color.Names.lavender_blue/1","doc":"Defines the color rgb(204, 204, 255).","ref":"Fledex.Color.Names.html#lavender_blue/1"},{"type":"function","title":"Fledex.Color.Names.lavender_blue/2","doc":"","ref":"Fledex.Color.Names.html#lavender_blue/2"},{"type":"function","title":"Fledex.Color.Names.lavender_blush/1","doc":"Defines the color rgb(255, 239, 244).","ref":"Fledex.Color.Names.html#lavender_blush/1"},{"type":"function","title":"Fledex.Color.Names.lavender_blush/2","doc":"","ref":"Fledex.Color.Names.html#lavender_blush/2"},{"type":"function","title":"Fledex.Color.Names.lavender_floral/1","doc":"Defines the color rgb(181, 124, 219).","ref":"Fledex.Color.Names.html#lavender_floral/1"},{"type":"function","title":"Fledex.Color.Names.lavender_floral/2","doc":"","ref":"Fledex.Color.Names.html#lavender_floral/2"},{"type":"function","title":"Fledex.Color.Names.lavender_gray/1","doc":"Defines the color rgb(196, 193, 209).","ref":"Fledex.Color.Names.html#lavender_gray/1"},{"type":"function","title":"Fledex.Color.Names.lavender_gray/2","doc":"","ref":"Fledex.Color.Names.html#lavender_gray/2"},{"type":"function","title":"Fledex.Color.Names.lavender_web/1","doc":"Defines the color rgb(229, 229, 249).","ref":"Fledex.Color.Names.html#lavender_web/1"},{"type":"function","title":"Fledex.Color.Names.lavender_web/2","doc":"","ref":"Fledex.Color.Names.html#lavender_web/2"},{"type":"function","title":"Fledex.Color.Names.lawn_green/1","doc":"Defines the color rgb(124, 252, 0).","ref":"Fledex.Color.Names.html#lawn_green/1"},{"type":"function","title":"Fledex.Color.Names.lawn_green/2","doc":"","ref":"Fledex.Color.Names.html#lawn_green/2"},{"type":"function","title":"Fledex.Color.Names.lemon/1","doc":"Defines the color rgb(255, 247, 0).","ref":"Fledex.Color.Names.html#lemon/1"},{"type":"function","title":"Fledex.Color.Names.lemon/2","doc":"","ref":"Fledex.Color.Names.html#lemon/2"},{"type":"function","title":"Fledex.Color.Names.lemon_chiffon/1","doc":"Defines the color rgb(255, 249, 204).","ref":"Fledex.Color.Names.html#lemon_chiffon/1"},{"type":"function","title":"Fledex.Color.Names.lemon_chiffon/2","doc":"","ref":"Fledex.Color.Names.html#lemon_chiffon/2"},{"type":"function","title":"Fledex.Color.Names.lemon_curry/1","doc":"Defines the color rgb(204, 160, 28).","ref":"Fledex.Color.Names.html#lemon_curry/1"},{"type":"function","title":"Fledex.Color.Names.lemon_curry/2","doc":"","ref":"Fledex.Color.Names.html#lemon_curry/2"},{"type":"function","title":"Fledex.Color.Names.lemon_glacier/1","doc":"Defines the color rgb(252, 255, 0).","ref":"Fledex.Color.Names.html#lemon_glacier/1"},{"type":"function","title":"Fledex.Color.Names.lemon_glacier/2","doc":"","ref":"Fledex.Color.Names.html#lemon_glacier/2"},{"type":"function","title":"Fledex.Color.Names.lemon_meringue/1","doc":"Defines the color rgb(244, 234, 191).","ref":"Fledex.Color.Names.html#lemon_meringue/1"},{"type":"function","title":"Fledex.Color.Names.lemon_meringue/2","doc":"","ref":"Fledex.Color.Names.html#lemon_meringue/2"},{"type":"function","title":"Fledex.Color.Names.lemon_yellow/1","doc":"Defines the color rgb(255, 244, 79).","ref":"Fledex.Color.Names.html#lemon_yellow/1"},{"type":"function","title":"Fledex.Color.Names.lemon_yellow/2","doc":"","ref":"Fledex.Color.Names.html#lemon_yellow/2"},{"type":"function","title":"Fledex.Color.Names.lemon_yellow_crayola/1","doc":"Defines the color rgb(255, 255, 158).","ref":"Fledex.Color.Names.html#lemon_yellow_crayola/1"},{"type":"function","title":"Fledex.Color.Names.lemon_yellow_crayola/2","doc":"","ref":"Fledex.Color.Names.html#lemon_yellow_crayola/2"},{"type":"function","title":"Fledex.Color.Names.liberty/1","doc":"Defines the color rgb(84, 89, 165).","ref":"Fledex.Color.Names.html#liberty/1"},{"type":"function","title":"Fledex.Color.Names.liberty/2","doc":"","ref":"Fledex.Color.Names.html#liberty/2"},{"type":"function","title":"Fledex.Color.Names.light_blue/1","doc":"Defines the color rgb(173, 216, 229).","ref":"Fledex.Color.Names.html#light_blue/1"},{"type":"function","title":"Fledex.Color.Names.light_blue/2","doc":"","ref":"Fledex.Color.Names.html#light_blue/2"},{"type":"function","title":"Fledex.Color.Names.light_coral/1","doc":"Defines the color rgb(239, 127, 127).","ref":"Fledex.Color.Names.html#light_coral/1"},{"type":"function","title":"Fledex.Color.Names.light_coral/2","doc":"","ref":"Fledex.Color.Names.html#light_coral/2"},{"type":"function","title":"Fledex.Color.Names.light_cornflower_blue/1","doc":"Defines the color rgb(147, 204, 234).","ref":"Fledex.Color.Names.html#light_cornflower_blue/1"},{"type":"function","title":"Fledex.Color.Names.light_cornflower_blue/2","doc":"","ref":"Fledex.Color.Names.html#light_cornflower_blue/2"},{"type":"function","title":"Fledex.Color.Names.light_cyan/1","doc":"Defines the color rgb(224, 255, 255).","ref":"Fledex.Color.Names.html#light_cyan/1"},{"type":"function","title":"Fledex.Color.Names.light_cyan/2","doc":"","ref":"Fledex.Color.Names.html#light_cyan/2"},{"type":"function","title":"Fledex.Color.Names.light_french_beige/1","doc":"Defines the color rgb(198, 173, 127).","ref":"Fledex.Color.Names.html#light_french_beige/1"},{"type":"function","title":"Fledex.Color.Names.light_french_beige/2","doc":"","ref":"Fledex.Color.Names.html#light_french_beige/2"},{"type":"function","title":"Fledex.Color.Names.light_goldenrod_yellow/1","doc":"Defines the color rgb(249, 249, 209).","ref":"Fledex.Color.Names.html#light_goldenrod_yellow/1"},{"type":"function","title":"Fledex.Color.Names.light_goldenrod_yellow/2","doc":"","ref":"Fledex.Color.Names.html#light_goldenrod_yellow/2"},{"type":"function","title":"Fledex.Color.Names.light_gray/1","doc":"Defines the color rgb(211, 211, 211).","ref":"Fledex.Color.Names.html#light_gray/1"},{"type":"function","title":"Fledex.Color.Names.light_gray/2","doc":"","ref":"Fledex.Color.Names.html#light_gray/2"},{"type":"function","title":"Fledex.Color.Names.light_green/1","doc":"Defines the color rgb(142, 237, 142).","ref":"Fledex.Color.Names.html#light_green/1"},{"type":"function","title":"Fledex.Color.Names.light_green/2","doc":"","ref":"Fledex.Color.Names.html#light_green/2"},{"type":"function","title":"Fledex.Color.Names.light_orange/1","doc":"Defines the color rgb(255, 216, 175).","ref":"Fledex.Color.Names.html#light_orange/1"},{"type":"function","title":"Fledex.Color.Names.light_orange/2","doc":"","ref":"Fledex.Color.Names.html#light_orange/2"},{"type":"function","title":"Fledex.Color.Names.light_periwinkle/1","doc":"Defines the color rgb(196, 204, 224).","ref":"Fledex.Color.Names.html#light_periwinkle/1"},{"type":"function","title":"Fledex.Color.Names.light_periwinkle/2","doc":"","ref":"Fledex.Color.Names.html#light_periwinkle/2"},{"type":"function","title":"Fledex.Color.Names.light_pink/1","doc":"Defines the color rgb(255, 181, 193).","ref":"Fledex.Color.Names.html#light_pink/1"},{"type":"function","title":"Fledex.Color.Names.light_pink/2","doc":"","ref":"Fledex.Color.Names.html#light_pink/2"},{"type":"function","title":"Fledex.Color.Names.light_salmon/1","doc":"Defines the color rgb(255, 160, 122).","ref":"Fledex.Color.Names.html#light_salmon/1"},{"type":"function","title":"Fledex.Color.Names.light_salmon/2","doc":"","ref":"Fledex.Color.Names.html#light_salmon/2"},{"type":"function","title":"Fledex.Color.Names.light_sea_green/1","doc":"Defines the color rgb(33, 178, 170).","ref":"Fledex.Color.Names.html#light_sea_green/1"},{"type":"function","title":"Fledex.Color.Names.light_sea_green/2","doc":"","ref":"Fledex.Color.Names.html#light_sea_green/2"},{"type":"function","title":"Fledex.Color.Names.light_sky_blue/1","doc":"Defines the color rgb(135, 206, 249).","ref":"Fledex.Color.Names.html#light_sky_blue/1"},{"type":"function","title":"Fledex.Color.Names.light_sky_blue/2","doc":"","ref":"Fledex.Color.Names.html#light_sky_blue/2"},{"type":"function","title":"Fledex.Color.Names.light_slate_gray/1","doc":"Defines the color rgb(119, 135, 153).","ref":"Fledex.Color.Names.html#light_slate_gray/1"},{"type":"function","title":"Fledex.Color.Names.light_slate_gray/2","doc":"","ref":"Fledex.Color.Names.html#light_slate_gray/2"},{"type":"function","title":"Fledex.Color.Names.light_steel_blue/1","doc":"Defines the color rgb(175, 196, 221).","ref":"Fledex.Color.Names.html#light_steel_blue/1"},{"type":"function","title":"Fledex.Color.Names.light_steel_blue/2","doc":"","ref":"Fledex.Color.Names.html#light_steel_blue/2"},{"type":"function","title":"Fledex.Color.Names.light_yellow/1","doc":"Defines the color rgb(255, 255, 224).","ref":"Fledex.Color.Names.html#light_yellow/1"},{"type":"function","title":"Fledex.Color.Names.light_yellow/2","doc":"","ref":"Fledex.Color.Names.html#light_yellow/2"},{"type":"function","title":"Fledex.Color.Names.lilac/1","doc":"Defines the color rgb(198, 163, 198).","ref":"Fledex.Color.Names.html#lilac/1"},{"type":"function","title":"Fledex.Color.Names.lilac/2","doc":"","ref":"Fledex.Color.Names.html#lilac/2"},{"type":"function","title":"Fledex.Color.Names.lilac_luster/1","doc":"Defines the color rgb(173, 153, 170).","ref":"Fledex.Color.Names.html#lilac_luster/1"},{"type":"function","title":"Fledex.Color.Names.lilac_luster/2","doc":"","ref":"Fledex.Color.Names.html#lilac_luster/2"},{"type":"function","title":"Fledex.Color.Names.lime_color_wheel/1","doc":"Defines the color rgb(191, 255, 0).","ref":"Fledex.Color.Names.html#lime_color_wheel/1"},{"type":"function","title":"Fledex.Color.Names.lime_color_wheel/2","doc":"","ref":"Fledex.Color.Names.html#lime_color_wheel/2"},{"type":"function","title":"Fledex.Color.Names.lime_green/1","doc":"Defines the color rgb(51, 204, 51).","ref":"Fledex.Color.Names.html#lime_green/1"},{"type":"function","title":"Fledex.Color.Names.lime_green/2","doc":"","ref":"Fledex.Color.Names.html#lime_green/2"},{"type":"function","title":"Fledex.Color.Names.lime_web_x11_green/1","doc":"Defines the color rgb(0, 255, 0).","ref":"Fledex.Color.Names.html#lime_web_x11_green/1"},{"type":"function","title":"Fledex.Color.Names.lime_web_x11_green/2","doc":"","ref":"Fledex.Color.Names.html#lime_web_x11_green/2"},{"type":"function","title":"Fledex.Color.Names.lincoln_green/1","doc":"Defines the color rgb(25, 89, 5).","ref":"Fledex.Color.Names.html#lincoln_green/1"},{"type":"function","title":"Fledex.Color.Names.lincoln_green/2","doc":"","ref":"Fledex.Color.Names.html#lincoln_green/2"},{"type":"function","title":"Fledex.Color.Names.linen/1","doc":"Defines the color rgb(249, 239, 229).","ref":"Fledex.Color.Names.html#linen/1"},{"type":"function","title":"Fledex.Color.Names.linen/2","doc":"","ref":"Fledex.Color.Names.html#linen/2"},{"type":"function","title":"Fledex.Color.Names.lion/1","doc":"Defines the color rgb(221, 204, 155).","ref":"Fledex.Color.Names.html#lion/1"},{"type":"function","title":"Fledex.Color.Names.lion/2","doc":"","ref":"Fledex.Color.Names.html#lion/2"},{"type":"function","title":"Fledex.Color.Names.liseran_purple/1","doc":"Defines the color rgb(221, 112, 160).","ref":"Fledex.Color.Names.html#liseran_purple/1"},{"type":"function","title":"Fledex.Color.Names.liseran_purple/2","doc":"","ref":"Fledex.Color.Names.html#liseran_purple/2"},{"type":"function","title":"Fledex.Color.Names.little_boy_blue/1","doc":"Defines the color rgb(107, 160, 219).","ref":"Fledex.Color.Names.html#little_boy_blue/1"},{"type":"function","title":"Fledex.Color.Names.little_boy_blue/2","doc":"","ref":"Fledex.Color.Names.html#little_boy_blue/2"},{"type":"function","title":"Fledex.Color.Names.liver/1","doc":"Defines the color rgb(102, 76, 71).","ref":"Fledex.Color.Names.html#liver/1"},{"type":"function","title":"Fledex.Color.Names.liver/2","doc":"","ref":"Fledex.Color.Names.html#liver/2"},{"type":"function","title":"Fledex.Color.Names.liver_chestnut/1","doc":"Defines the color rgb(153, 114, 86).","ref":"Fledex.Color.Names.html#liver_chestnut/1"},{"type":"function","title":"Fledex.Color.Names.liver_chestnut/2","doc":"","ref":"Fledex.Color.Names.html#liver_chestnut/2"},{"type":"function","title":"Fledex.Color.Names.liver_dogs/1","doc":"Defines the color rgb(183, 109, 40).","ref":"Fledex.Color.Names.html#liver_dogs/1"},{"type":"function","title":"Fledex.Color.Names.liver_dogs/2","doc":"","ref":"Fledex.Color.Names.html#liver_dogs/2"},{"type":"function","title":"Fledex.Color.Names.liver_organ/1","doc":"Defines the color rgb(107, 45, 30).","ref":"Fledex.Color.Names.html#liver_organ/1"},{"type":"function","title":"Fledex.Color.Names.liver_organ/2","doc":"","ref":"Fledex.Color.Names.html#liver_organ/2"},{"type":"function","title":"Fledex.Color.Names.livid/1","doc":"Defines the color rgb(102, 153, 204).","ref":"Fledex.Color.Names.html#livid/1"},{"type":"function","title":"Fledex.Color.Names.livid/2","doc":"","ref":"Fledex.Color.Names.html#livid/2"},{"type":"function","title":"Fledex.Color.Names.macaroni_and_cheese/1","doc":"Defines the color rgb(255, 188, 135).","ref":"Fledex.Color.Names.html#macaroni_and_cheese/1"},{"type":"function","title":"Fledex.Color.Names.macaroni_and_cheese/2","doc":"","ref":"Fledex.Color.Names.html#macaroni_and_cheese/2"},{"type":"function","title":"Fledex.Color.Names.madder_lake/1","doc":"Defines the color rgb(204, 51, 53).","ref":"Fledex.Color.Names.html#madder_lake/1"},{"type":"function","title":"Fledex.Color.Names.madder_lake/2","doc":"","ref":"Fledex.Color.Names.html#madder_lake/2"},{"type":"function","title":"Fledex.Color.Names.magenta/1","doc":"Defines the color rgb(255, 0, 255).","ref":"Fledex.Color.Names.html#magenta/1"},{"type":"function","title":"Fledex.Color.Names.magenta/2","doc":"","ref":"Fledex.Color.Names.html#magenta/2"},{"type":"function","title":"Fledex.Color.Names.magenta_crayola/1","doc":"Defines the color rgb(244, 84, 165).","ref":"Fledex.Color.Names.html#magenta_crayola/1"},{"type":"function","title":"Fledex.Color.Names.magenta_crayola/2","doc":"","ref":"Fledex.Color.Names.html#magenta_crayola/2"},{"type":"function","title":"Fledex.Color.Names.magenta_dye/1","doc":"Defines the color rgb(201, 30, 122).","ref":"Fledex.Color.Names.html#magenta_dye/1"},{"type":"function","title":"Fledex.Color.Names.magenta_dye/2","doc":"","ref":"Fledex.Color.Names.html#magenta_dye/2"},{"type":"function","title":"Fledex.Color.Names.magenta_haze/1","doc":"Defines the color rgb(158, 68, 117).","ref":"Fledex.Color.Names.html#magenta_haze/1"},{"type":"function","title":"Fledex.Color.Names.magenta_haze/2","doc":"","ref":"Fledex.Color.Names.html#magenta_haze/2"},{"type":"function","title":"Fledex.Color.Names.magenta_pantone/1","doc":"Defines the color rgb(209, 63, 124).","ref":"Fledex.Color.Names.html#magenta_pantone/1"},{"type":"function","title":"Fledex.Color.Names.magenta_pantone/2","doc":"","ref":"Fledex.Color.Names.html#magenta_pantone/2"},{"type":"function","title":"Fledex.Color.Names.magenta_process/1","doc":"Defines the color rgb(255, 0, 142).","ref":"Fledex.Color.Names.html#magenta_process/1"},{"type":"function","title":"Fledex.Color.Names.magenta_process/2","doc":"","ref":"Fledex.Color.Names.html#magenta_process/2"},{"type":"function","title":"Fledex.Color.Names.magic_mint/1","doc":"Defines the color rgb(170, 239, 209).","ref":"Fledex.Color.Names.html#magic_mint/1"},{"type":"function","title":"Fledex.Color.Names.magic_mint/2","doc":"","ref":"Fledex.Color.Names.html#magic_mint/2"},{"type":"function","title":"Fledex.Color.Names.magnolia/1","doc":"Defines the color rgb(242, 232, 214).","ref":"Fledex.Color.Names.html#magnolia/1"},{"type":"function","title":"Fledex.Color.Names.magnolia/2","doc":"","ref":"Fledex.Color.Names.html#magnolia/2"},{"type":"function","title":"Fledex.Color.Names.mahogany/1","doc":"Defines the color rgb(191, 63, 0).","ref":"Fledex.Color.Names.html#mahogany/1"},{"type":"function","title":"Fledex.Color.Names.mahogany/2","doc":"","ref":"Fledex.Color.Names.html#mahogany/2"},{"type":"function","title":"Fledex.Color.Names.maize/1","doc":"Defines the color rgb(249, 237, 91).","ref":"Fledex.Color.Names.html#maize/1"},{"type":"function","title":"Fledex.Color.Names.maize/2","doc":"","ref":"Fledex.Color.Names.html#maize/2"},{"type":"function","title":"Fledex.Color.Names.maize_crayola/1","doc":"Defines the color rgb(242, 198, 73).","ref":"Fledex.Color.Names.html#maize_crayola/1"},{"type":"function","title":"Fledex.Color.Names.maize_crayola/2","doc":"","ref":"Fledex.Color.Names.html#maize_crayola/2"},{"type":"function","title":"Fledex.Color.Names.majorelle_blue/1","doc":"Defines the color rgb(96, 79, 219).","ref":"Fledex.Color.Names.html#majorelle_blue/1"},{"type":"function","title":"Fledex.Color.Names.majorelle_blue/2","doc":"","ref":"Fledex.Color.Names.html#majorelle_blue/2"},{"type":"function","title":"Fledex.Color.Names.malachite/1","doc":"Defines the color rgb(10, 216, 81).","ref":"Fledex.Color.Names.html#malachite/1"},{"type":"function","title":"Fledex.Color.Names.malachite/2","doc":"","ref":"Fledex.Color.Names.html#malachite/2"},{"type":"function","title":"Fledex.Color.Names.manatee/1","doc":"Defines the color rgb(150, 153, 170).","ref":"Fledex.Color.Names.html#manatee/1"},{"type":"function","title":"Fledex.Color.Names.manatee/2","doc":"","ref":"Fledex.Color.Names.html#manatee/2"},{"type":"function","title":"Fledex.Color.Names.mandarin/1","doc":"Defines the color rgb(242, 122, 71).","ref":"Fledex.Color.Names.html#mandarin/1"},{"type":"function","title":"Fledex.Color.Names.mandarin/2","doc":"","ref":"Fledex.Color.Names.html#mandarin/2"},{"type":"function","title":"Fledex.Color.Names.mango/1","doc":"Defines the color rgb(252, 191, 2).","ref":"Fledex.Color.Names.html#mango/1"},{"type":"function","title":"Fledex.Color.Names.mango/2","doc":"","ref":"Fledex.Color.Names.html#mango/2"},{"type":"function","title":"Fledex.Color.Names.mango_tango/1","doc":"Defines the color rgb(255, 130, 66).","ref":"Fledex.Color.Names.html#mango_tango/1"},{"type":"function","title":"Fledex.Color.Names.mango_tango/2","doc":"","ref":"Fledex.Color.Names.html#mango_tango/2"},{"type":"function","title":"Fledex.Color.Names.mantis/1","doc":"Defines the color rgb(114, 193, 102).","ref":"Fledex.Color.Names.html#mantis/1"},{"type":"function","title":"Fledex.Color.Names.mantis/2","doc":"","ref":"Fledex.Color.Names.html#mantis/2"},{"type":"function","title":"Fledex.Color.Names.mardi_gras/1","doc":"Defines the color rgb(135, 0, 132).","ref":"Fledex.Color.Names.html#mardi_gras/1"},{"type":"function","title":"Fledex.Color.Names.mardi_gras/2","doc":"","ref":"Fledex.Color.Names.html#mardi_gras/2"},{"type":"function","title":"Fledex.Color.Names.marigold/1","doc":"Defines the color rgb(234, 163, 33).","ref":"Fledex.Color.Names.html#marigold/1"},{"type":"function","title":"Fledex.Color.Names.marigold/2","doc":"","ref":"Fledex.Color.Names.html#marigold/2"},{"type":"function","title":"Fledex.Color.Names.maroon_crayola/1","doc":"Defines the color rgb(193, 33, 71).","ref":"Fledex.Color.Names.html#maroon_crayola/1"},{"type":"function","title":"Fledex.Color.Names.maroon_crayola/2","doc":"","ref":"Fledex.Color.Names.html#maroon_crayola/2"},{"type":"function","title":"Fledex.Color.Names.maroon_web/1","doc":"Defines the color rgb(127, 0, 0).","ref":"Fledex.Color.Names.html#maroon_web/1"},{"type":"function","title":"Fledex.Color.Names.maroon_web/2","doc":"","ref":"Fledex.Color.Names.html#maroon_web/2"},{"type":"function","title":"Fledex.Color.Names.maroon_x11/1","doc":"Defines the color rgb(175, 48, 96).","ref":"Fledex.Color.Names.html#maroon_x11/1"},{"type":"function","title":"Fledex.Color.Names.maroon_x11/2","doc":"","ref":"Fledex.Color.Names.html#maroon_x11/2"},{"type":"function","title":"Fledex.Color.Names.mauve/1","doc":"Defines the color rgb(224, 175, 255).","ref":"Fledex.Color.Names.html#mauve/1"},{"type":"function","title":"Fledex.Color.Names.mauve/2","doc":"","ref":"Fledex.Color.Names.html#mauve/2"},{"type":"function","title":"Fledex.Color.Names.mauve_taupe/1","doc":"Defines the color rgb(145, 94, 109).","ref":"Fledex.Color.Names.html#mauve_taupe/1"},{"type":"function","title":"Fledex.Color.Names.mauve_taupe/2","doc":"","ref":"Fledex.Color.Names.html#mauve_taupe/2"},{"type":"function","title":"Fledex.Color.Names.mauvelous/1","doc":"Defines the color rgb(239, 153, 170).","ref":"Fledex.Color.Names.html#mauvelous/1"},{"type":"function","title":"Fledex.Color.Names.mauvelous/2","doc":"","ref":"Fledex.Color.Names.html#mauvelous/2"},{"type":"function","title":"Fledex.Color.Names.maximum_blue/1","doc":"Defines the color rgb(71, 170, 204).","ref":"Fledex.Color.Names.html#maximum_blue/1"},{"type":"function","title":"Fledex.Color.Names.maximum_blue/2","doc":"","ref":"Fledex.Color.Names.html#maximum_blue/2"},{"type":"function","title":"Fledex.Color.Names.maximum_blue_green/1","doc":"Defines the color rgb(48, 191, 191).","ref":"Fledex.Color.Names.html#maximum_blue_green/1"},{"type":"function","title":"Fledex.Color.Names.maximum_blue_green/2","doc":"","ref":"Fledex.Color.Names.html#maximum_blue_green/2"},{"type":"function","title":"Fledex.Color.Names.maximum_blue_purple/1","doc":"Defines the color rgb(170, 170, 229).","ref":"Fledex.Color.Names.html#maximum_blue_purple/1"},{"type":"function","title":"Fledex.Color.Names.maximum_blue_purple/2","doc":"","ref":"Fledex.Color.Names.html#maximum_blue_purple/2"},{"type":"function","title":"Fledex.Color.Names.maximum_green/1","doc":"Defines the color rgb(94, 140, 48).","ref":"Fledex.Color.Names.html#maximum_green/1"},{"type":"function","title":"Fledex.Color.Names.maximum_green/2","doc":"","ref":"Fledex.Color.Names.html#maximum_green/2"},{"type":"function","title":"Fledex.Color.Names.maximum_green_yellow/1","doc":"Defines the color rgb(216, 229, 79).","ref":"Fledex.Color.Names.html#maximum_green_yellow/1"},{"type":"function","title":"Fledex.Color.Names.maximum_green_yellow/2","doc":"","ref":"Fledex.Color.Names.html#maximum_green_yellow/2"},{"type":"function","title":"Fledex.Color.Names.maximum_purple/1","doc":"Defines the color rgb(114, 51, 127).","ref":"Fledex.Color.Names.html#maximum_purple/1"},{"type":"function","title":"Fledex.Color.Names.maximum_purple/2","doc":"","ref":"Fledex.Color.Names.html#maximum_purple/2"},{"type":"function","title":"Fledex.Color.Names.maximum_red/1","doc":"Defines the color rgb(216, 33, 33).","ref":"Fledex.Color.Names.html#maximum_red/1"},{"type":"function","title":"Fledex.Color.Names.maximum_red/2","doc":"","ref":"Fledex.Color.Names.html#maximum_red/2"},{"type":"function","title":"Fledex.Color.Names.maximum_red_purple/1","doc":"Defines the color rgb(165, 58, 119).","ref":"Fledex.Color.Names.html#maximum_red_purple/1"},{"type":"function","title":"Fledex.Color.Names.maximum_red_purple/2","doc":"","ref":"Fledex.Color.Names.html#maximum_red_purple/2"},{"type":"function","title":"Fledex.Color.Names.maximum_yellow/1","doc":"Defines the color rgb(249, 249, 56).","ref":"Fledex.Color.Names.html#maximum_yellow/1"},{"type":"function","title":"Fledex.Color.Names.maximum_yellow/2","doc":"","ref":"Fledex.Color.Names.html#maximum_yellow/2"},{"type":"function","title":"Fledex.Color.Names.maximum_yellow_red/1","doc":"Defines the color rgb(242, 186, 73).","ref":"Fledex.Color.Names.html#maximum_yellow_red/1"},{"type":"function","title":"Fledex.Color.Names.maximum_yellow_red/2","doc":"","ref":"Fledex.Color.Names.html#maximum_yellow_red/2"},{"type":"function","title":"Fledex.Color.Names.may_green/1","doc":"Defines the color rgb(76, 145, 63).","ref":"Fledex.Color.Names.html#may_green/1"},{"type":"function","title":"Fledex.Color.Names.may_green/2","doc":"","ref":"Fledex.Color.Names.html#may_green/2"},{"type":"function","title":"Fledex.Color.Names.maya_blue/1","doc":"Defines the color rgb(114, 193, 249).","ref":"Fledex.Color.Names.html#maya_blue/1"},{"type":"function","title":"Fledex.Color.Names.maya_blue/2","doc":"","ref":"Fledex.Color.Names.html#maya_blue/2"},{"type":"function","title":"Fledex.Color.Names.medium_aquamarine/1","doc":"Defines the color rgb(102, 221, 170).","ref":"Fledex.Color.Names.html#medium_aquamarine/1"},{"type":"function","title":"Fledex.Color.Names.medium_aquamarine/2","doc":"","ref":"Fledex.Color.Names.html#medium_aquamarine/2"},{"type":"function","title":"Fledex.Color.Names.medium_blue/1","doc":"Defines the color rgb(0, 0, 204).","ref":"Fledex.Color.Names.html#medium_blue/1"},{"type":"function","title":"Fledex.Color.Names.medium_blue/2","doc":"","ref":"Fledex.Color.Names.html#medium_blue/2"},{"type":"function","title":"Fledex.Color.Names.medium_candy_apple_red/1","doc":"Defines the color rgb(226, 5, 43).","ref":"Fledex.Color.Names.html#medium_candy_apple_red/1"},{"type":"function","title":"Fledex.Color.Names.medium_candy_apple_red/2","doc":"","ref":"Fledex.Color.Names.html#medium_candy_apple_red/2"},{"type":"function","title":"Fledex.Color.Names.medium_carmine/1","doc":"Defines the color rgb(175, 63, 53).","ref":"Fledex.Color.Names.html#medium_carmine/1"},{"type":"function","title":"Fledex.Color.Names.medium_carmine/2","doc":"","ref":"Fledex.Color.Names.html#medium_carmine/2"},{"type":"function","title":"Fledex.Color.Names.medium_champagne/1","doc":"Defines the color rgb(242, 229, 170).","ref":"Fledex.Color.Names.html#medium_champagne/1"},{"type":"function","title":"Fledex.Color.Names.medium_champagne/2","doc":"","ref":"Fledex.Color.Names.html#medium_champagne/2"},{"type":"function","title":"Fledex.Color.Names.medium_orchid/1","doc":"Defines the color rgb(186, 84, 211).","ref":"Fledex.Color.Names.html#medium_orchid/1"},{"type":"function","title":"Fledex.Color.Names.medium_orchid/2","doc":"","ref":"Fledex.Color.Names.html#medium_orchid/2"},{"type":"function","title":"Fledex.Color.Names.medium_purple/1","doc":"Defines the color rgb(147, 112, 219).","ref":"Fledex.Color.Names.html#medium_purple/1"},{"type":"function","title":"Fledex.Color.Names.medium_purple/2","doc":"","ref":"Fledex.Color.Names.html#medium_purple/2"},{"type":"function","title":"Fledex.Color.Names.medium_sea_green/1","doc":"Defines the color rgb(61, 178, 112).","ref":"Fledex.Color.Names.html#medium_sea_green/1"},{"type":"function","title":"Fledex.Color.Names.medium_sea_green/2","doc":"","ref":"Fledex.Color.Names.html#medium_sea_green/2"},{"type":"function","title":"Fledex.Color.Names.medium_slate_blue/1","doc":"Defines the color rgb(122, 104, 237).","ref":"Fledex.Color.Names.html#medium_slate_blue/1"},{"type":"function","title":"Fledex.Color.Names.medium_slate_blue/2","doc":"","ref":"Fledex.Color.Names.html#medium_slate_blue/2"},{"type":"function","title":"Fledex.Color.Names.medium_spring_green/1","doc":"Defines the color rgb(0, 249, 153).","ref":"Fledex.Color.Names.html#medium_spring_green/1"},{"type":"function","title":"Fledex.Color.Names.medium_spring_green/2","doc":"","ref":"Fledex.Color.Names.html#medium_spring_green/2"},{"type":"function","title":"Fledex.Color.Names.medium_turquoise/1","doc":"Defines the color rgb(71, 209, 204).","ref":"Fledex.Color.Names.html#medium_turquoise/1"},{"type":"function","title":"Fledex.Color.Names.medium_turquoise/2","doc":"","ref":"Fledex.Color.Names.html#medium_turquoise/2"},{"type":"function","title":"Fledex.Color.Names.medium_violet_red/1","doc":"Defines the color rgb(198, 20, 132).","ref":"Fledex.Color.Names.html#medium_violet_red/1"},{"type":"function","title":"Fledex.Color.Names.medium_violet_red/2","doc":"","ref":"Fledex.Color.Names.html#medium_violet_red/2"},{"type":"function","title":"Fledex.Color.Names.mellow_apricot/1","doc":"Defines the color rgb(247, 183, 119).","ref":"Fledex.Color.Names.html#mellow_apricot/1"},{"type":"function","title":"Fledex.Color.Names.mellow_apricot/2","doc":"","ref":"Fledex.Color.Names.html#mellow_apricot/2"},{"type":"function","title":"Fledex.Color.Names.mellow_yellow/1","doc":"Defines the color rgb(247, 221, 124).","ref":"Fledex.Color.Names.html#mellow_yellow/1"},{"type":"function","title":"Fledex.Color.Names.mellow_yellow/2","doc":"","ref":"Fledex.Color.Names.html#mellow_yellow/2"},{"type":"function","title":"Fledex.Color.Names.melon/1","doc":"Defines the color rgb(255, 186, 173).","ref":"Fledex.Color.Names.html#melon/1"},{"type":"function","title":"Fledex.Color.Names.melon/2","doc":"","ref":"Fledex.Color.Names.html#melon/2"},{"type":"function","title":"Fledex.Color.Names.metallic_gold/1","doc":"Defines the color rgb(211, 175, 56).","ref":"Fledex.Color.Names.html#metallic_gold/1"},{"type":"function","title":"Fledex.Color.Names.metallic_gold/2","doc":"","ref":"Fledex.Color.Names.html#metallic_gold/2"},{"type":"function","title":"Fledex.Color.Names.metallic_seaweed/1","doc":"Defines the color rgb(10, 124, 140).","ref":"Fledex.Color.Names.html#metallic_seaweed/1"},{"type":"function","title":"Fledex.Color.Names.metallic_seaweed/2","doc":"","ref":"Fledex.Color.Names.html#metallic_seaweed/2"},{"type":"function","title":"Fledex.Color.Names.metallic_sunburst/1","doc":"Defines the color rgb(155, 124, 56).","ref":"Fledex.Color.Names.html#metallic_sunburst/1"},{"type":"function","title":"Fledex.Color.Names.metallic_sunburst/2","doc":"","ref":"Fledex.Color.Names.html#metallic_sunburst/2"},{"type":"function","title":"Fledex.Color.Names.mexican_pink/1","doc":"Defines the color rgb(226, 0, 124).","ref":"Fledex.Color.Names.html#mexican_pink/1"},{"type":"function","title":"Fledex.Color.Names.mexican_pink/2","doc":"","ref":"Fledex.Color.Names.html#mexican_pink/2"},{"type":"function","title":"Fledex.Color.Names.middle_blue/1","doc":"Defines the color rgb(124, 211, 229).","ref":"Fledex.Color.Names.html#middle_blue/1"},{"type":"function","title":"Fledex.Color.Names.middle_blue/2","doc":"","ref":"Fledex.Color.Names.html#middle_blue/2"},{"type":"function","title":"Fledex.Color.Names.middle_blue_green/1","doc":"Defines the color rgb(140, 216, 204).","ref":"Fledex.Color.Names.html#middle_blue_green/1"},{"type":"function","title":"Fledex.Color.Names.middle_blue_green/2","doc":"","ref":"Fledex.Color.Names.html#middle_blue_green/2"},{"type":"function","title":"Fledex.Color.Names.middle_blue_purple/1","doc":"Defines the color rgb(140, 114, 191).","ref":"Fledex.Color.Names.html#middle_blue_purple/1"},{"type":"function","title":"Fledex.Color.Names.middle_blue_purple/2","doc":"","ref":"Fledex.Color.Names.html#middle_blue_purple/2"},{"type":"function","title":"Fledex.Color.Names.middle_green/1","doc":"Defines the color rgb(76, 140, 86).","ref":"Fledex.Color.Names.html#middle_green/1"},{"type":"function","title":"Fledex.Color.Names.middle_green/2","doc":"","ref":"Fledex.Color.Names.html#middle_green/2"},{"type":"function","title":"Fledex.Color.Names.middle_green_yellow/1","doc":"Defines the color rgb(170, 191, 96).","ref":"Fledex.Color.Names.html#middle_green_yellow/1"},{"type":"function","title":"Fledex.Color.Names.middle_green_yellow/2","doc":"","ref":"Fledex.Color.Names.html#middle_green_yellow/2"},{"type":"function","title":"Fledex.Color.Names.middle_grey/1","doc":"Defines the color rgb(140, 135, 127).","ref":"Fledex.Color.Names.html#middle_grey/1"},{"type":"function","title":"Fledex.Color.Names.middle_grey/2","doc":"","ref":"Fledex.Color.Names.html#middle_grey/2"},{"type":"function","title":"Fledex.Color.Names.middle_purple/1","doc":"Defines the color rgb(216, 130, 181).","ref":"Fledex.Color.Names.html#middle_purple/1"},{"type":"function","title":"Fledex.Color.Names.middle_purple/2","doc":"","ref":"Fledex.Color.Names.html#middle_purple/2"},{"type":"function","title":"Fledex.Color.Names.middle_red/1","doc":"Defines the color rgb(229, 142, 114).","ref":"Fledex.Color.Names.html#middle_red/1"},{"type":"function","title":"Fledex.Color.Names.middle_red/2","doc":"","ref":"Fledex.Color.Names.html#middle_red/2"},{"type":"function","title":"Fledex.Color.Names.middle_red_purple/1","doc":"Defines the color rgb(165, 84, 84).","ref":"Fledex.Color.Names.html#middle_red_purple/1"},{"type":"function","title":"Fledex.Color.Names.middle_red_purple/2","doc":"","ref":"Fledex.Color.Names.html#middle_red_purple/2"},{"type":"function","title":"Fledex.Color.Names.middle_yellow/1","doc":"Defines the color rgb(255, 234, 0).","ref":"Fledex.Color.Names.html#middle_yellow/1"},{"type":"function","title":"Fledex.Color.Names.middle_yellow/2","doc":"","ref":"Fledex.Color.Names.html#middle_yellow/2"},{"type":"function","title":"Fledex.Color.Names.middle_yellow_red/1","doc":"Defines the color rgb(237, 175, 117).","ref":"Fledex.Color.Names.html#middle_yellow_red/1"},{"type":"function","title":"Fledex.Color.Names.middle_yellow_red/2","doc":"","ref":"Fledex.Color.Names.html#middle_yellow_red/2"},{"type":"function","title":"Fledex.Color.Names.midnight/1","doc":"Defines the color rgb(112, 38, 112).","ref":"Fledex.Color.Names.html#midnight/1"},{"type":"function","title":"Fledex.Color.Names.midnight/2","doc":"","ref":"Fledex.Color.Names.html#midnight/2"},{"type":"function","title":"Fledex.Color.Names.midnight_blue/1","doc":"Defines the color rgb(25, 25, 112).","ref":"Fledex.Color.Names.html#midnight_blue/1"},{"type":"function","title":"Fledex.Color.Names.midnight_blue/2","doc":"","ref":"Fledex.Color.Names.html#midnight_blue/2"},{"type":"function","title":"Fledex.Color.Names.midnight_green_eagle_green/1","doc":"Defines the color rgb(0, 73, 84).","ref":"Fledex.Color.Names.html#midnight_green_eagle_green/1"},{"type":"function","title":"Fledex.Color.Names.midnight_green_eagle_green/2","doc":"","ref":"Fledex.Color.Names.html#midnight_green_eagle_green/2"},{"type":"function","title":"Fledex.Color.Names.mikado_yellow/1","doc":"Defines the color rgb(255, 196, 12).","ref":"Fledex.Color.Names.html#mikado_yellow/1"},{"type":"function","title":"Fledex.Color.Names.mikado_yellow/2","doc":"","ref":"Fledex.Color.Names.html#mikado_yellow/2"},{"type":"function","title":"Fledex.Color.Names.mimi_pink/1","doc":"Defines the color rgb(255, 216, 232).","ref":"Fledex.Color.Names.html#mimi_pink/1"},{"type":"function","title":"Fledex.Color.Names.mimi_pink/2","doc":"","ref":"Fledex.Color.Names.html#mimi_pink/2"},{"type":"function","title":"Fledex.Color.Names.mindaro/1","doc":"Defines the color rgb(226, 249, 135).","ref":"Fledex.Color.Names.html#mindaro/1"},{"type":"function","title":"Fledex.Color.Names.mindaro/2","doc":"","ref":"Fledex.Color.Names.html#mindaro/2"},{"type":"function","title":"Fledex.Color.Names.ming/1","doc":"Defines the color rgb(53, 114, 124).","ref":"Fledex.Color.Names.html#ming/1"},{"type":"function","title":"Fledex.Color.Names.ming/2","doc":"","ref":"Fledex.Color.Names.html#ming/2"},{"type":"function","title":"Fledex.Color.Names.minion_yellow/1","doc":"Defines the color rgb(244, 219, 79).","ref":"Fledex.Color.Names.html#minion_yellow/1"},{"type":"function","title":"Fledex.Color.Names.minion_yellow/2","doc":"","ref":"Fledex.Color.Names.html#minion_yellow/2"},{"type":"function","title":"Fledex.Color.Names.mint/1","doc":"Defines the color rgb(61, 181, 137).","ref":"Fledex.Color.Names.html#mint/1"},{"type":"function","title":"Fledex.Color.Names.mint/2","doc":"","ref":"Fledex.Color.Names.html#mint/2"},{"type":"function","title":"Fledex.Color.Names.mint_cream/1","doc":"Defines the color rgb(244, 255, 249).","ref":"Fledex.Color.Names.html#mint_cream/1"},{"type":"function","title":"Fledex.Color.Names.mint_cream/2","doc":"","ref":"Fledex.Color.Names.html#mint_cream/2"},{"type":"function","title":"Fledex.Color.Names.mint_green/1","doc":"Defines the color rgb(153, 255, 153).","ref":"Fledex.Color.Names.html#mint_green/1"},{"type":"function","title":"Fledex.Color.Names.mint_green/2","doc":"","ref":"Fledex.Color.Names.html#mint_green/2"},{"type":"function","title":"Fledex.Color.Names.misty_moss/1","doc":"Defines the color rgb(186, 181, 119).","ref":"Fledex.Color.Names.html#misty_moss/1"},{"type":"function","title":"Fledex.Color.Names.misty_moss/2","doc":"","ref":"Fledex.Color.Names.html#misty_moss/2"},{"type":"function","title":"Fledex.Color.Names.misty_rose/1","doc":"Defines the color rgb(255, 226, 224).","ref":"Fledex.Color.Names.html#misty_rose/1"},{"type":"function","title":"Fledex.Color.Names.misty_rose/2","doc":"","ref":"Fledex.Color.Names.html#misty_rose/2"},{"type":"function","title":"Fledex.Color.Names.mode_beige/1","doc":"Defines the color rgb(150, 112, 22).","ref":"Fledex.Color.Names.html#mode_beige/1"},{"type":"function","title":"Fledex.Color.Names.mode_beige/2","doc":"","ref":"Fledex.Color.Names.html#mode_beige/2"},{"type":"function","title":"Fledex.Color.Names.mona_lisa/1","doc":"Defines the color rgb(255, 147, 142).","ref":"Fledex.Color.Names.html#mona_lisa/1"},{"type":"function","title":"Fledex.Color.Names.mona_lisa/2","doc":"","ref":"Fledex.Color.Names.html#mona_lisa/2"},{"type":"function","title":"Fledex.Color.Names.morning_blue/1","doc":"Defines the color rgb(140, 163, 153).","ref":"Fledex.Color.Names.html#morning_blue/1"},{"type":"function","title":"Fledex.Color.Names.morning_blue/2","doc":"","ref":"Fledex.Color.Names.html#morning_blue/2"},{"type":"function","title":"Fledex.Color.Names.moss_green/1","doc":"Defines the color rgb(137, 153, 91).","ref":"Fledex.Color.Names.html#moss_green/1"},{"type":"function","title":"Fledex.Color.Names.moss_green/2","doc":"","ref":"Fledex.Color.Names.html#moss_green/2"},{"type":"function","title":"Fledex.Color.Names.mountain_meadow/1","doc":"Defines the color rgb(48, 186, 142).","ref":"Fledex.Color.Names.html#mountain_meadow/1"},{"type":"function","title":"Fledex.Color.Names.mountain_meadow/2","doc":"","ref":"Fledex.Color.Names.html#mountain_meadow/2"},{"type":"function","title":"Fledex.Color.Names.mountbatten_pink/1","doc":"Defines the color rgb(153, 122, 140).","ref":"Fledex.Color.Names.html#mountbatten_pink/1"},{"type":"function","title":"Fledex.Color.Names.mountbatten_pink/2","doc":"","ref":"Fledex.Color.Names.html#mountbatten_pink/2"},{"type":"function","title":"Fledex.Color.Names.msu_green/1","doc":"Defines the color rgb(22, 68, 58).","ref":"Fledex.Color.Names.html#msu_green/1"},{"type":"function","title":"Fledex.Color.Names.msu_green/2","doc":"","ref":"Fledex.Color.Names.html#msu_green/2"},{"type":"function","title":"Fledex.Color.Names.mulberry/1","doc":"Defines the color rgb(196, 73, 140).","ref":"Fledex.Color.Names.html#mulberry/1"},{"type":"function","title":"Fledex.Color.Names.mulberry/2","doc":"","ref":"Fledex.Color.Names.html#mulberry/2"},{"type":"function","title":"Fledex.Color.Names.mulberry_crayola/1","doc":"Defines the color rgb(198, 79, 155).","ref":"Fledex.Color.Names.html#mulberry_crayola/1"},{"type":"function","title":"Fledex.Color.Names.mulberry_crayola/2","doc":"","ref":"Fledex.Color.Names.html#mulberry_crayola/2"},{"type":"function","title":"Fledex.Color.Names.mustard/1","doc":"Defines the color rgb(255, 219, 89).","ref":"Fledex.Color.Names.html#mustard/1"},{"type":"function","title":"Fledex.Color.Names.mustard/2","doc":"","ref":"Fledex.Color.Names.html#mustard/2"},{"type":"function","title":"Fledex.Color.Names.myrtle_green/1","doc":"Defines the color rgb(48, 119, 114).","ref":"Fledex.Color.Names.html#myrtle_green/1"},{"type":"function","title":"Fledex.Color.Names.myrtle_green/2","doc":"","ref":"Fledex.Color.Names.html#myrtle_green/2"},{"type":"function","title":"Fledex.Color.Names.mystic/1","doc":"Defines the color rgb(214, 81, 130).","ref":"Fledex.Color.Names.html#mystic/1"},{"type":"function","title":"Fledex.Color.Names.mystic/2","doc":"","ref":"Fledex.Color.Names.html#mystic/2"},{"type":"function","title":"Fledex.Color.Names.mystic_maroon/1","doc":"Defines the color rgb(173, 66, 119).","ref":"Fledex.Color.Names.html#mystic_maroon/1"},{"type":"function","title":"Fledex.Color.Names.mystic_maroon/2","doc":"","ref":"Fledex.Color.Names.html#mystic_maroon/2"},{"type":"function","title":"Fledex.Color.Names.nadeshiko_pink/1","doc":"Defines the color rgb(244, 173, 198).","ref":"Fledex.Color.Names.html#nadeshiko_pink/1"},{"type":"function","title":"Fledex.Color.Names.nadeshiko_pink/2","doc":"","ref":"Fledex.Color.Names.html#nadeshiko_pink/2"},{"type":"function","title":"Fledex.Color.Names.names/0","doc":"Get a list of all the predefined color (atom) names. The name can be used to either\nretrieve the info by calling `info/2` or by calling the function with that\nname (see also the __Color Names__ section nad the [example livebook](3b_fledex_more_about_colors.livemd))","ref":"Fledex.Color.Names.html#names/0"},{"type":"function","title":"Fledex.Color.Names.naples_yellow/1","doc":"Defines the color rgb(249, 216, 94).","ref":"Fledex.Color.Names.html#naples_yellow/1"},{"type":"function","title":"Fledex.Color.Names.naples_yellow/2","doc":"","ref":"Fledex.Color.Names.html#naples_yellow/2"},{"type":"function","title":"Fledex.Color.Names.navajo_white/1","doc":"Defines the color rgb(255, 221, 173).","ref":"Fledex.Color.Names.html#navajo_white/1"},{"type":"function","title":"Fledex.Color.Names.navajo_white/2","doc":"","ref":"Fledex.Color.Names.html#navajo_white/2"},{"type":"function","title":"Fledex.Color.Names.navy_blue/1","doc":"Defines the color rgb(0, 0, 127).","ref":"Fledex.Color.Names.html#navy_blue/1"},{"type":"function","title":"Fledex.Color.Names.navy_blue/2","doc":"","ref":"Fledex.Color.Names.html#navy_blue/2"},{"type":"function","title":"Fledex.Color.Names.navy_blue_crayola/1","doc":"Defines the color rgb(25, 114, 209).","ref":"Fledex.Color.Names.html#navy_blue_crayola/1"},{"type":"function","title":"Fledex.Color.Names.navy_blue_crayola/2","doc":"","ref":"Fledex.Color.Names.html#navy_blue_crayola/2"},{"type":"function","title":"Fledex.Color.Names.neon_blue/1","doc":"Defines the color rgb(68, 102, 255).","ref":"Fledex.Color.Names.html#neon_blue/1"},{"type":"function","title":"Fledex.Color.Names.neon_blue/2","doc":"","ref":"Fledex.Color.Names.html#neon_blue/2"},{"type":"function","title":"Fledex.Color.Names.neon_fuchsia/1","doc":"Defines the color rgb(255, 63, 99).","ref":"Fledex.Color.Names.html#neon_fuchsia/1"},{"type":"function","title":"Fledex.Color.Names.neon_fuchsia/2","doc":"","ref":"Fledex.Color.Names.html#neon_fuchsia/2"},{"type":"function","title":"Fledex.Color.Names.neon_green/1","doc":"Defines the color rgb(56, 255, 20).","ref":"Fledex.Color.Names.html#neon_green/1"},{"type":"function","title":"Fledex.Color.Names.neon_green/2","doc":"","ref":"Fledex.Color.Names.html#neon_green/2"},{"type":"function","title":"Fledex.Color.Names.new_york_pink/1","doc":"Defines the color rgb(214, 130, 127).","ref":"Fledex.Color.Names.html#new_york_pink/1"},{"type":"function","title":"Fledex.Color.Names.new_york_pink/2","doc":"","ref":"Fledex.Color.Names.html#new_york_pink/2"},{"type":"function","title":"Fledex.Color.Names.nickel/1","doc":"Defines the color rgb(114, 114, 114).","ref":"Fledex.Color.Names.html#nickel/1"},{"type":"function","title":"Fledex.Color.Names.nickel/2","doc":"","ref":"Fledex.Color.Names.html#nickel/2"},{"type":"function","title":"Fledex.Color.Names.non_photo_blue/1","doc":"Defines the color rgb(163, 221, 237).","ref":"Fledex.Color.Names.html#non_photo_blue/1"},{"type":"function","title":"Fledex.Color.Names.non_photo_blue/2","doc":"","ref":"Fledex.Color.Names.html#non_photo_blue/2"},{"type":"function","title":"Fledex.Color.Names.nyanza/1","doc":"Defines the color rgb(232, 255, 219).","ref":"Fledex.Color.Names.html#nyanza/1"},{"type":"function","title":"Fledex.Color.Names.nyanza/2","doc":"","ref":"Fledex.Color.Names.html#nyanza/2"},{"type":"function","title":"Fledex.Color.Names.ochre/1","doc":"Defines the color rgb(204, 119, 33).","ref":"Fledex.Color.Names.html#ochre/1"},{"type":"function","title":"Fledex.Color.Names.ochre/2","doc":"","ref":"Fledex.Color.Names.html#ochre/2"},{"type":"function","title":"Fledex.Color.Names.old_burgundy/1","doc":"Defines the color rgb(66, 48, 45).","ref":"Fledex.Color.Names.html#old_burgundy/1"},{"type":"function","title":"Fledex.Color.Names.old_burgundy/2","doc":"","ref":"Fledex.Color.Names.html#old_burgundy/2"},{"type":"function","title":"Fledex.Color.Names.old_gold/1","doc":"Defines the color rgb(206, 181, 58).","ref":"Fledex.Color.Names.html#old_gold/1"},{"type":"function","title":"Fledex.Color.Names.old_gold/2","doc":"","ref":"Fledex.Color.Names.html#old_gold/2"},{"type":"function","title":"Fledex.Color.Names.old_lace/1","doc":"Defines the color rgb(252, 244, 229).","ref":"Fledex.Color.Names.html#old_lace/1"},{"type":"function","title":"Fledex.Color.Names.old_lace/2","doc":"","ref":"Fledex.Color.Names.html#old_lace/2"},{"type":"function","title":"Fledex.Color.Names.old_lavender/1","doc":"Defines the color rgb(119, 104, 119).","ref":"Fledex.Color.Names.html#old_lavender/1"},{"type":"function","title":"Fledex.Color.Names.old_lavender/2","doc":"","ref":"Fledex.Color.Names.html#old_lavender/2"},{"type":"function","title":"Fledex.Color.Names.old_mauve/1","doc":"Defines the color rgb(102, 48, 71).","ref":"Fledex.Color.Names.html#old_mauve/1"},{"type":"function","title":"Fledex.Color.Names.old_mauve/2","doc":"","ref":"Fledex.Color.Names.html#old_mauve/2"},{"type":"function","title":"Fledex.Color.Names.old_rose/1","doc":"Defines the color rgb(191, 127, 130).","ref":"Fledex.Color.Names.html#old_rose/1"},{"type":"function","title":"Fledex.Color.Names.old_rose/2","doc":"","ref":"Fledex.Color.Names.html#old_rose/2"},{"type":"function","title":"Fledex.Color.Names.old_silver/1","doc":"Defines the color rgb(132, 132, 130).","ref":"Fledex.Color.Names.html#old_silver/1"},{"type":"function","title":"Fledex.Color.Names.old_silver/2","doc":"","ref":"Fledex.Color.Names.html#old_silver/2"},{"type":"function","title":"Fledex.Color.Names.olive/1","doc":"Defines the color rgb(127, 127, 0).","ref":"Fledex.Color.Names.html#olive/1"},{"type":"function","title":"Fledex.Color.Names.olive/2","doc":"","ref":"Fledex.Color.Names.html#olive/2"},{"type":"function","title":"Fledex.Color.Names.olive_drab_3/1","doc":"Defines the color rgb(107, 142, 35).","ref":"Fledex.Color.Names.html#olive_drab_3/1"},{"type":"function","title":"Fledex.Color.Names.olive_drab_3/2","doc":"","ref":"Fledex.Color.Names.html#olive_drab_3/2"},{"type":"function","title":"Fledex.Color.Names.olive_drab_7/1","doc":"Defines the color rgb(61, 51, 30).","ref":"Fledex.Color.Names.html#olive_drab_7/1"},{"type":"function","title":"Fledex.Color.Names.olive_drab_7/2","doc":"","ref":"Fledex.Color.Names.html#olive_drab_7/2"},{"type":"function","title":"Fledex.Color.Names.olive_green/1","doc":"Defines the color rgb(181, 178, 91).","ref":"Fledex.Color.Names.html#olive_green/1"},{"type":"function","title":"Fledex.Color.Names.olive_green/2","doc":"","ref":"Fledex.Color.Names.html#olive_green/2"},{"type":"function","title":"Fledex.Color.Names.olivine/1","doc":"Defines the color rgb(153, 186, 114).","ref":"Fledex.Color.Names.html#olivine/1"},{"type":"function","title":"Fledex.Color.Names.olivine/2","doc":"","ref":"Fledex.Color.Names.html#olivine/2"},{"type":"function","title":"Fledex.Color.Names.onyx/1","doc":"Defines the color rgb(53, 56, 56).","ref":"Fledex.Color.Names.html#onyx/1"},{"type":"function","title":"Fledex.Color.Names.onyx/2","doc":"","ref":"Fledex.Color.Names.html#onyx/2"},{"type":"function","title":"Fledex.Color.Names.opal/1","doc":"Defines the color rgb(168, 193, 188).","ref":"Fledex.Color.Names.html#opal/1"},{"type":"function","title":"Fledex.Color.Names.opal/2","doc":"","ref":"Fledex.Color.Names.html#opal/2"},{"type":"function","title":"Fledex.Color.Names.opera_mauve/1","doc":"Defines the color rgb(183, 132, 165).","ref":"Fledex.Color.Names.html#opera_mauve/1"},{"type":"function","title":"Fledex.Color.Names.opera_mauve/2","doc":"","ref":"Fledex.Color.Names.html#opera_mauve/2"},{"type":"function","title":"Fledex.Color.Names.orange/1","doc":"Defines the color rgb(255, 127, 0).","ref":"Fledex.Color.Names.html#orange/1"},{"type":"function","title":"Fledex.Color.Names.orange/2","doc":"","ref":"Fledex.Color.Names.html#orange/2"},{"type":"function","title":"Fledex.Color.Names.orange_crayola/1","doc":"Defines the color rgb(255, 117, 56).","ref":"Fledex.Color.Names.html#orange_crayola/1"},{"type":"function","title":"Fledex.Color.Names.orange_crayola/2","doc":"","ref":"Fledex.Color.Names.html#orange_crayola/2"},{"type":"function","title":"Fledex.Color.Names.orange_pantone/1","doc":"Defines the color rgb(255, 89, 0).","ref":"Fledex.Color.Names.html#orange_pantone/1"},{"type":"function","title":"Fledex.Color.Names.orange_pantone/2","doc":"","ref":"Fledex.Color.Names.html#orange_pantone/2"},{"type":"function","title":"Fledex.Color.Names.orange_peel/1","doc":"Defines the color rgb(255, 158, 0).","ref":"Fledex.Color.Names.html#orange_peel/1"},{"type":"function","title":"Fledex.Color.Names.orange_peel/2","doc":"","ref":"Fledex.Color.Names.html#orange_peel/2"},{"type":"function","title":"Fledex.Color.Names.orange_red/1","doc":"Defines the color rgb(255, 104, 30).","ref":"Fledex.Color.Names.html#orange_red/1"},{"type":"function","title":"Fledex.Color.Names.orange_red/2","doc":"","ref":"Fledex.Color.Names.html#orange_red/2"},{"type":"function","title":"Fledex.Color.Names.orange_red_crayola/1","doc":"Defines the color rgb(255, 84, 73).","ref":"Fledex.Color.Names.html#orange_red_crayola/1"},{"type":"function","title":"Fledex.Color.Names.orange_red_crayola/2","doc":"","ref":"Fledex.Color.Names.html#orange_red_crayola/2"},{"type":"function","title":"Fledex.Color.Names.orange_soda/1","doc":"Defines the color rgb(249, 91, 61).","ref":"Fledex.Color.Names.html#orange_soda/1"},{"type":"function","title":"Fledex.Color.Names.orange_soda/2","doc":"","ref":"Fledex.Color.Names.html#orange_soda/2"},{"type":"function","title":"Fledex.Color.Names.orange_web/1","doc":"Defines the color rgb(255, 165, 0).","ref":"Fledex.Color.Names.html#orange_web/1"},{"type":"function","title":"Fledex.Color.Names.orange_web/2","doc":"","ref":"Fledex.Color.Names.html#orange_web/2"},{"type":"function","title":"Fledex.Color.Names.orange_yellow/1","doc":"Defines the color rgb(244, 188, 30).","ref":"Fledex.Color.Names.html#orange_yellow/1"},{"type":"function","title":"Fledex.Color.Names.orange_yellow/2","doc":"","ref":"Fledex.Color.Names.html#orange_yellow/2"},{"type":"function","title":"Fledex.Color.Names.orange_yellow_crayola/1","doc":"Defines the color rgb(247, 214, 104).","ref":"Fledex.Color.Names.html#orange_yellow_crayola/1"},{"type":"function","title":"Fledex.Color.Names.orange_yellow_crayola/2","doc":"","ref":"Fledex.Color.Names.html#orange_yellow_crayola/2"},{"type":"function","title":"Fledex.Color.Names.orchid/1","doc":"Defines the color rgb(216, 112, 214).","ref":"Fledex.Color.Names.html#orchid/1"},{"type":"function","title":"Fledex.Color.Names.orchid/2","doc":"","ref":"Fledex.Color.Names.html#orchid/2"},{"type":"function","title":"Fledex.Color.Names.orchid_crayola/1","doc":"Defines the color rgb(226, 155, 209).","ref":"Fledex.Color.Names.html#orchid_crayola/1"},{"type":"function","title":"Fledex.Color.Names.orchid_crayola/2","doc":"","ref":"Fledex.Color.Names.html#orchid_crayola/2"},{"type":"function","title":"Fledex.Color.Names.orchid_pink/1","doc":"Defines the color rgb(242, 188, 204).","ref":"Fledex.Color.Names.html#orchid_pink/1"},{"type":"function","title":"Fledex.Color.Names.orchid_pink/2","doc":"","ref":"Fledex.Color.Names.html#orchid_pink/2"},{"type":"function","title":"Fledex.Color.Names.ou_crimson_red/1","doc":"Defines the color rgb(132, 22, 22).","ref":"Fledex.Color.Names.html#ou_crimson_red/1"},{"type":"function","title":"Fledex.Color.Names.ou_crimson_red/2","doc":"","ref":"Fledex.Color.Names.html#ou_crimson_red/2"},{"type":"function","title":"Fledex.Color.Names.outer_space_crayola/1","doc":"Defines the color rgb(45, 56, 58).","ref":"Fledex.Color.Names.html#outer_space_crayola/1"},{"type":"function","title":"Fledex.Color.Names.outer_space_crayola/2","doc":"","ref":"Fledex.Color.Names.html#outer_space_crayola/2"},{"type":"function","title":"Fledex.Color.Names.outrageous_orange/1","doc":"Defines the color rgb(255, 109, 73).","ref":"Fledex.Color.Names.html#outrageous_orange/1"},{"type":"function","title":"Fledex.Color.Names.outrageous_orange/2","doc":"","ref":"Fledex.Color.Names.html#outrageous_orange/2"},{"type":"function","title":"Fledex.Color.Names.oxblood/1","doc":"Defines the color rgb(73, 0, 0).","ref":"Fledex.Color.Names.html#oxblood/1"},{"type":"function","title":"Fledex.Color.Names.oxblood/2","doc":"","ref":"Fledex.Color.Names.html#oxblood/2"},{"type":"function","title":"Fledex.Color.Names.oxford_blue/1","doc":"Defines the color rgb(0, 33, 71).","ref":"Fledex.Color.Names.html#oxford_blue/1"},{"type":"function","title":"Fledex.Color.Names.oxford_blue/2","doc":"","ref":"Fledex.Color.Names.html#oxford_blue/2"},{"type":"function","title":"Fledex.Color.Names.pacific_blue/1","doc":"Defines the color rgb(28, 168, 201).","ref":"Fledex.Color.Names.html#pacific_blue/1"},{"type":"function","title":"Fledex.Color.Names.pacific_blue/2","doc":"","ref":"Fledex.Color.Names.html#pacific_blue/2"},{"type":"function","title":"Fledex.Color.Names.pakistan_green/1","doc":"Defines the color rgb(0, 102, 0).","ref":"Fledex.Color.Names.html#pakistan_green/1"},{"type":"function","title":"Fledex.Color.Names.pakistan_green/2","doc":"","ref":"Fledex.Color.Names.html#pakistan_green/2"},{"type":"function","title":"Fledex.Color.Names.palatinate_purple/1","doc":"Defines the color rgb(104, 40, 96).","ref":"Fledex.Color.Names.html#palatinate_purple/1"},{"type":"function","title":"Fledex.Color.Names.palatinate_purple/2","doc":"","ref":"Fledex.Color.Names.html#palatinate_purple/2"},{"type":"function","title":"Fledex.Color.Names.pale_aqua/1","doc":"Defines the color rgb(191, 211, 229).","ref":"Fledex.Color.Names.html#pale_aqua/1"},{"type":"function","title":"Fledex.Color.Names.pale_aqua/2","doc":"","ref":"Fledex.Color.Names.html#pale_aqua/2"},{"type":"function","title":"Fledex.Color.Names.pale_cerulean/1","doc":"Defines the color rgb(155, 196, 226).","ref":"Fledex.Color.Names.html#pale_cerulean/1"},{"type":"function","title":"Fledex.Color.Names.pale_cerulean/2","doc":"","ref":"Fledex.Color.Names.html#pale_cerulean/2"},{"type":"function","title":"Fledex.Color.Names.pale_dogwood/1","doc":"Defines the color rgb(237, 122, 155).","ref":"Fledex.Color.Names.html#pale_dogwood/1"},{"type":"function","title":"Fledex.Color.Names.pale_dogwood/2","doc":"","ref":"Fledex.Color.Names.html#pale_dogwood/2"},{"type":"function","title":"Fledex.Color.Names.pale_pink/1","doc":"Defines the color rgb(249, 216, 221).","ref":"Fledex.Color.Names.html#pale_pink/1"},{"type":"function","title":"Fledex.Color.Names.pale_pink/2","doc":"","ref":"Fledex.Color.Names.html#pale_pink/2"},{"type":"function","title":"Fledex.Color.Names.pale_purple_pantone/1","doc":"Defines the color rgb(249, 229, 249).","ref":"Fledex.Color.Names.html#pale_purple_pantone/1"},{"type":"function","title":"Fledex.Color.Names.pale_purple_pantone/2","doc":"","ref":"Fledex.Color.Names.html#pale_purple_pantone/2"},{"type":"function","title":"Fledex.Color.Names.pale_spring_bud/1","doc":"Defines the color rgb(237, 234, 188).","ref":"Fledex.Color.Names.html#pale_spring_bud/1"},{"type":"function","title":"Fledex.Color.Names.pale_spring_bud/2","doc":"","ref":"Fledex.Color.Names.html#pale_spring_bud/2"},{"type":"function","title":"Fledex.Color.Names.pansy_purple/1","doc":"Defines the color rgb(119, 22, 73).","ref":"Fledex.Color.Names.html#pansy_purple/1"},{"type":"function","title":"Fledex.Color.Names.pansy_purple/2","doc":"","ref":"Fledex.Color.Names.html#pansy_purple/2"},{"type":"function","title":"Fledex.Color.Names.paolo_veronese_green/1","doc":"Defines the color rgb(0, 155, 124).","ref":"Fledex.Color.Names.html#paolo_veronese_green/1"},{"type":"function","title":"Fledex.Color.Names.paolo_veronese_green/2","doc":"","ref":"Fledex.Color.Names.html#paolo_veronese_green/2"},{"type":"function","title":"Fledex.Color.Names.papaya_whip/1","doc":"Defines the color rgb(255, 239, 214).","ref":"Fledex.Color.Names.html#papaya_whip/1"},{"type":"function","title":"Fledex.Color.Names.papaya_whip/2","doc":"","ref":"Fledex.Color.Names.html#papaya_whip/2"},{"type":"function","title":"Fledex.Color.Names.paradise_pink/1","doc":"Defines the color rgb(229, 61, 96).","ref":"Fledex.Color.Names.html#paradise_pink/1"},{"type":"function","title":"Fledex.Color.Names.paradise_pink/2","doc":"","ref":"Fledex.Color.Names.html#paradise_pink/2"},{"type":"function","title":"Fledex.Color.Names.parchment/1","doc":"Defines the color rgb(242, 232, 209).","ref":"Fledex.Color.Names.html#parchment/1"},{"type":"function","title":"Fledex.Color.Names.parchment/2","doc":"","ref":"Fledex.Color.Names.html#parchment/2"},{"type":"function","title":"Fledex.Color.Names.paris_green/1","doc":"Defines the color rgb(79, 198, 119).","ref":"Fledex.Color.Names.html#paris_green/1"},{"type":"function","title":"Fledex.Color.Names.paris_green/2","doc":"","ref":"Fledex.Color.Names.html#paris_green/2"},{"type":"function","title":"Fledex.Color.Names.pastel_pink/1","doc":"Defines the color rgb(221, 165, 163).","ref":"Fledex.Color.Names.html#pastel_pink/1"},{"type":"function","title":"Fledex.Color.Names.pastel_pink/2","doc":"","ref":"Fledex.Color.Names.html#pastel_pink/2"},{"type":"function","title":"Fledex.Color.Names.patriarch/1","doc":"Defines the color rgb(127, 0, 127).","ref":"Fledex.Color.Names.html#patriarch/1"},{"type":"function","title":"Fledex.Color.Names.patriarch/2","doc":"","ref":"Fledex.Color.Names.html#patriarch/2"},{"type":"function","title":"Fledex.Color.Names.paua/1","doc":"Defines the color rgb(30, 0, 94).","ref":"Fledex.Color.Names.html#paua/1"},{"type":"function","title":"Fledex.Color.Names.paua/2","doc":"","ref":"Fledex.Color.Names.html#paua/2"},{"type":"function","title":"Fledex.Color.Names.payne_s_grey/1","doc":"Defines the color rgb(84, 104, 119).","ref":"Fledex.Color.Names.html#payne_s_grey/1"},{"type":"function","title":"Fledex.Color.Names.payne_s_grey/2","doc":"","ref":"Fledex.Color.Names.html#payne_s_grey/2"},{"type":"function","title":"Fledex.Color.Names.peach/1","doc":"Defines the color rgb(255, 229, 181).","ref":"Fledex.Color.Names.html#peach/1"},{"type":"function","title":"Fledex.Color.Names.peach/2","doc":"","ref":"Fledex.Color.Names.html#peach/2"},{"type":"function","title":"Fledex.Color.Names.peach_crayola/1","doc":"Defines the color rgb(255, 204, 163).","ref":"Fledex.Color.Names.html#peach_crayola/1"},{"type":"function","title":"Fledex.Color.Names.peach_crayola/2","doc":"","ref":"Fledex.Color.Names.html#peach_crayola/2"},{"type":"function","title":"Fledex.Color.Names.peach_puff/1","doc":"Defines the color rgb(255, 216, 186).","ref":"Fledex.Color.Names.html#peach_puff/1"},{"type":"function","title":"Fledex.Color.Names.peach_puff/2","doc":"","ref":"Fledex.Color.Names.html#peach_puff/2"},{"type":"function","title":"Fledex.Color.Names.pear/1","doc":"Defines the color rgb(209, 226, 48).","ref":"Fledex.Color.Names.html#pear/1"},{"type":"function","title":"Fledex.Color.Names.pear/2","doc":"","ref":"Fledex.Color.Names.html#pear/2"},{"type":"function","title":"Fledex.Color.Names.pearly_purple/1","doc":"Defines the color rgb(183, 104, 163).","ref":"Fledex.Color.Names.html#pearly_purple/1"},{"type":"function","title":"Fledex.Color.Names.pearly_purple/2","doc":"","ref":"Fledex.Color.Names.html#pearly_purple/2"},{"type":"function","title":"Fledex.Color.Names.periwinkle/1","doc":"Defines the color rgb(204, 204, 255).","ref":"Fledex.Color.Names.html#periwinkle/1"},{"type":"function","title":"Fledex.Color.Names.periwinkle/2","doc":"","ref":"Fledex.Color.Names.html#periwinkle/2"},{"type":"function","title":"Fledex.Color.Names.periwinkle_crayola/1","doc":"Defines the color rgb(193, 204, 229).","ref":"Fledex.Color.Names.html#periwinkle_crayola/1"},{"type":"function","title":"Fledex.Color.Names.periwinkle_crayola/2","doc":"","ref":"Fledex.Color.Names.html#periwinkle_crayola/2"},{"type":"function","title":"Fledex.Color.Names.permanent_geranium_lake/1","doc":"Defines the color rgb(224, 43, 43).","ref":"Fledex.Color.Names.html#permanent_geranium_lake/1"},{"type":"function","title":"Fledex.Color.Names.permanent_geranium_lake/2","doc":"","ref":"Fledex.Color.Names.html#permanent_geranium_lake/2"},{"type":"function","title":"Fledex.Color.Names.persian_blue/1","doc":"Defines the color rgb(28, 56, 186).","ref":"Fledex.Color.Names.html#persian_blue/1"},{"type":"function","title":"Fledex.Color.Names.persian_blue/2","doc":"","ref":"Fledex.Color.Names.html#persian_blue/2"},{"type":"function","title":"Fledex.Color.Names.persian_green/1","doc":"Defines the color rgb(0, 165, 147).","ref":"Fledex.Color.Names.html#persian_green/1"},{"type":"function","title":"Fledex.Color.Names.persian_green/2","doc":"","ref":"Fledex.Color.Names.html#persian_green/2"},{"type":"function","title":"Fledex.Color.Names.persian_indigo/1","doc":"Defines the color rgb(51, 17, 122).","ref":"Fledex.Color.Names.html#persian_indigo/1"},{"type":"function","title":"Fledex.Color.Names.persian_indigo/2","doc":"","ref":"Fledex.Color.Names.html#persian_indigo/2"},{"type":"function","title":"Fledex.Color.Names.persian_orange/1","doc":"Defines the color rgb(216, 142, 89).","ref":"Fledex.Color.Names.html#persian_orange/1"},{"type":"function","title":"Fledex.Color.Names.persian_orange/2","doc":"","ref":"Fledex.Color.Names.html#persian_orange/2"},{"type":"function","title":"Fledex.Color.Names.persian_pink/1","doc":"Defines the color rgb(247, 127, 191).","ref":"Fledex.Color.Names.html#persian_pink/1"},{"type":"function","title":"Fledex.Color.Names.persian_pink/2","doc":"","ref":"Fledex.Color.Names.html#persian_pink/2"},{"type":"function","title":"Fledex.Color.Names.persian_plum/1","doc":"Defines the color rgb(112, 28, 28).","ref":"Fledex.Color.Names.html#persian_plum/1"},{"type":"function","title":"Fledex.Color.Names.persian_plum/2","doc":"","ref":"Fledex.Color.Names.html#persian_plum/2"},{"type":"function","title":"Fledex.Color.Names.persian_red/1","doc":"Defines the color rgb(204, 51, 51).","ref":"Fledex.Color.Names.html#persian_red/1"},{"type":"function","title":"Fledex.Color.Names.persian_red/2","doc":"","ref":"Fledex.Color.Names.html#persian_red/2"},{"type":"function","title":"Fledex.Color.Names.persian_rose/1","doc":"Defines the color rgb(255, 40, 163).","ref":"Fledex.Color.Names.html#persian_rose/1"},{"type":"function","title":"Fledex.Color.Names.persian_rose/2","doc":"","ref":"Fledex.Color.Names.html#persian_rose/2"},{"type":"function","title":"Fledex.Color.Names.persimmon/1","doc":"Defines the color rgb(237, 89, 0).","ref":"Fledex.Color.Names.html#persimmon/1"},{"type":"function","title":"Fledex.Color.Names.persimmon/2","doc":"","ref":"Fledex.Color.Names.html#persimmon/2"},{"type":"function","title":"Fledex.Color.Names.pewter_blue/1","doc":"Defines the color rgb(140, 168, 183).","ref":"Fledex.Color.Names.html#pewter_blue/1"},{"type":"function","title":"Fledex.Color.Names.pewter_blue/2","doc":"","ref":"Fledex.Color.Names.html#pewter_blue/2"},{"type":"function","title":"Fledex.Color.Names.phlox/1","doc":"Defines the color rgb(221, 0, 255).","ref":"Fledex.Color.Names.html#phlox/1"},{"type":"function","title":"Fledex.Color.Names.phlox/2","doc":"","ref":"Fledex.Color.Names.html#phlox/2"},{"type":"function","title":"Fledex.Color.Names.phthalo_blue/1","doc":"Defines the color rgb(0, 15, 137).","ref":"Fledex.Color.Names.html#phthalo_blue/1"},{"type":"function","title":"Fledex.Color.Names.phthalo_blue/2","doc":"","ref":"Fledex.Color.Names.html#phthalo_blue/2"},{"type":"function","title":"Fledex.Color.Names.phthalo_green/1","doc":"Defines the color rgb(17, 53, 35).","ref":"Fledex.Color.Names.html#phthalo_green/1"},{"type":"function","title":"Fledex.Color.Names.phthalo_green/2","doc":"","ref":"Fledex.Color.Names.html#phthalo_green/2"},{"type":"function","title":"Fledex.Color.Names.picotee_blue/1","doc":"Defines the color rgb(45, 38, 135).","ref":"Fledex.Color.Names.html#picotee_blue/1"},{"type":"function","title":"Fledex.Color.Names.picotee_blue/2","doc":"","ref":"Fledex.Color.Names.html#picotee_blue/2"},{"type":"function","title":"Fledex.Color.Names.pictorial_carmine/1","doc":"Defines the color rgb(193, 10, 79).","ref":"Fledex.Color.Names.html#pictorial_carmine/1"},{"type":"function","title":"Fledex.Color.Names.pictorial_carmine/2","doc":"","ref":"Fledex.Color.Names.html#pictorial_carmine/2"},{"type":"function","title":"Fledex.Color.Names.piggy_pink/1","doc":"Defines the color rgb(252, 221, 229).","ref":"Fledex.Color.Names.html#piggy_pink/1"},{"type":"function","title":"Fledex.Color.Names.piggy_pink/2","doc":"","ref":"Fledex.Color.Names.html#piggy_pink/2"},{"type":"function","title":"Fledex.Color.Names.pine_green/1","doc":"Defines the color rgb(0, 119, 112).","ref":"Fledex.Color.Names.html#pine_green/1"},{"type":"function","title":"Fledex.Color.Names.pine_green/2","doc":"","ref":"Fledex.Color.Names.html#pine_green/2"},{"type":"function","title":"Fledex.Color.Names.pine_tree/1","doc":"Defines the color rgb(40, 45, 35).","ref":"Fledex.Color.Names.html#pine_tree/1"},{"type":"function","title":"Fledex.Color.Names.pine_tree/2","doc":"","ref":"Fledex.Color.Names.html#pine_tree/2"},{"type":"function","title":"Fledex.Color.Names.pink/1","doc":"Defines the color rgb(255, 191, 204).","ref":"Fledex.Color.Names.html#pink/1"},{"type":"function","title":"Fledex.Color.Names.pink/2","doc":"","ref":"Fledex.Color.Names.html#pink/2"},{"type":"function","title":"Fledex.Color.Names.pink_lace/1","doc":"Defines the color rgb(255, 221, 244).","ref":"Fledex.Color.Names.html#pink_lace/1"},{"type":"function","title":"Fledex.Color.Names.pink_lace/2","doc":"","ref":"Fledex.Color.Names.html#pink_lace/2"},{"type":"function","title":"Fledex.Color.Names.pink_lavender/1","doc":"Defines the color rgb(216, 178, 209).","ref":"Fledex.Color.Names.html#pink_lavender/1"},{"type":"function","title":"Fledex.Color.Names.pink_lavender/2","doc":"","ref":"Fledex.Color.Names.html#pink_lavender/2"},{"type":"function","title":"Fledex.Color.Names.pink_pantone/1","doc":"Defines the color rgb(214, 71, 147).","ref":"Fledex.Color.Names.html#pink_pantone/1"},{"type":"function","title":"Fledex.Color.Names.pink_pantone/2","doc":"","ref":"Fledex.Color.Names.html#pink_pantone/2"},{"type":"function","title":"Fledex.Color.Names.pink_sherbet/1","doc":"Defines the color rgb(247, 142, 165).","ref":"Fledex.Color.Names.html#pink_sherbet/1"},{"type":"function","title":"Fledex.Color.Names.pink_sherbet/2","doc":"","ref":"Fledex.Color.Names.html#pink_sherbet/2"},{"type":"function","title":"Fledex.Color.Names.pistachio/1","doc":"Defines the color rgb(147, 196, 114).","ref":"Fledex.Color.Names.html#pistachio/1"},{"type":"function","title":"Fledex.Color.Names.pistachio/2","doc":"","ref":"Fledex.Color.Names.html#pistachio/2"},{"type":"function","title":"Fledex.Color.Names.platinum/1","doc":"Defines the color rgb(229, 226, 226).","ref":"Fledex.Color.Names.html#platinum/1"},{"type":"function","title":"Fledex.Color.Names.platinum/2","doc":"","ref":"Fledex.Color.Names.html#platinum/2"},{"type":"function","title":"Fledex.Color.Names.plum/1","doc":"Defines the color rgb(142, 68, 132).","ref":"Fledex.Color.Names.html#plum/1"},{"type":"function","title":"Fledex.Color.Names.plum/2","doc":"","ref":"Fledex.Color.Names.html#plum/2"},{"type":"function","title":"Fledex.Color.Names.plum_web/1","doc":"Defines the color rgb(221, 160, 221).","ref":"Fledex.Color.Names.html#plum_web/1"},{"type":"function","title":"Fledex.Color.Names.plum_web/2","doc":"","ref":"Fledex.Color.Names.html#plum_web/2"},{"type":"function","title":"Fledex.Color.Names.plump_purple/1","doc":"Defines the color rgb(89, 68, 178).","ref":"Fledex.Color.Names.html#plump_purple/1"},{"type":"function","title":"Fledex.Color.Names.plump_purple/2","doc":"","ref":"Fledex.Color.Names.html#plump_purple/2"},{"type":"function","title":"Fledex.Color.Names.polished_pine/1","doc":"Defines the color rgb(91, 163, 147).","ref":"Fledex.Color.Names.html#polished_pine/1"},{"type":"function","title":"Fledex.Color.Names.polished_pine/2","doc":"","ref":"Fledex.Color.Names.html#polished_pine/2"},{"type":"function","title":"Fledex.Color.Names.pomp_and_power/1","doc":"Defines the color rgb(135, 96, 142).","ref":"Fledex.Color.Names.html#pomp_and_power/1"},{"type":"function","title":"Fledex.Color.Names.pomp_and_power/2","doc":"","ref":"Fledex.Color.Names.html#pomp_and_power/2"},{"type":"function","title":"Fledex.Color.Names.popstar/1","doc":"Defines the color rgb(191, 79, 96).","ref":"Fledex.Color.Names.html#popstar/1"},{"type":"function","title":"Fledex.Color.Names.popstar/2","doc":"","ref":"Fledex.Color.Names.html#popstar/2"},{"type":"function","title":"Fledex.Color.Names.portland_orange/1","doc":"Defines the color rgb(255, 89, 53).","ref":"Fledex.Color.Names.html#portland_orange/1"},{"type":"function","title":"Fledex.Color.Names.portland_orange/2","doc":"","ref":"Fledex.Color.Names.html#portland_orange/2"},{"type":"function","title":"Fledex.Color.Names.powder_blue/1","doc":"Defines the color rgb(175, 224, 229).","ref":"Fledex.Color.Names.html#powder_blue/1"},{"type":"function","title":"Fledex.Color.Names.powder_blue/2","doc":"","ref":"Fledex.Color.Names.html#powder_blue/2"},{"type":"function","title":"Fledex.Color.Names.princeton_orange/1","doc":"Defines the color rgb(244, 127, 38).","ref":"Fledex.Color.Names.html#princeton_orange/1"},{"type":"function","title":"Fledex.Color.Names.princeton_orange/2","doc":"","ref":"Fledex.Color.Names.html#princeton_orange/2"},{"type":"function","title":"Fledex.Color.Names.process_yellow/1","doc":"Defines the color rgb(255, 239, 0).","ref":"Fledex.Color.Names.html#process_yellow/1"},{"type":"function","title":"Fledex.Color.Names.process_yellow/2","doc":"","ref":"Fledex.Color.Names.html#process_yellow/2"},{"type":"function","title":"Fledex.Color.Names.prune/1","doc":"Defines the color rgb(112, 28, 28).","ref":"Fledex.Color.Names.html#prune/1"},{"type":"function","title":"Fledex.Color.Names.prune/2","doc":"","ref":"Fledex.Color.Names.html#prune/2"},{"type":"function","title":"Fledex.Color.Names.prussian_blue/1","doc":"Defines the color rgb(0, 48, 84).","ref":"Fledex.Color.Names.html#prussian_blue/1"},{"type":"function","title":"Fledex.Color.Names.prussian_blue/2","doc":"","ref":"Fledex.Color.Names.html#prussian_blue/2"},{"type":"function","title":"Fledex.Color.Names.psychedelic_purple/1","doc":"Defines the color rgb(221, 0, 255).","ref":"Fledex.Color.Names.html#psychedelic_purple/1"},{"type":"function","title":"Fledex.Color.Names.psychedelic_purple/2","doc":"","ref":"Fledex.Color.Names.html#psychedelic_purple/2"},{"type":"function","title":"Fledex.Color.Names.puce/1","doc":"Defines the color rgb(204, 135, 153).","ref":"Fledex.Color.Names.html#puce/1"},{"type":"function","title":"Fledex.Color.Names.puce/2","doc":"","ref":"Fledex.Color.Names.html#puce/2"},{"type":"function","title":"Fledex.Color.Names.pullman_brown_ups_brown/1","doc":"Defines the color rgb(99, 63, 22).","ref":"Fledex.Color.Names.html#pullman_brown_ups_brown/1"},{"type":"function","title":"Fledex.Color.Names.pullman_brown_ups_brown/2","doc":"","ref":"Fledex.Color.Names.html#pullman_brown_ups_brown/2"},{"type":"function","title":"Fledex.Color.Names.pumpkin/1","doc":"Defines the color rgb(255, 117, 22).","ref":"Fledex.Color.Names.html#pumpkin/1"},{"type":"function","title":"Fledex.Color.Names.pumpkin/2","doc":"","ref":"Fledex.Color.Names.html#pumpkin/2"},{"type":"function","title":"Fledex.Color.Names.purple/1","doc":"Defines the color rgb(96, 0, 127).","ref":"Fledex.Color.Names.html#purple/1"},{"type":"function","title":"Fledex.Color.Names.purple/2","doc":"","ref":"Fledex.Color.Names.html#purple/2"},{"type":"function","title":"Fledex.Color.Names.purple_mountain_majesty/1","doc":"Defines the color rgb(150, 119, 181).","ref":"Fledex.Color.Names.html#purple_mountain_majesty/1"},{"type":"function","title":"Fledex.Color.Names.purple_mountain_majesty/2","doc":"","ref":"Fledex.Color.Names.html#purple_mountain_majesty/2"},{"type":"function","title":"Fledex.Color.Names.purple_munsell/1","doc":"Defines the color rgb(158, 0, 196).","ref":"Fledex.Color.Names.html#purple_munsell/1"},{"type":"function","title":"Fledex.Color.Names.purple_munsell/2","doc":"","ref":"Fledex.Color.Names.html#purple_munsell/2"},{"type":"function","title":"Fledex.Color.Names.purple_navy/1","doc":"Defines the color rgb(79, 81, 127).","ref":"Fledex.Color.Names.html#purple_navy/1"},{"type":"function","title":"Fledex.Color.Names.purple_navy/2","doc":"","ref":"Fledex.Color.Names.html#purple_navy/2"},{"type":"function","title":"Fledex.Color.Names.purple_pizzazz/1","doc":"Defines the color rgb(255, 79, 216).","ref":"Fledex.Color.Names.html#purple_pizzazz/1"},{"type":"function","title":"Fledex.Color.Names.purple_pizzazz/2","doc":"","ref":"Fledex.Color.Names.html#purple_pizzazz/2"},{"type":"function","title":"Fledex.Color.Names.purple_plum/1","doc":"Defines the color rgb(155, 81, 181).","ref":"Fledex.Color.Names.html#purple_plum/1"},{"type":"function","title":"Fledex.Color.Names.purple_plum/2","doc":"","ref":"Fledex.Color.Names.html#purple_plum/2"},{"type":"function","title":"Fledex.Color.Names.purple_web/1","doc":"Defines the color rgb(127, 0, 127).","ref":"Fledex.Color.Names.html#purple_web/1"},{"type":"function","title":"Fledex.Color.Names.purple_web/2","doc":"","ref":"Fledex.Color.Names.html#purple_web/2"},{"type":"function","title":"Fledex.Color.Names.purple_x11/1","doc":"Defines the color rgb(160, 33, 239).","ref":"Fledex.Color.Names.html#purple_x11/1"},{"type":"function","title":"Fledex.Color.Names.purple_x11/2","doc":"","ref":"Fledex.Color.Names.html#purple_x11/2"},{"type":"function","title":"Fledex.Color.Names.purpureus/1","doc":"Defines the color rgb(153, 79, 173).","ref":"Fledex.Color.Names.html#purpureus/1"},{"type":"function","title":"Fledex.Color.Names.purpureus/2","doc":"","ref":"Fledex.Color.Names.html#purpureus/2"},{"type":"function","title":"Fledex.Color.Names.queen_blue/1","doc":"Defines the color rgb(66, 107, 147).","ref":"Fledex.Color.Names.html#queen_blue/1"},{"type":"function","title":"Fledex.Color.Names.queen_blue/2","doc":"","ref":"Fledex.Color.Names.html#queen_blue/2"},{"type":"function","title":"Fledex.Color.Names.queen_pink/1","doc":"Defines the color rgb(232, 204, 214).","ref":"Fledex.Color.Names.html#queen_pink/1"},{"type":"function","title":"Fledex.Color.Names.queen_pink/2","doc":"","ref":"Fledex.Color.Names.html#queen_pink/2"},{"type":"function","title":"Fledex.Color.Names.quick_silver/1","doc":"Defines the color rgb(165, 165, 165).","ref":"Fledex.Color.Names.html#quick_silver/1"},{"type":"function","title":"Fledex.Color.Names.quick_silver/2","doc":"","ref":"Fledex.Color.Names.html#quick_silver/2"},{"type":"function","title":"Fledex.Color.Names.quinacridone_magenta/1","doc":"Defines the color rgb(142, 58, 89).","ref":"Fledex.Color.Names.html#quinacridone_magenta/1"},{"type":"function","title":"Fledex.Color.Names.quinacridone_magenta/2","doc":"","ref":"Fledex.Color.Names.html#quinacridone_magenta/2"},{"type":"function","title":"Fledex.Color.Names.radical_red/1","doc":"Defines the color rgb(255, 53, 94).","ref":"Fledex.Color.Names.html#radical_red/1"},{"type":"function","title":"Fledex.Color.Names.radical_red/2","doc":"","ref":"Fledex.Color.Names.html#radical_red/2"},{"type":"function","title":"Fledex.Color.Names.raisin_black/1","doc":"Defines the color rgb(35, 33, 35).","ref":"Fledex.Color.Names.html#raisin_black/1"},{"type":"function","title":"Fledex.Color.Names.raisin_black/2","doc":"","ref":"Fledex.Color.Names.html#raisin_black/2"},{"type":"function","title":"Fledex.Color.Names.rajah/1","doc":"Defines the color rgb(249, 170, 96).","ref":"Fledex.Color.Names.html#rajah/1"},{"type":"function","title":"Fledex.Color.Names.rajah/2","doc":"","ref":"Fledex.Color.Names.html#rajah/2"},{"type":"function","title":"Fledex.Color.Names.raspberry/1","doc":"Defines the color rgb(226, 10, 91).","ref":"Fledex.Color.Names.html#raspberry/1"},{"type":"function","title":"Fledex.Color.Names.raspberry/2","doc":"","ref":"Fledex.Color.Names.html#raspberry/2"},{"type":"function","title":"Fledex.Color.Names.raspberry_glace/1","doc":"Defines the color rgb(145, 94, 109).","ref":"Fledex.Color.Names.html#raspberry_glace/1"},{"type":"function","title":"Fledex.Color.Names.raspberry_glace/2","doc":"","ref":"Fledex.Color.Names.html#raspberry_glace/2"},{"type":"function","title":"Fledex.Color.Names.raspberry_rose/1","doc":"Defines the color rgb(178, 68, 107).","ref":"Fledex.Color.Names.html#raspberry_rose/1"},{"type":"function","title":"Fledex.Color.Names.raspberry_rose/2","doc":"","ref":"Fledex.Color.Names.html#raspberry_rose/2"},{"type":"function","title":"Fledex.Color.Names.raw_sienna/1","doc":"Defines the color rgb(214, 137, 89).","ref":"Fledex.Color.Names.html#raw_sienna/1"},{"type":"function","title":"Fledex.Color.Names.raw_sienna/2","doc":"","ref":"Fledex.Color.Names.html#raw_sienna/2"},{"type":"function","title":"Fledex.Color.Names.raw_umber/1","doc":"Defines the color rgb(130, 102, 68).","ref":"Fledex.Color.Names.html#raw_umber/1"},{"type":"function","title":"Fledex.Color.Names.raw_umber/2","doc":"","ref":"Fledex.Color.Names.html#raw_umber/2"},{"type":"function","title":"Fledex.Color.Names.razzle_dazzle_rose/1","doc":"Defines the color rgb(255, 51, 204).","ref":"Fledex.Color.Names.html#razzle_dazzle_rose/1"},{"type":"function","title":"Fledex.Color.Names.razzle_dazzle_rose/2","doc":"","ref":"Fledex.Color.Names.html#razzle_dazzle_rose/2"},{"type":"function","title":"Fledex.Color.Names.razzmatazz/1","doc":"Defines the color rgb(226, 38, 107).","ref":"Fledex.Color.Names.html#razzmatazz/1"},{"type":"function","title":"Fledex.Color.Names.razzmatazz/2","doc":"","ref":"Fledex.Color.Names.html#razzmatazz/2"},{"type":"function","title":"Fledex.Color.Names.razzmic_berry/1","doc":"Defines the color rgb(140, 79, 132).","ref":"Fledex.Color.Names.html#razzmic_berry/1"},{"type":"function","title":"Fledex.Color.Names.razzmic_berry/2","doc":"","ref":"Fledex.Color.Names.html#razzmic_berry/2"},{"type":"function","title":"Fledex.Color.Names.rebecca_purple/1","doc":"Defines the color rgb(102, 51, 153).","ref":"Fledex.Color.Names.html#rebecca_purple/1"},{"type":"function","title":"Fledex.Color.Names.rebecca_purple/2","doc":"","ref":"Fledex.Color.Names.html#rebecca_purple/2"},{"type":"function","title":"Fledex.Color.Names.red/1","doc":"Defines the color rgb(255, 0, 0).","ref":"Fledex.Color.Names.html#red/1"},{"type":"function","title":"Fledex.Color.Names.red/2","doc":"","ref":"Fledex.Color.Names.html#red/2"},{"type":"function","title":"Fledex.Color.Names.red_crayola/1","doc":"Defines the color rgb(237, 33, 76).","ref":"Fledex.Color.Names.html#red_crayola/1"},{"type":"function","title":"Fledex.Color.Names.red_crayola/2","doc":"","ref":"Fledex.Color.Names.html#red_crayola/2"},{"type":"function","title":"Fledex.Color.Names.red_munsell/1","doc":"Defines the color rgb(242, 0, 61).","ref":"Fledex.Color.Names.html#red_munsell/1"},{"type":"function","title":"Fledex.Color.Names.red_munsell/2","doc":"","ref":"Fledex.Color.Names.html#red_munsell/2"},{"type":"function","title":"Fledex.Color.Names.red_ncs/1","doc":"Defines the color rgb(196, 2, 51).","ref":"Fledex.Color.Names.html#red_ncs/1"},{"type":"function","title":"Fledex.Color.Names.red_ncs/2","doc":"","ref":"Fledex.Color.Names.html#red_ncs/2"},{"type":"function","title":"Fledex.Color.Names.red_orange/1","doc":"Defines the color rgb(255, 84, 73).","ref":"Fledex.Color.Names.html#red_orange/1"},{"type":"function","title":"Fledex.Color.Names.red_orange/2","doc":"","ref":"Fledex.Color.Names.html#red_orange/2"},{"type":"function","title":"Fledex.Color.Names.red_orange_color_wheel/1","doc":"Defines the color rgb(255, 68, 0).","ref":"Fledex.Color.Names.html#red_orange_color_wheel/1"},{"type":"function","title":"Fledex.Color.Names.red_orange_color_wheel/2","doc":"","ref":"Fledex.Color.Names.html#red_orange_color_wheel/2"},{"type":"function","title":"Fledex.Color.Names.red_orange_crayola/1","doc":"Defines the color rgb(255, 104, 30).","ref":"Fledex.Color.Names.html#red_orange_crayola/1"},{"type":"function","title":"Fledex.Color.Names.red_orange_crayola/2","doc":"","ref":"Fledex.Color.Names.html#red_orange_crayola/2"},{"type":"function","title":"Fledex.Color.Names.red_pantone/1","doc":"Defines the color rgb(237, 40, 56).","ref":"Fledex.Color.Names.html#red_pantone/1"},{"type":"function","title":"Fledex.Color.Names.red_pantone/2","doc":"","ref":"Fledex.Color.Names.html#red_pantone/2"},{"type":"function","title":"Fledex.Color.Names.red_pigment/1","doc":"Defines the color rgb(237, 28, 35).","ref":"Fledex.Color.Names.html#red_pigment/1"},{"type":"function","title":"Fledex.Color.Names.red_pigment/2","doc":"","ref":"Fledex.Color.Names.html#red_pigment/2"},{"type":"function","title":"Fledex.Color.Names.red_purple/1","doc":"Defines the color rgb(226, 0, 119).","ref":"Fledex.Color.Names.html#red_purple/1"},{"type":"function","title":"Fledex.Color.Names.red_purple/2","doc":"","ref":"Fledex.Color.Names.html#red_purple/2"},{"type":"function","title":"Fledex.Color.Names.red_ryb/1","doc":"Defines the color rgb(255, 38, 17).","ref":"Fledex.Color.Names.html#red_ryb/1"},{"type":"function","title":"Fledex.Color.Names.red_ryb/2","doc":"","ref":"Fledex.Color.Names.html#red_ryb/2"},{"type":"function","title":"Fledex.Color.Names.red_salsa/1","doc":"Defines the color rgb(252, 58, 73).","ref":"Fledex.Color.Names.html#red_salsa/1"},{"type":"function","title":"Fledex.Color.Names.red_salsa/2","doc":"","ref":"Fledex.Color.Names.html#red_salsa/2"},{"type":"function","title":"Fledex.Color.Names.red_violet/1","doc":"Defines the color rgb(198, 20, 132).","ref":"Fledex.Color.Names.html#red_violet/1"},{"type":"function","title":"Fledex.Color.Names.red_violet/2","doc":"","ref":"Fledex.Color.Names.html#red_violet/2"},{"type":"function","title":"Fledex.Color.Names.red_violet_color_wheel/1","doc":"Defines the color rgb(145, 43, 61).","ref":"Fledex.Color.Names.html#red_violet_color_wheel/1"},{"type":"function","title":"Fledex.Color.Names.red_violet_color_wheel/2","doc":"","ref":"Fledex.Color.Names.html#red_violet_color_wheel/2"},{"type":"function","title":"Fledex.Color.Names.red_violet_crayola/1","doc":"Defines the color rgb(191, 68, 142).","ref":"Fledex.Color.Names.html#red_violet_crayola/1"},{"type":"function","title":"Fledex.Color.Names.red_violet_crayola/2","doc":"","ref":"Fledex.Color.Names.html#red_violet_crayola/2"},{"type":"function","title":"Fledex.Color.Names.redwood/1","doc":"Defines the color rgb(163, 89, 81).","ref":"Fledex.Color.Names.html#redwood/1"},{"type":"function","title":"Fledex.Color.Names.redwood/2","doc":"","ref":"Fledex.Color.Names.html#redwood/2"},{"type":"function","title":"Fledex.Color.Names.resolution_blue/1","doc":"Defines the color rgb(0, 35, 135).","ref":"Fledex.Color.Names.html#resolution_blue/1"},{"type":"function","title":"Fledex.Color.Names.resolution_blue/2","doc":"","ref":"Fledex.Color.Names.html#resolution_blue/2"},{"type":"function","title":"Fledex.Color.Names.rhythm/1","doc":"Defines the color rgb(119, 117, 150).","ref":"Fledex.Color.Names.html#rhythm/1"},{"type":"function","title":"Fledex.Color.Names.rhythm/2","doc":"","ref":"Fledex.Color.Names.html#rhythm/2"},{"type":"function","title":"Fledex.Color.Names.rich_black/1","doc":"Defines the color rgb(0, 63, 63).","ref":"Fledex.Color.Names.html#rich_black/1"},{"type":"function","title":"Fledex.Color.Names.rich_black/2","doc":"","ref":"Fledex.Color.Names.html#rich_black/2"},{"type":"function","title":"Fledex.Color.Names.rich_black_fogra29/1","doc":"Defines the color rgb(0, 10, 17).","ref":"Fledex.Color.Names.html#rich_black_fogra29/1"},{"type":"function","title":"Fledex.Color.Names.rich_black_fogra29/2","doc":"","ref":"Fledex.Color.Names.html#rich_black_fogra29/2"},{"type":"function","title":"Fledex.Color.Names.rich_black_fogra39/1","doc":"Defines the color rgb(0, 2, 2).","ref":"Fledex.Color.Names.html#rich_black_fogra39/1"},{"type":"function","title":"Fledex.Color.Names.rich_black_fogra39/2","doc":"","ref":"Fledex.Color.Names.html#rich_black_fogra39/2"},{"type":"function","title":"Fledex.Color.Names.rifle_green/1","doc":"Defines the color rgb(68, 76, 56).","ref":"Fledex.Color.Names.html#rifle_green/1"},{"type":"function","title":"Fledex.Color.Names.rifle_green/2","doc":"","ref":"Fledex.Color.Names.html#rifle_green/2"},{"type":"function","title":"Fledex.Color.Names.robin_egg_blue/1","doc":"Defines the color rgb(0, 204, 204).","ref":"Fledex.Color.Names.html#robin_egg_blue/1"},{"type":"function","title":"Fledex.Color.Names.robin_egg_blue/2","doc":"","ref":"Fledex.Color.Names.html#robin_egg_blue/2"},{"type":"function","title":"Fledex.Color.Names.rocket_metallic/1","doc":"Defines the color rgb(137, 127, 127).","ref":"Fledex.Color.Names.html#rocket_metallic/1"},{"type":"function","title":"Fledex.Color.Names.rocket_metallic/2","doc":"","ref":"Fledex.Color.Names.html#rocket_metallic/2"},{"type":"function","title":"Fledex.Color.Names.rojo_spanish_red/1","doc":"Defines the color rgb(168, 17, 0).","ref":"Fledex.Color.Names.html#rojo_spanish_red/1"},{"type":"function","title":"Fledex.Color.Names.rojo_spanish_red/2","doc":"","ref":"Fledex.Color.Names.html#rojo_spanish_red/2"},{"type":"function","title":"Fledex.Color.Names.roman_silver/1","doc":"Defines the color rgb(130, 137, 150).","ref":"Fledex.Color.Names.html#roman_silver/1"},{"type":"function","title":"Fledex.Color.Names.roman_silver/2","doc":"","ref":"Fledex.Color.Names.html#roman_silver/2"},{"type":"function","title":"Fledex.Color.Names.rose/1","doc":"Defines the color rgb(255, 0, 127).","ref":"Fledex.Color.Names.html#rose/1"},{"type":"function","title":"Fledex.Color.Names.rose/2","doc":"","ref":"Fledex.Color.Names.html#rose/2"},{"type":"function","title":"Fledex.Color.Names.rose_bonbon/1","doc":"Defines the color rgb(249, 66, 158).","ref":"Fledex.Color.Names.html#rose_bonbon/1"},{"type":"function","title":"Fledex.Color.Names.rose_bonbon/2","doc":"","ref":"Fledex.Color.Names.html#rose_bonbon/2"},{"type":"function","title":"Fledex.Color.Names.rose_dust/1","doc":"Defines the color rgb(158, 94, 112).","ref":"Fledex.Color.Names.html#rose_dust/1"},{"type":"function","title":"Fledex.Color.Names.rose_dust/2","doc":"","ref":"Fledex.Color.Names.html#rose_dust/2"},{"type":"function","title":"Fledex.Color.Names.rose_ebony/1","doc":"Defines the color rgb(102, 71, 68).","ref":"Fledex.Color.Names.html#rose_ebony/1"},{"type":"function","title":"Fledex.Color.Names.rose_ebony/2","doc":"","ref":"Fledex.Color.Names.html#rose_ebony/2"},{"type":"function","title":"Fledex.Color.Names.rose_madder/1","doc":"Defines the color rgb(226, 38, 53).","ref":"Fledex.Color.Names.html#rose_madder/1"},{"type":"function","title":"Fledex.Color.Names.rose_madder/2","doc":"","ref":"Fledex.Color.Names.html#rose_madder/2"},{"type":"function","title":"Fledex.Color.Names.rose_pink/1","doc":"Defines the color rgb(255, 102, 204).","ref":"Fledex.Color.Names.html#rose_pink/1"},{"type":"function","title":"Fledex.Color.Names.rose_pink/2","doc":"","ref":"Fledex.Color.Names.html#rose_pink/2"},{"type":"function","title":"Fledex.Color.Names.rose_pompadour/1","doc":"Defines the color rgb(237, 122, 155).","ref":"Fledex.Color.Names.html#rose_pompadour/1"},{"type":"function","title":"Fledex.Color.Names.rose_pompadour/2","doc":"","ref":"Fledex.Color.Names.html#rose_pompadour/2"},{"type":"function","title":"Fledex.Color.Names.rose_red/1","doc":"Defines the color rgb(193, 30, 86).","ref":"Fledex.Color.Names.html#rose_red/1"},{"type":"function","title":"Fledex.Color.Names.rose_red/2","doc":"","ref":"Fledex.Color.Names.html#rose_red/2"},{"type":"function","title":"Fledex.Color.Names.rose_taupe/1","doc":"Defines the color rgb(142, 91, 91).","ref":"Fledex.Color.Names.html#rose_taupe/1"},{"type":"function","title":"Fledex.Color.Names.rose_taupe/2","doc":"","ref":"Fledex.Color.Names.html#rose_taupe/2"},{"type":"function","title":"Fledex.Color.Names.rose_vale/1","doc":"Defines the color rgb(170, 79, 81).","ref":"Fledex.Color.Names.html#rose_vale/1"},{"type":"function","title":"Fledex.Color.Names.rose_vale/2","doc":"","ref":"Fledex.Color.Names.html#rose_vale/2"},{"type":"function","title":"Fledex.Color.Names.rosewood/1","doc":"Defines the color rgb(102, 0, 10).","ref":"Fledex.Color.Names.html#rosewood/1"},{"type":"function","title":"Fledex.Color.Names.rosewood/2","doc":"","ref":"Fledex.Color.Names.html#rosewood/2"},{"type":"function","title":"Fledex.Color.Names.rosso_corsa/1","doc":"Defines the color rgb(211, 0, 0).","ref":"Fledex.Color.Names.html#rosso_corsa/1"},{"type":"function","title":"Fledex.Color.Names.rosso_corsa/2","doc":"","ref":"Fledex.Color.Names.html#rosso_corsa/2"},{"type":"function","title":"Fledex.Color.Names.rosy_brown/1","doc":"Defines the color rgb(188, 142, 142).","ref":"Fledex.Color.Names.html#rosy_brown/1"},{"type":"function","title":"Fledex.Color.Names.rosy_brown/2","doc":"","ref":"Fledex.Color.Names.html#rosy_brown/2"},{"type":"function","title":"Fledex.Color.Names.royal_blue_dark/1","doc":"Defines the color rgb(0, 35, 102).","ref":"Fledex.Color.Names.html#royal_blue_dark/1"},{"type":"function","title":"Fledex.Color.Names.royal_blue_dark/2","doc":"","ref":"Fledex.Color.Names.html#royal_blue_dark/2"},{"type":"function","title":"Fledex.Color.Names.royal_blue_light/1","doc":"Defines the color rgb(63, 104, 224).","ref":"Fledex.Color.Names.html#royal_blue_light/1"},{"type":"function","title":"Fledex.Color.Names.royal_blue_light/2","doc":"","ref":"Fledex.Color.Names.html#royal_blue_light/2"},{"type":"function","title":"Fledex.Color.Names.royal_purple/1","doc":"Defines the color rgb(119, 81, 168).","ref":"Fledex.Color.Names.html#royal_purple/1"},{"type":"function","title":"Fledex.Color.Names.royal_purple/2","doc":"","ref":"Fledex.Color.Names.html#royal_purple/2"},{"type":"function","title":"Fledex.Color.Names.royal_yellow/1","doc":"Defines the color rgb(249, 216, 94).","ref":"Fledex.Color.Names.html#royal_yellow/1"},{"type":"function","title":"Fledex.Color.Names.royal_yellow/2","doc":"","ref":"Fledex.Color.Names.html#royal_yellow/2"},{"type":"function","title":"Fledex.Color.Names.ruber/1","doc":"Defines the color rgb(206, 68, 117).","ref":"Fledex.Color.Names.html#ruber/1"},{"type":"function","title":"Fledex.Color.Names.ruber/2","doc":"","ref":"Fledex.Color.Names.html#ruber/2"},{"type":"function","title":"Fledex.Color.Names.rubine_red/1","doc":"Defines the color rgb(209, 0, 86).","ref":"Fledex.Color.Names.html#rubine_red/1"},{"type":"function","title":"Fledex.Color.Names.rubine_red/2","doc":"","ref":"Fledex.Color.Names.html#rubine_red/2"},{"type":"function","title":"Fledex.Color.Names.ruby/1","doc":"Defines the color rgb(224, 17, 94).","ref":"Fledex.Color.Names.html#ruby/1"},{"type":"function","title":"Fledex.Color.Names.ruby/2","doc":"","ref":"Fledex.Color.Names.html#ruby/2"},{"type":"function","title":"Fledex.Color.Names.ruby_red/1","doc":"Defines the color rgb(155, 17, 30).","ref":"Fledex.Color.Names.html#ruby_red/1"},{"type":"function","title":"Fledex.Color.Names.ruby_red/2","doc":"","ref":"Fledex.Color.Names.html#ruby_red/2"},{"type":"function","title":"Fledex.Color.Names.rufous/1","doc":"Defines the color rgb(168, 28, 7).","ref":"Fledex.Color.Names.html#rufous/1"},{"type":"function","title":"Fledex.Color.Names.rufous/2","doc":"","ref":"Fledex.Color.Names.html#rufous/2"},{"type":"function","title":"Fledex.Color.Names.russet/1","doc":"Defines the color rgb(127, 68, 28).","ref":"Fledex.Color.Names.html#russet/1"},{"type":"function","title":"Fledex.Color.Names.russet/2","doc":"","ref":"Fledex.Color.Names.html#russet/2"},{"type":"function","title":"Fledex.Color.Names.russian_green/1","doc":"Defines the color rgb(102, 145, 102).","ref":"Fledex.Color.Names.html#russian_green/1"},{"type":"function","title":"Fledex.Color.Names.russian_green/2","doc":"","ref":"Fledex.Color.Names.html#russian_green/2"},{"type":"function","title":"Fledex.Color.Names.russian_violet/1","doc":"Defines the color rgb(51, 22, 76).","ref":"Fledex.Color.Names.html#russian_violet/1"},{"type":"function","title":"Fledex.Color.Names.russian_violet/2","doc":"","ref":"Fledex.Color.Names.html#russian_violet/2"},{"type":"function","title":"Fledex.Color.Names.rust/1","doc":"Defines the color rgb(183, 63, 12).","ref":"Fledex.Color.Names.html#rust/1"},{"type":"function","title":"Fledex.Color.Names.rust/2","doc":"","ref":"Fledex.Color.Names.html#rust/2"},{"type":"function","title":"Fledex.Color.Names.rusty_red/1","doc":"Defines the color rgb(216, 43, 66).","ref":"Fledex.Color.Names.html#rusty_red/1"},{"type":"function","title":"Fledex.Color.Names.rusty_red/2","doc":"","ref":"Fledex.Color.Names.html#rusty_red/2"},{"type":"function","title":"Fledex.Color.Names.sacramento_state_green/1","doc":"Defines the color rgb(5, 56, 38).","ref":"Fledex.Color.Names.html#sacramento_state_green/1"},{"type":"function","title":"Fledex.Color.Names.sacramento_state_green/2","doc":"","ref":"Fledex.Color.Names.html#sacramento_state_green/2"},{"type":"function","title":"Fledex.Color.Names.saddle_brown/1","doc":"Defines the color rgb(140, 68, 17).","ref":"Fledex.Color.Names.html#saddle_brown/1"},{"type":"function","title":"Fledex.Color.Names.saddle_brown/2","doc":"","ref":"Fledex.Color.Names.html#saddle_brown/2"},{"type":"function","title":"Fledex.Color.Names.safety_orange/1","doc":"Defines the color rgb(255, 119, 0).","ref":"Fledex.Color.Names.html#safety_orange/1"},{"type":"function","title":"Fledex.Color.Names.safety_orange/2","doc":"","ref":"Fledex.Color.Names.html#safety_orange/2"},{"type":"function","title":"Fledex.Color.Names.safety_orange_blaze_orange/1","doc":"Defines the color rgb(255, 102, 0).","ref":"Fledex.Color.Names.html#safety_orange_blaze_orange/1"},{"type":"function","title":"Fledex.Color.Names.safety_orange_blaze_orange/2","doc":"","ref":"Fledex.Color.Names.html#safety_orange_blaze_orange/2"},{"type":"function","title":"Fledex.Color.Names.safety_yellow/1","doc":"Defines the color rgb(237, 209, 2).","ref":"Fledex.Color.Names.html#safety_yellow/1"},{"type":"function","title":"Fledex.Color.Names.safety_yellow/2","doc":"","ref":"Fledex.Color.Names.html#safety_yellow/2"},{"type":"function","title":"Fledex.Color.Names.saffron/1","doc":"Defines the color rgb(244, 196, 48).","ref":"Fledex.Color.Names.html#saffron/1"},{"type":"function","title":"Fledex.Color.Names.saffron/2","doc":"","ref":"Fledex.Color.Names.html#saffron/2"},{"type":"function","title":"Fledex.Color.Names.sage/1","doc":"Defines the color rgb(188, 183, 137).","ref":"Fledex.Color.Names.html#sage/1"},{"type":"function","title":"Fledex.Color.Names.sage/2","doc":"","ref":"Fledex.Color.Names.html#sage/2"},{"type":"function","title":"Fledex.Color.Names.salmon/1","doc":"Defines the color rgb(249, 127, 114).","ref":"Fledex.Color.Names.html#salmon/1"},{"type":"function","title":"Fledex.Color.Names.salmon/2","doc":"","ref":"Fledex.Color.Names.html#salmon/2"},{"type":"function","title":"Fledex.Color.Names.salmon_pink/1","doc":"Defines the color rgb(255, 145, 163).","ref":"Fledex.Color.Names.html#salmon_pink/1"},{"type":"function","title":"Fledex.Color.Names.salmon_pink/2","doc":"","ref":"Fledex.Color.Names.html#salmon_pink/2"},{"type":"function","title":"Fledex.Color.Names.sand/1","doc":"Defines the color rgb(193, 178, 127).","ref":"Fledex.Color.Names.html#sand/1"},{"type":"function","title":"Fledex.Color.Names.sand/2","doc":"","ref":"Fledex.Color.Names.html#sand/2"},{"type":"function","title":"Fledex.Color.Names.sand_dune/1","doc":"Defines the color rgb(150, 112, 22).","ref":"Fledex.Color.Names.html#sand_dune/1"},{"type":"function","title":"Fledex.Color.Names.sand_dune/2","doc":"","ref":"Fledex.Color.Names.html#sand_dune/2"},{"type":"function","title":"Fledex.Color.Names.sandy_brown/1","doc":"Defines the color rgb(244, 163, 96).","ref":"Fledex.Color.Names.html#sandy_brown/1"},{"type":"function","title":"Fledex.Color.Names.sandy_brown/2","doc":"","ref":"Fledex.Color.Names.html#sandy_brown/2"},{"type":"function","title":"Fledex.Color.Names.sap_green/1","doc":"Defines the color rgb(79, 124, 40).","ref":"Fledex.Color.Names.html#sap_green/1"},{"type":"function","title":"Fledex.Color.Names.sap_green/2","doc":"","ref":"Fledex.Color.Names.html#sap_green/2"},{"type":"function","title":"Fledex.Color.Names.sapphire/1","doc":"Defines the color rgb(15, 81, 186).","ref":"Fledex.Color.Names.html#sapphire/1"},{"type":"function","title":"Fledex.Color.Names.sapphire/2","doc":"","ref":"Fledex.Color.Names.html#sapphire/2"},{"type":"function","title":"Fledex.Color.Names.sapphire_blue/1","doc":"Defines the color rgb(0, 102, 165).","ref":"Fledex.Color.Names.html#sapphire_blue/1"},{"type":"function","title":"Fledex.Color.Names.sapphire_blue/2","doc":"","ref":"Fledex.Color.Names.html#sapphire_blue/2"},{"type":"function","title":"Fledex.Color.Names.sapphire_crayola/1","doc":"Defines the color rgb(45, 91, 160).","ref":"Fledex.Color.Names.html#sapphire_crayola/1"},{"type":"function","title":"Fledex.Color.Names.sapphire_crayola/2","doc":"","ref":"Fledex.Color.Names.html#sapphire_crayola/2"},{"type":"function","title":"Fledex.Color.Names.satin_sheen_gold/1","doc":"Defines the color rgb(204, 160, 53).","ref":"Fledex.Color.Names.html#satin_sheen_gold/1"},{"type":"function","title":"Fledex.Color.Names.satin_sheen_gold/2","doc":"","ref":"Fledex.Color.Names.html#satin_sheen_gold/2"},{"type":"function","title":"Fledex.Color.Names.scarlet/1","doc":"Defines the color rgb(255, 35, 0).","ref":"Fledex.Color.Names.html#scarlet/1"},{"type":"function","title":"Fledex.Color.Names.scarlet/2","doc":"","ref":"Fledex.Color.Names.html#scarlet/2"},{"type":"function","title":"Fledex.Color.Names.schauss_pink/1","doc":"Defines the color rgb(255, 145, 175).","ref":"Fledex.Color.Names.html#schauss_pink/1"},{"type":"function","title":"Fledex.Color.Names.schauss_pink/2","doc":"","ref":"Fledex.Color.Names.html#schauss_pink/2"},{"type":"function","title":"Fledex.Color.Names.school_bus_yellow/1","doc":"Defines the color rgb(255, 216, 0).","ref":"Fledex.Color.Names.html#school_bus_yellow/1"},{"type":"function","title":"Fledex.Color.Names.school_bus_yellow/2","doc":"","ref":"Fledex.Color.Names.html#school_bus_yellow/2"},{"type":"function","title":"Fledex.Color.Names.screamin_green/1","doc":"Defines the color rgb(102, 255, 102).","ref":"Fledex.Color.Names.html#screamin_green/1"},{"type":"function","title":"Fledex.Color.Names.screamin_green/2","doc":"","ref":"Fledex.Color.Names.html#screamin_green/2"},{"type":"function","title":"Fledex.Color.Names.sea_green/1","doc":"Defines the color rgb(45, 140, 86).","ref":"Fledex.Color.Names.html#sea_green/1"},{"type":"function","title":"Fledex.Color.Names.sea_green/2","doc":"","ref":"Fledex.Color.Names.html#sea_green/2"},{"type":"function","title":"Fledex.Color.Names.sea_green_crayola/1","doc":"Defines the color rgb(0, 255, 204).","ref":"Fledex.Color.Names.html#sea_green_crayola/1"},{"type":"function","title":"Fledex.Color.Names.sea_green_crayola/2","doc":"","ref":"Fledex.Color.Names.html#sea_green_crayola/2"},{"type":"function","title":"Fledex.Color.Names.seal_brown/1","doc":"Defines the color rgb(51, 20, 20).","ref":"Fledex.Color.Names.html#seal_brown/1"},{"type":"function","title":"Fledex.Color.Names.seal_brown/2","doc":"","ref":"Fledex.Color.Names.html#seal_brown/2"},{"type":"function","title":"Fledex.Color.Names.seance/1","doc":"Defines the color rgb(96, 33, 135).","ref":"Fledex.Color.Names.html#seance/1"},{"type":"function","title":"Fledex.Color.Names.seance/2","doc":"","ref":"Fledex.Color.Names.html#seance/2"},{"type":"function","title":"Fledex.Color.Names.seashell/1","doc":"Defines the color rgb(255, 244, 237).","ref":"Fledex.Color.Names.html#seashell/1"},{"type":"function","title":"Fledex.Color.Names.seashell/2","doc":"","ref":"Fledex.Color.Names.html#seashell/2"},{"type":"function","title":"Fledex.Color.Names.secret/1","doc":"Defines the color rgb(117, 66, 114).","ref":"Fledex.Color.Names.html#secret/1"},{"type":"function","title":"Fledex.Color.Names.secret/2","doc":"","ref":"Fledex.Color.Names.html#secret/2"},{"type":"function","title":"Fledex.Color.Names.selective_yellow/1","doc":"Defines the color rgb(255, 186, 0).","ref":"Fledex.Color.Names.html#selective_yellow/1"},{"type":"function","title":"Fledex.Color.Names.selective_yellow/2","doc":"","ref":"Fledex.Color.Names.html#selective_yellow/2"},{"type":"function","title":"Fledex.Color.Names.sepia/1","doc":"Defines the color rgb(112, 66, 20).","ref":"Fledex.Color.Names.html#sepia/1"},{"type":"function","title":"Fledex.Color.Names.sepia/2","doc":"","ref":"Fledex.Color.Names.html#sepia/2"},{"type":"function","title":"Fledex.Color.Names.shadow/1","doc":"Defines the color rgb(137, 119, 91).","ref":"Fledex.Color.Names.html#shadow/1"},{"type":"function","title":"Fledex.Color.Names.shadow/2","doc":"","ref":"Fledex.Color.Names.html#shadow/2"},{"type":"function","title":"Fledex.Color.Names.shadow_blue/1","doc":"Defines the color rgb(119, 140, 165).","ref":"Fledex.Color.Names.html#shadow_blue/1"},{"type":"function","title":"Fledex.Color.Names.shadow_blue/2","doc":"","ref":"Fledex.Color.Names.html#shadow_blue/2"},{"type":"function","title":"Fledex.Color.Names.shamrock_green/1","doc":"Defines the color rgb(0, 158, 96).","ref":"Fledex.Color.Names.html#shamrock_green/1"},{"type":"function","title":"Fledex.Color.Names.shamrock_green/2","doc":"","ref":"Fledex.Color.Names.html#shamrock_green/2"},{"type":"function","title":"Fledex.Color.Names.sheen_green/1","doc":"Defines the color rgb(142, 211, 0).","ref":"Fledex.Color.Names.html#sheen_green/1"},{"type":"function","title":"Fledex.Color.Names.sheen_green/2","doc":"","ref":"Fledex.Color.Names.html#sheen_green/2"},{"type":"function","title":"Fledex.Color.Names.shimmering_blush/1","doc":"Defines the color rgb(216, 135, 147).","ref":"Fledex.Color.Names.html#shimmering_blush/1"},{"type":"function","title":"Fledex.Color.Names.shimmering_blush/2","doc":"","ref":"Fledex.Color.Names.html#shimmering_blush/2"},{"type":"function","title":"Fledex.Color.Names.shiny_shamrock/1","doc":"Defines the color rgb(94, 165, 119).","ref":"Fledex.Color.Names.html#shiny_shamrock/1"},{"type":"function","title":"Fledex.Color.Names.shiny_shamrock/2","doc":"","ref":"Fledex.Color.Names.html#shiny_shamrock/2"},{"type":"function","title":"Fledex.Color.Names.shocking_pink/1","doc":"Defines the color rgb(252, 15, 191).","ref":"Fledex.Color.Names.html#shocking_pink/1"},{"type":"function","title":"Fledex.Color.Names.shocking_pink/2","doc":"","ref":"Fledex.Color.Names.html#shocking_pink/2"},{"type":"function","title":"Fledex.Color.Names.shocking_pink_crayola/1","doc":"Defines the color rgb(255, 112, 255).","ref":"Fledex.Color.Names.html#shocking_pink_crayola/1"},{"type":"function","title":"Fledex.Color.Names.shocking_pink_crayola/2","doc":"","ref":"Fledex.Color.Names.html#shocking_pink_crayola/2"},{"type":"function","title":"Fledex.Color.Names.sienna/1","doc":"Defines the color rgb(135, 45, 22).","ref":"Fledex.Color.Names.html#sienna/1"},{"type":"function","title":"Fledex.Color.Names.sienna/2","doc":"","ref":"Fledex.Color.Names.html#sienna/2"},{"type":"function","title":"Fledex.Color.Names.silver/1","doc":"Defines the color rgb(191, 191, 191).","ref":"Fledex.Color.Names.html#silver/1"},{"type":"function","title":"Fledex.Color.Names.silver/2","doc":"","ref":"Fledex.Color.Names.html#silver/2"},{"type":"function","title":"Fledex.Color.Names.silver_chalice/1","doc":"Defines the color rgb(170, 170, 170).","ref":"Fledex.Color.Names.html#silver_chalice/1"},{"type":"function","title":"Fledex.Color.Names.silver_chalice/2","doc":"","ref":"Fledex.Color.Names.html#silver_chalice/2"},{"type":"function","title":"Fledex.Color.Names.silver_crayola/1","doc":"Defines the color rgb(201, 191, 186).","ref":"Fledex.Color.Names.html#silver_crayola/1"},{"type":"function","title":"Fledex.Color.Names.silver_crayola/2","doc":"","ref":"Fledex.Color.Names.html#silver_crayola/2"},{"type":"function","title":"Fledex.Color.Names.silver_metallic/1","doc":"Defines the color rgb(170, 168, 173).","ref":"Fledex.Color.Names.html#silver_metallic/1"},{"type":"function","title":"Fledex.Color.Names.silver_metallic/2","doc":"","ref":"Fledex.Color.Names.html#silver_metallic/2"},{"type":"function","title":"Fledex.Color.Names.silver_pink/1","doc":"Defines the color rgb(196, 173, 173).","ref":"Fledex.Color.Names.html#silver_pink/1"},{"type":"function","title":"Fledex.Color.Names.silver_pink/2","doc":"","ref":"Fledex.Color.Names.html#silver_pink/2"},{"type":"function","title":"Fledex.Color.Names.silver_sand/1","doc":"Defines the color rgb(191, 193, 193).","ref":"Fledex.Color.Names.html#silver_sand/1"},{"type":"function","title":"Fledex.Color.Names.silver_sand/2","doc":"","ref":"Fledex.Color.Names.html#silver_sand/2"},{"type":"function","title":"Fledex.Color.Names.sinopia/1","doc":"Defines the color rgb(204, 63, 10).","ref":"Fledex.Color.Names.html#sinopia/1"},{"type":"function","title":"Fledex.Color.Names.sinopia/2","doc":"","ref":"Fledex.Color.Names.html#sinopia/2"},{"type":"function","title":"Fledex.Color.Names.sizzling_red/1","doc":"Defines the color rgb(255, 56, 84).","ref":"Fledex.Color.Names.html#sizzling_red/1"},{"type":"function","title":"Fledex.Color.Names.sizzling_red/2","doc":"","ref":"Fledex.Color.Names.html#sizzling_red/2"},{"type":"function","title":"Fledex.Color.Names.sizzling_sunrise/1","doc":"Defines the color rgb(255, 219, 0).","ref":"Fledex.Color.Names.html#sizzling_sunrise/1"},{"type":"function","title":"Fledex.Color.Names.sizzling_sunrise/2","doc":"","ref":"Fledex.Color.Names.html#sizzling_sunrise/2"},{"type":"function","title":"Fledex.Color.Names.skobeloff/1","doc":"Defines the color rgb(0, 114, 114).","ref":"Fledex.Color.Names.html#skobeloff/1"},{"type":"function","title":"Fledex.Color.Names.skobeloff/2","doc":"","ref":"Fledex.Color.Names.html#skobeloff/2"},{"type":"function","title":"Fledex.Color.Names.sky_blue/1","doc":"Defines the color rgb(135, 206, 234).","ref":"Fledex.Color.Names.html#sky_blue/1"},{"type":"function","title":"Fledex.Color.Names.sky_blue/2","doc":"","ref":"Fledex.Color.Names.html#sky_blue/2"},{"type":"function","title":"Fledex.Color.Names.sky_blue_crayola/1","doc":"Defines the color rgb(117, 214, 234).","ref":"Fledex.Color.Names.html#sky_blue_crayola/1"},{"type":"function","title":"Fledex.Color.Names.sky_blue_crayola/2","doc":"","ref":"Fledex.Color.Names.html#sky_blue_crayola/2"},{"type":"function","title":"Fledex.Color.Names.sky_magenta/1","doc":"Defines the color rgb(206, 112, 175).","ref":"Fledex.Color.Names.html#sky_magenta/1"},{"type":"function","title":"Fledex.Color.Names.sky_magenta/2","doc":"","ref":"Fledex.Color.Names.html#sky_magenta/2"},{"type":"function","title":"Fledex.Color.Names.slate_blue/1","doc":"Defines the color rgb(107, 89, 204).","ref":"Fledex.Color.Names.html#slate_blue/1"},{"type":"function","title":"Fledex.Color.Names.slate_blue/2","doc":"","ref":"Fledex.Color.Names.html#slate_blue/2"},{"type":"function","title":"Fledex.Color.Names.slate_gray/1","doc":"Defines the color rgb(112, 127, 142).","ref":"Fledex.Color.Names.html#slate_gray/1"},{"type":"function","title":"Fledex.Color.Names.slate_gray/2","doc":"","ref":"Fledex.Color.Names.html#slate_gray/2"},{"type":"function","title":"Fledex.Color.Names.slimy_green/1","doc":"Defines the color rgb(40, 150, 22).","ref":"Fledex.Color.Names.html#slimy_green/1"},{"type":"function","title":"Fledex.Color.Names.slimy_green/2","doc":"","ref":"Fledex.Color.Names.html#slimy_green/2"},{"type":"function","title":"Fledex.Color.Names.smitten/1","doc":"Defines the color rgb(198, 63, 135).","ref":"Fledex.Color.Names.html#smitten/1"},{"type":"function","title":"Fledex.Color.Names.smitten/2","doc":"","ref":"Fledex.Color.Names.html#smitten/2"},{"type":"function","title":"Fledex.Color.Names.smoky_black/1","doc":"Defines the color rgb(15, 12, 7).","ref":"Fledex.Color.Names.html#smoky_black/1"},{"type":"function","title":"Fledex.Color.Names.smoky_black/2","doc":"","ref":"Fledex.Color.Names.html#smoky_black/2"},{"type":"function","title":"Fledex.Color.Names.snow/1","doc":"Defines the color rgb(255, 249, 249).","ref":"Fledex.Color.Names.html#snow/1"},{"type":"function","title":"Fledex.Color.Names.snow/2","doc":"","ref":"Fledex.Color.Names.html#snow/2"},{"type":"function","title":"Fledex.Color.Names.solid_pink/1","doc":"Defines the color rgb(137, 56, 66).","ref":"Fledex.Color.Names.html#solid_pink/1"},{"type":"function","title":"Fledex.Color.Names.solid_pink/2","doc":"","ref":"Fledex.Color.Names.html#solid_pink/2"},{"type":"function","title":"Fledex.Color.Names.sonic_silver/1","doc":"Defines the color rgb(117, 117, 117).","ref":"Fledex.Color.Names.html#sonic_silver/1"},{"type":"function","title":"Fledex.Color.Names.sonic_silver/2","doc":"","ref":"Fledex.Color.Names.html#sonic_silver/2"},{"type":"function","title":"Fledex.Color.Names.space_cadet/1","doc":"Defines the color rgb(28, 40, 81).","ref":"Fledex.Color.Names.html#space_cadet/1"},{"type":"function","title":"Fledex.Color.Names.space_cadet/2","doc":"","ref":"Fledex.Color.Names.html#space_cadet/2"},{"type":"function","title":"Fledex.Color.Names.spanish_bistre/1","doc":"Defines the color rgb(127, 117, 51).","ref":"Fledex.Color.Names.html#spanish_bistre/1"},{"type":"function","title":"Fledex.Color.Names.spanish_bistre/2","doc":"","ref":"Fledex.Color.Names.html#spanish_bistre/2"},{"type":"function","title":"Fledex.Color.Names.spanish_blue/1","doc":"Defines the color rgb(0, 112, 183).","ref":"Fledex.Color.Names.html#spanish_blue/1"},{"type":"function","title":"Fledex.Color.Names.spanish_blue/2","doc":"","ref":"Fledex.Color.Names.html#spanish_blue/2"},{"type":"function","title":"Fledex.Color.Names.spanish_carmine/1","doc":"Defines the color rgb(209, 0, 71).","ref":"Fledex.Color.Names.html#spanish_carmine/1"},{"type":"function","title":"Fledex.Color.Names.spanish_carmine/2","doc":"","ref":"Fledex.Color.Names.html#spanish_carmine/2"},{"type":"function","title":"Fledex.Color.Names.spanish_gray/1","doc":"Defines the color rgb(153, 153, 153).","ref":"Fledex.Color.Names.html#spanish_gray/1"},{"type":"function","title":"Fledex.Color.Names.spanish_gray/2","doc":"","ref":"Fledex.Color.Names.html#spanish_gray/2"},{"type":"function","title":"Fledex.Color.Names.spanish_green/1","doc":"Defines the color rgb(0, 145, 79).","ref":"Fledex.Color.Names.html#spanish_green/1"},{"type":"function","title":"Fledex.Color.Names.spanish_green/2","doc":"","ref":"Fledex.Color.Names.html#spanish_green/2"},{"type":"function","title":"Fledex.Color.Names.spanish_orange/1","doc":"Defines the color rgb(232, 96, 0).","ref":"Fledex.Color.Names.html#spanish_orange/1"},{"type":"function","title":"Fledex.Color.Names.spanish_orange/2","doc":"","ref":"Fledex.Color.Names.html#spanish_orange/2"},{"type":"function","title":"Fledex.Color.Names.spanish_pink/1","doc":"Defines the color rgb(247, 191, 191).","ref":"Fledex.Color.Names.html#spanish_pink/1"},{"type":"function","title":"Fledex.Color.Names.spanish_pink/2","doc":"","ref":"Fledex.Color.Names.html#spanish_pink/2"},{"type":"function","title":"Fledex.Color.Names.spanish_red/1","doc":"Defines the color rgb(229, 0, 38).","ref":"Fledex.Color.Names.html#spanish_red/1"},{"type":"function","title":"Fledex.Color.Names.spanish_red/2","doc":"","ref":"Fledex.Color.Names.html#spanish_red/2"},{"type":"function","title":"Fledex.Color.Names.spanish_sky_blue/1","doc":"Defines the color rgb(0, 255, 255).","ref":"Fledex.Color.Names.html#spanish_sky_blue/1"},{"type":"function","title":"Fledex.Color.Names.spanish_sky_blue/2","doc":"","ref":"Fledex.Color.Names.html#spanish_sky_blue/2"},{"type":"function","title":"Fledex.Color.Names.spanish_violet/1","doc":"Defines the color rgb(76, 40, 130).","ref":"Fledex.Color.Names.html#spanish_violet/1"},{"type":"function","title":"Fledex.Color.Names.spanish_violet/2","doc":"","ref":"Fledex.Color.Names.html#spanish_violet/2"},{"type":"function","title":"Fledex.Color.Names.spanish_viridian/1","doc":"Defines the color rgb(0, 127, 91).","ref":"Fledex.Color.Names.html#spanish_viridian/1"},{"type":"function","title":"Fledex.Color.Names.spanish_viridian/2","doc":"","ref":"Fledex.Color.Names.html#spanish_viridian/2"},{"type":"function","title":"Fledex.Color.Names.spring_bud/1","doc":"Defines the color rgb(165, 252, 0).","ref":"Fledex.Color.Names.html#spring_bud/1"},{"type":"function","title":"Fledex.Color.Names.spring_bud/2","doc":"","ref":"Fledex.Color.Names.html#spring_bud/2"},{"type":"function","title":"Fledex.Color.Names.spring_frost/1","doc":"Defines the color rgb(135, 255, 40).","ref":"Fledex.Color.Names.html#spring_frost/1"},{"type":"function","title":"Fledex.Color.Names.spring_frost/2","doc":"","ref":"Fledex.Color.Names.html#spring_frost/2"},{"type":"function","title":"Fledex.Color.Names.spring_green/1","doc":"Defines the color rgb(0, 255, 127).","ref":"Fledex.Color.Names.html#spring_green/1"},{"type":"function","title":"Fledex.Color.Names.spring_green/2","doc":"","ref":"Fledex.Color.Names.html#spring_green/2"},{"type":"function","title":"Fledex.Color.Names.spring_green_crayola/1","doc":"Defines the color rgb(237, 234, 188).","ref":"Fledex.Color.Names.html#spring_green_crayola/1"},{"type":"function","title":"Fledex.Color.Names.spring_green_crayola/2","doc":"","ref":"Fledex.Color.Names.html#spring_green_crayola/2"},{"type":"function","title":"Fledex.Color.Names.st_patrick_s_blue/1","doc":"Defines the color rgb(35, 40, 122).","ref":"Fledex.Color.Names.html#st_patrick_s_blue/1"},{"type":"function","title":"Fledex.Color.Names.st_patrick_s_blue/2","doc":"","ref":"Fledex.Color.Names.html#st_patrick_s_blue/2"},{"type":"function","title":"Fledex.Color.Names.star_command_blue/1","doc":"Defines the color rgb(0, 122, 183).","ref":"Fledex.Color.Names.html#star_command_blue/1"},{"type":"function","title":"Fledex.Color.Names.star_command_blue/2","doc":"","ref":"Fledex.Color.Names.html#star_command_blue/2"},{"type":"function","title":"Fledex.Color.Names.steel_blue/1","doc":"Defines the color rgb(68, 130, 181).","ref":"Fledex.Color.Names.html#steel_blue/1"},{"type":"function","title":"Fledex.Color.Names.steel_blue/2","doc":"","ref":"Fledex.Color.Names.html#steel_blue/2"},{"type":"function","title":"Fledex.Color.Names.steel_pink/1","doc":"Defines the color rgb(204, 51, 204).","ref":"Fledex.Color.Names.html#steel_pink/1"},{"type":"function","title":"Fledex.Color.Names.steel_pink/2","doc":"","ref":"Fledex.Color.Names.html#steel_pink/2"},{"type":"function","title":"Fledex.Color.Names.stil_de_grain_yellow/1","doc":"Defines the color rgb(249, 216, 94).","ref":"Fledex.Color.Names.html#stil_de_grain_yellow/1"},{"type":"function","title":"Fledex.Color.Names.stil_de_grain_yellow/2","doc":"","ref":"Fledex.Color.Names.html#stil_de_grain_yellow/2"},{"type":"function","title":"Fledex.Color.Names.straw/1","doc":"Defines the color rgb(226, 216, 112).","ref":"Fledex.Color.Names.html#straw/1"},{"type":"function","title":"Fledex.Color.Names.straw/2","doc":"","ref":"Fledex.Color.Names.html#straw/2"},{"type":"function","title":"Fledex.Color.Names.strawberry/1","doc":"Defines the color rgb(249, 79, 84).","ref":"Fledex.Color.Names.html#strawberry/1"},{"type":"function","title":"Fledex.Color.Names.strawberry/2","doc":"","ref":"Fledex.Color.Names.html#strawberry/2"},{"type":"function","title":"Fledex.Color.Names.strawberry_blonde/1","doc":"Defines the color rgb(255, 147, 96).","ref":"Fledex.Color.Names.html#strawberry_blonde/1"},{"type":"function","title":"Fledex.Color.Names.strawberry_blonde/2","doc":"","ref":"Fledex.Color.Names.html#strawberry_blonde/2"},{"type":"function","title":"Fledex.Color.Names.strong_lime_green/1","doc":"Defines the color rgb(51, 204, 51).","ref":"Fledex.Color.Names.html#strong_lime_green/1"},{"type":"function","title":"Fledex.Color.Names.strong_lime_green/2","doc":"","ref":"Fledex.Color.Names.html#strong_lime_green/2"},{"type":"function","title":"Fledex.Color.Names.sugar_plum/1","doc":"Defines the color rgb(145, 79, 117).","ref":"Fledex.Color.Names.html#sugar_plum/1"},{"type":"function","title":"Fledex.Color.Names.sugar_plum/2","doc":"","ref":"Fledex.Color.Names.html#sugar_plum/2"},{"type":"function","title":"Fledex.Color.Names.sunglow/1","doc":"Defines the color rgb(255, 204, 51).","ref":"Fledex.Color.Names.html#sunglow/1"},{"type":"function","title":"Fledex.Color.Names.sunglow/2","doc":"","ref":"Fledex.Color.Names.html#sunglow/2"},{"type":"function","title":"Fledex.Color.Names.sunray/1","doc":"Defines the color rgb(226, 170, 86).","ref":"Fledex.Color.Names.html#sunray/1"},{"type":"function","title":"Fledex.Color.Names.sunray/2","doc":"","ref":"Fledex.Color.Names.html#sunray/2"},{"type":"function","title":"Fledex.Color.Names.sunset/1","doc":"Defines the color rgb(249, 214, 165).","ref":"Fledex.Color.Names.html#sunset/1"},{"type":"function","title":"Fledex.Color.Names.sunset/2","doc":"","ref":"Fledex.Color.Names.html#sunset/2"},{"type":"function","title":"Fledex.Color.Names.super_pink/1","doc":"Defines the color rgb(206, 107, 168).","ref":"Fledex.Color.Names.html#super_pink/1"},{"type":"function","title":"Fledex.Color.Names.super_pink/2","doc":"","ref":"Fledex.Color.Names.html#super_pink/2"},{"type":"function","title":"Fledex.Color.Names.sweet_brown/1","doc":"Defines the color rgb(168, 56, 48).","ref":"Fledex.Color.Names.html#sweet_brown/1"},{"type":"function","title":"Fledex.Color.Names.sweet_brown/2","doc":"","ref":"Fledex.Color.Names.html#sweet_brown/2"},{"type":"function","title":"Fledex.Color.Names.syracuse_orange/1","doc":"Defines the color rgb(211, 68, 0).","ref":"Fledex.Color.Names.html#syracuse_orange/1"},{"type":"function","title":"Fledex.Color.Names.syracuse_orange/2","doc":"","ref":"Fledex.Color.Names.html#syracuse_orange/2"},{"type":"function","title":"Fledex.Color.Names.tan/1","doc":"Defines the color rgb(209, 181, 140).","ref":"Fledex.Color.Names.html#tan/1"},{"type":"function","title":"Fledex.Color.Names.tan/2","doc":"","ref":"Fledex.Color.Names.html#tan/2"},{"type":"function","title":"Fledex.Color.Names.tan_crayola/1","doc":"Defines the color rgb(216, 153, 107).","ref":"Fledex.Color.Names.html#tan_crayola/1"},{"type":"function","title":"Fledex.Color.Names.tan_crayola/2","doc":"","ref":"Fledex.Color.Names.html#tan_crayola/2"},{"type":"function","title":"Fledex.Color.Names.tangerine/1","doc":"Defines the color rgb(242, 132, 0).","ref":"Fledex.Color.Names.html#tangerine/1"},{"type":"function","title":"Fledex.Color.Names.tangerine/2","doc":"","ref":"Fledex.Color.Names.html#tangerine/2"},{"type":"function","title":"Fledex.Color.Names.tango_pink/1","doc":"Defines the color rgb(226, 112, 122).","ref":"Fledex.Color.Names.html#tango_pink/1"},{"type":"function","title":"Fledex.Color.Names.tango_pink/2","doc":"","ref":"Fledex.Color.Names.html#tango_pink/2"},{"type":"function","title":"Fledex.Color.Names.tart_orange/1","doc":"Defines the color rgb(249, 76, 68).","ref":"Fledex.Color.Names.html#tart_orange/1"},{"type":"function","title":"Fledex.Color.Names.tart_orange/2","doc":"","ref":"Fledex.Color.Names.html#tart_orange/2"},{"type":"function","title":"Fledex.Color.Names.taupe/1","doc":"Defines the color rgb(71, 61, 51).","ref":"Fledex.Color.Names.html#taupe/1"},{"type":"function","title":"Fledex.Color.Names.taupe/2","doc":"","ref":"Fledex.Color.Names.html#taupe/2"},{"type":"function","title":"Fledex.Color.Names.taupe_gray/1","doc":"Defines the color rgb(140, 132, 137).","ref":"Fledex.Color.Names.html#taupe_gray/1"},{"type":"function","title":"Fledex.Color.Names.taupe_gray/2","doc":"","ref":"Fledex.Color.Names.html#taupe_gray/2"},{"type":"function","title":"Fledex.Color.Names.tea_green/1","doc":"Defines the color rgb(209, 239, 191).","ref":"Fledex.Color.Names.html#tea_green/1"},{"type":"function","title":"Fledex.Color.Names.tea_green/2","doc":"","ref":"Fledex.Color.Names.html#tea_green/2"},{"type":"function","title":"Fledex.Color.Names.tea_rose/1","doc":"Defines the color rgb(244, 193, 193).","ref":"Fledex.Color.Names.html#tea_rose/1"},{"type":"function","title":"Fledex.Color.Names.tea_rose/2","doc":"","ref":"Fledex.Color.Names.html#tea_rose/2"},{"type":"function","title":"Fledex.Color.Names.teal/1","doc":"Defines the color rgb(0, 127, 127).","ref":"Fledex.Color.Names.html#teal/1"},{"type":"function","title":"Fledex.Color.Names.teal/2","doc":"","ref":"Fledex.Color.Names.html#teal/2"},{"type":"function","title":"Fledex.Color.Names.teal_blue/1","doc":"Defines the color rgb(53, 117, 135).","ref":"Fledex.Color.Names.html#teal_blue/1"},{"type":"function","title":"Fledex.Color.Names.teal_blue/2","doc":"","ref":"Fledex.Color.Names.html#teal_blue/2"},{"type":"function","title":"Fledex.Color.Names.telemagenta/1","doc":"Defines the color rgb(206, 51, 117).","ref":"Fledex.Color.Names.html#telemagenta/1"},{"type":"function","title":"Fledex.Color.Names.telemagenta/2","doc":"","ref":"Fledex.Color.Names.html#telemagenta/2"},{"type":"function","title":"Fledex.Color.Names.tenne_tawny/1","doc":"Defines the color rgb(204, 86, 0).","ref":"Fledex.Color.Names.html#tenne_tawny/1"},{"type":"function","title":"Fledex.Color.Names.tenne_tawny/2","doc":"","ref":"Fledex.Color.Names.html#tenne_tawny/2"},{"type":"function","title":"Fledex.Color.Names.terra_cotta/1","doc":"Defines the color rgb(226, 114, 91).","ref":"Fledex.Color.Names.html#terra_cotta/1"},{"type":"function","title":"Fledex.Color.Names.terra_cotta/2","doc":"","ref":"Fledex.Color.Names.html#terra_cotta/2"},{"type":"function","title":"Fledex.Color.Names.thistle/1","doc":"Defines the color rgb(216, 191, 216).","ref":"Fledex.Color.Names.html#thistle/1"},{"type":"function","title":"Fledex.Color.Names.thistle/2","doc":"","ref":"Fledex.Color.Names.html#thistle/2"},{"type":"function","title":"Fledex.Color.Names.thulian_pink/1","doc":"Defines the color rgb(221, 112, 160).","ref":"Fledex.Color.Names.html#thulian_pink/1"},{"type":"function","title":"Fledex.Color.Names.thulian_pink/2","doc":"","ref":"Fledex.Color.Names.html#thulian_pink/2"},{"type":"function","title":"Fledex.Color.Names.tickle_me_pink/1","doc":"Defines the color rgb(252, 137, 170).","ref":"Fledex.Color.Names.html#tickle_me_pink/1"},{"type":"function","title":"Fledex.Color.Names.tickle_me_pink/2","doc":"","ref":"Fledex.Color.Names.html#tickle_me_pink/2"},{"type":"function","title":"Fledex.Color.Names.tiffany_blue/1","doc":"Defines the color rgb(10, 186, 181).","ref":"Fledex.Color.Names.html#tiffany_blue/1"},{"type":"function","title":"Fledex.Color.Names.tiffany_blue/2","doc":"","ref":"Fledex.Color.Names.html#tiffany_blue/2"},{"type":"function","title":"Fledex.Color.Names.timberwolf/1","doc":"Defines the color rgb(219, 214, 209).","ref":"Fledex.Color.Names.html#timberwolf/1"},{"type":"function","title":"Fledex.Color.Names.timberwolf/2","doc":"","ref":"Fledex.Color.Names.html#timberwolf/2"},{"type":"function","title":"Fledex.Color.Names.titanium_yellow/1","doc":"Defines the color rgb(237, 229, 0).","ref":"Fledex.Color.Names.html#titanium_yellow/1"},{"type":"function","title":"Fledex.Color.Names.titanium_yellow/2","doc":"","ref":"Fledex.Color.Names.html#titanium_yellow/2"},{"type":"function","title":"Fledex.Color.Names.tomato/1","doc":"Defines the color rgb(255, 99, 71).","ref":"Fledex.Color.Names.html#tomato/1"},{"type":"function","title":"Fledex.Color.Names.tomato/2","doc":"","ref":"Fledex.Color.Names.html#tomato/2"},{"type":"function","title":"Fledex.Color.Names.tourmaline/1","doc":"Defines the color rgb(135, 160, 168).","ref":"Fledex.Color.Names.html#tourmaline/1"},{"type":"function","title":"Fledex.Color.Names.tourmaline/2","doc":"","ref":"Fledex.Color.Names.html#tourmaline/2"},{"type":"function","title":"Fledex.Color.Names.tropical_rainforest/1","doc":"Defines the color rgb(0, 117, 94).","ref":"Fledex.Color.Names.html#tropical_rainforest/1"},{"type":"function","title":"Fledex.Color.Names.tropical_rainforest/2","doc":"","ref":"Fledex.Color.Names.html#tropical_rainforest/2"},{"type":"function","title":"Fledex.Color.Names.true_blue/1","doc":"Defines the color rgb(0, 114, 206).","ref":"Fledex.Color.Names.html#true_blue/1"},{"type":"function","title":"Fledex.Color.Names.true_blue/2","doc":"","ref":"Fledex.Color.Names.html#true_blue/2"},{"type":"function","title":"Fledex.Color.Names.trypan_blue/1","doc":"Defines the color rgb(28, 5, 178).","ref":"Fledex.Color.Names.html#trypan_blue/1"},{"type":"function","title":"Fledex.Color.Names.trypan_blue/2","doc":"","ref":"Fledex.Color.Names.html#trypan_blue/2"},{"type":"function","title":"Fledex.Color.Names.tufts_blue/1","doc":"Defines the color rgb(61, 142, 221).","ref":"Fledex.Color.Names.html#tufts_blue/1"},{"type":"function","title":"Fledex.Color.Names.tufts_blue/2","doc":"","ref":"Fledex.Color.Names.html#tufts_blue/2"},{"type":"function","title":"Fledex.Color.Names.tumbleweed/1","doc":"Defines the color rgb(221, 170, 135).","ref":"Fledex.Color.Names.html#tumbleweed/1"},{"type":"function","title":"Fledex.Color.Names.tumbleweed/2","doc":"","ref":"Fledex.Color.Names.html#tumbleweed/2"},{"type":"function","title":"Fledex.Color.Names.turquoise/1","doc":"Defines the color rgb(63, 224, 209).","ref":"Fledex.Color.Names.html#turquoise/1"},{"type":"function","title":"Fledex.Color.Names.turquoise/2","doc":"","ref":"Fledex.Color.Names.html#turquoise/2"},{"type":"function","title":"Fledex.Color.Names.turquoise_blue/1","doc":"Defines the color rgb(0, 255, 239).","ref":"Fledex.Color.Names.html#turquoise_blue/1"},{"type":"function","title":"Fledex.Color.Names.turquoise_blue/2","doc":"","ref":"Fledex.Color.Names.html#turquoise_blue/2"},{"type":"function","title":"Fledex.Color.Names.turquoise_green/1","doc":"Defines the color rgb(160, 214, 181).","ref":"Fledex.Color.Names.html#turquoise_green/1"},{"type":"function","title":"Fledex.Color.Names.turquoise_green/2","doc":"","ref":"Fledex.Color.Names.html#turquoise_green/2"},{"type":"function","title":"Fledex.Color.Names.turtle_green/1","doc":"Defines the color rgb(137, 153, 91).","ref":"Fledex.Color.Names.html#turtle_green/1"},{"type":"function","title":"Fledex.Color.Names.turtle_green/2","doc":"","ref":"Fledex.Color.Names.html#turtle_green/2"},{"type":"function","title":"Fledex.Color.Names.tuscan/1","doc":"Defines the color rgb(249, 214, 165).","ref":"Fledex.Color.Names.html#tuscan/1"},{"type":"function","title":"Fledex.Color.Names.tuscan/2","doc":"","ref":"Fledex.Color.Names.html#tuscan/2"},{"type":"function","title":"Fledex.Color.Names.tuscan_brown/1","doc":"Defines the color rgb(112, 79, 56).","ref":"Fledex.Color.Names.html#tuscan_brown/1"},{"type":"function","title":"Fledex.Color.Names.tuscan_brown/2","doc":"","ref":"Fledex.Color.Names.html#tuscan_brown/2"},{"type":"function","title":"Fledex.Color.Names.tuscan_red/1","doc":"Defines the color rgb(124, 71, 71).","ref":"Fledex.Color.Names.html#tuscan_red/1"},{"type":"function","title":"Fledex.Color.Names.tuscan_red/2","doc":"","ref":"Fledex.Color.Names.html#tuscan_red/2"},{"type":"function","title":"Fledex.Color.Names.tuscan_tan/1","doc":"Defines the color rgb(165, 122, 91).","ref":"Fledex.Color.Names.html#tuscan_tan/1"},{"type":"function","title":"Fledex.Color.Names.tuscan_tan/2","doc":"","ref":"Fledex.Color.Names.html#tuscan_tan/2"},{"type":"function","title":"Fledex.Color.Names.tuscany/1","doc":"Defines the color rgb(191, 153, 153).","ref":"Fledex.Color.Names.html#tuscany/1"},{"type":"function","title":"Fledex.Color.Names.tuscany/2","doc":"","ref":"Fledex.Color.Names.html#tuscany/2"},{"type":"function","title":"Fledex.Color.Names.twilight_lavender/1","doc":"Defines the color rgb(137, 73, 107).","ref":"Fledex.Color.Names.html#twilight_lavender/1"},{"type":"function","title":"Fledex.Color.Names.twilight_lavender/2","doc":"","ref":"Fledex.Color.Names.html#twilight_lavender/2"},{"type":"function","title":"Fledex.Color.Names.tyrian_purple/1","doc":"Defines the color rgb(102, 2, 61).","ref":"Fledex.Color.Names.html#tyrian_purple/1"},{"type":"function","title":"Fledex.Color.Names.tyrian_purple/2","doc":"","ref":"Fledex.Color.Names.html#tyrian_purple/2"},{"type":"function","title":"Fledex.Color.Names.ua_blue/1","doc":"Defines the color rgb(0, 51, 170).","ref":"Fledex.Color.Names.html#ua_blue/1"},{"type":"function","title":"Fledex.Color.Names.ua_blue/2","doc":"","ref":"Fledex.Color.Names.html#ua_blue/2"},{"type":"function","title":"Fledex.Color.Names.ua_red/1","doc":"Defines the color rgb(216, 0, 76).","ref":"Fledex.Color.Names.html#ua_red/1"},{"type":"function","title":"Fledex.Color.Names.ua_red/2","doc":"","ref":"Fledex.Color.Names.html#ua_red/2"},{"type":"function","title":"Fledex.Color.Names.ultra_pink/1","doc":"Defines the color rgb(255, 112, 255).","ref":"Fledex.Color.Names.html#ultra_pink/1"},{"type":"function","title":"Fledex.Color.Names.ultra_pink/2","doc":"","ref":"Fledex.Color.Names.html#ultra_pink/2"},{"type":"function","title":"Fledex.Color.Names.ultra_red/1","doc":"Defines the color rgb(252, 107, 132).","ref":"Fledex.Color.Names.html#ultra_red/1"},{"type":"function","title":"Fledex.Color.Names.ultra_red/2","doc":"","ref":"Fledex.Color.Names.html#ultra_red/2"},{"type":"function","title":"Fledex.Color.Names.ultramarine/1","doc":"Defines the color rgb(17, 10, 142).","ref":"Fledex.Color.Names.html#ultramarine/1"},{"type":"function","title":"Fledex.Color.Names.ultramarine/2","doc":"","ref":"Fledex.Color.Names.html#ultramarine/2"},{"type":"function","title":"Fledex.Color.Names.ultramarine_blue/1","doc":"Defines the color rgb(63, 102, 244).","ref":"Fledex.Color.Names.html#ultramarine_blue/1"},{"type":"function","title":"Fledex.Color.Names.ultramarine_blue/2","doc":"","ref":"Fledex.Color.Names.html#ultramarine_blue/2"},{"type":"function","title":"Fledex.Color.Names.umber/1","doc":"Defines the color rgb(99, 81, 71).","ref":"Fledex.Color.Names.html#umber/1"},{"type":"function","title":"Fledex.Color.Names.umber/2","doc":"","ref":"Fledex.Color.Names.html#umber/2"},{"type":"function","title":"Fledex.Color.Names.unbleached_silk/1","doc":"Defines the color rgb(255, 221, 201).","ref":"Fledex.Color.Names.html#unbleached_silk/1"},{"type":"function","title":"Fledex.Color.Names.unbleached_silk/2","doc":"","ref":"Fledex.Color.Names.html#unbleached_silk/2"},{"type":"function","title":"Fledex.Color.Names.united_nations_blue/1","doc":"Defines the color rgb(91, 145, 229).","ref":"Fledex.Color.Names.html#united_nations_blue/1"},{"type":"function","title":"Fledex.Color.Names.united_nations_blue/2","doc":"","ref":"Fledex.Color.Names.html#united_nations_blue/2"},{"type":"function","title":"Fledex.Color.Names.university_of_pennsylvania_red/1","doc":"Defines the color rgb(165, 0, 33).","ref":"Fledex.Color.Names.html#university_of_pennsylvania_red/1"},{"type":"function","title":"Fledex.Color.Names.university_of_pennsylvania_red/2","doc":"","ref":"Fledex.Color.Names.html#university_of_pennsylvania_red/2"},{"type":"function","title":"Fledex.Color.Names.unmellow_yellow/1","doc":"Defines the color rgb(255, 255, 102).","ref":"Fledex.Color.Names.html#unmellow_yellow/1"},{"type":"function","title":"Fledex.Color.Names.unmellow_yellow/2","doc":"","ref":"Fledex.Color.Names.html#unmellow_yellow/2"},{"type":"function","title":"Fledex.Color.Names.up_forest_green/1","doc":"Defines the color rgb(0, 68, 33).","ref":"Fledex.Color.Names.html#up_forest_green/1"},{"type":"function","title":"Fledex.Color.Names.up_forest_green/2","doc":"","ref":"Fledex.Color.Names.html#up_forest_green/2"},{"type":"function","title":"Fledex.Color.Names.up_maroon/1","doc":"Defines the color rgb(122, 17, 17).","ref":"Fledex.Color.Names.html#up_maroon/1"},{"type":"function","title":"Fledex.Color.Names.up_maroon/2","doc":"","ref":"Fledex.Color.Names.html#up_maroon/2"},{"type":"function","title":"Fledex.Color.Names.upsdell_red/1","doc":"Defines the color rgb(173, 33, 40).","ref":"Fledex.Color.Names.html#upsdell_red/1"},{"type":"function","title":"Fledex.Color.Names.upsdell_red/2","doc":"","ref":"Fledex.Color.Names.html#upsdell_red/2"},{"type":"function","title":"Fledex.Color.Names.uranian_blue/1","doc":"Defines the color rgb(175, 219, 244).","ref":"Fledex.Color.Names.html#uranian_blue/1"},{"type":"function","title":"Fledex.Color.Names.uranian_blue/2","doc":"","ref":"Fledex.Color.Names.html#uranian_blue/2"},{"type":"function","title":"Fledex.Color.Names.usafa_blue/1","doc":"Defines the color rgb(0, 79, 153).","ref":"Fledex.Color.Names.html#usafa_blue/1"},{"type":"function","title":"Fledex.Color.Names.usafa_blue/2","doc":"","ref":"Fledex.Color.Names.html#usafa_blue/2"},{"type":"function","title":"Fledex.Color.Names.van_dyke_brown/1","doc":"Defines the color rgb(102, 66, 40).","ref":"Fledex.Color.Names.html#van_dyke_brown/1"},{"type":"function","title":"Fledex.Color.Names.van_dyke_brown/2","doc":"","ref":"Fledex.Color.Names.html#van_dyke_brown/2"},{"type":"function","title":"Fledex.Color.Names.vanilla/1","doc":"Defines the color rgb(242, 229, 170).","ref":"Fledex.Color.Names.html#vanilla/1"},{"type":"function","title":"Fledex.Color.Names.vanilla/2","doc":"","ref":"Fledex.Color.Names.html#vanilla/2"},{"type":"function","title":"Fledex.Color.Names.vanilla_ice/1","doc":"Defines the color rgb(242, 142, 168).","ref":"Fledex.Color.Names.html#vanilla_ice/1"},{"type":"function","title":"Fledex.Color.Names.vanilla_ice/2","doc":"","ref":"Fledex.Color.Names.html#vanilla_ice/2"},{"type":"function","title":"Fledex.Color.Names.vegas_gold/1","doc":"Defines the color rgb(196, 178, 89).","ref":"Fledex.Color.Names.html#vegas_gold/1"},{"type":"function","title":"Fledex.Color.Names.vegas_gold/2","doc":"","ref":"Fledex.Color.Names.html#vegas_gold/2"},{"type":"function","title":"Fledex.Color.Names.venetian_red/1","doc":"Defines the color rgb(198, 7, 20).","ref":"Fledex.Color.Names.html#venetian_red/1"},{"type":"function","title":"Fledex.Color.Names.venetian_red/2","doc":"","ref":"Fledex.Color.Names.html#venetian_red/2"},{"type":"function","title":"Fledex.Color.Names.verdigris/1","doc":"Defines the color rgb(66, 178, 173).","ref":"Fledex.Color.Names.html#verdigris/1"},{"type":"function","title":"Fledex.Color.Names.verdigris/2","doc":"","ref":"Fledex.Color.Names.html#verdigris/2"},{"type":"function","title":"Fledex.Color.Names.vermilion2/1","doc":"Defines the color rgb(216, 56, 30).","ref":"Fledex.Color.Names.html#vermilion2/1"},{"type":"function","title":"Fledex.Color.Names.vermilion2/2","doc":"","ref":"Fledex.Color.Names.html#vermilion2/2"},{"type":"function","title":"Fledex.Color.Names.vermilion/1","doc":"Defines the color rgb(226, 66, 51).","ref":"Fledex.Color.Names.html#vermilion/1"},{"type":"function","title":"Fledex.Color.Names.vermilion/2","doc":"","ref":"Fledex.Color.Names.html#vermilion/2"},{"type":"function","title":"Fledex.Color.Names.veronica/1","doc":"Defines the color rgb(160, 33, 239).","ref":"Fledex.Color.Names.html#veronica/1"},{"type":"function","title":"Fledex.Color.Names.veronica/2","doc":"","ref":"Fledex.Color.Names.html#veronica/2"},{"type":"function","title":"Fledex.Color.Names.violet/1","doc":"Defines the color rgb(142, 0, 255).","ref":"Fledex.Color.Names.html#violet/1"},{"type":"function","title":"Fledex.Color.Names.violet/2","doc":"","ref":"Fledex.Color.Names.html#violet/2"},{"type":"function","title":"Fledex.Color.Names.violet_blue/1","doc":"Defines the color rgb(51, 73, 178).","ref":"Fledex.Color.Names.html#violet_blue/1"},{"type":"function","title":"Fledex.Color.Names.violet_blue/2","doc":"","ref":"Fledex.Color.Names.html#violet_blue/2"},{"type":"function","title":"Fledex.Color.Names.violet_blue_crayola/1","doc":"Defines the color rgb(117, 109, 198).","ref":"Fledex.Color.Names.html#violet_blue_crayola/1"},{"type":"function","title":"Fledex.Color.Names.violet_blue_crayola/2","doc":"","ref":"Fledex.Color.Names.html#violet_blue_crayola/2"},{"type":"function","title":"Fledex.Color.Names.violet_color_wheel/1","doc":"Defines the color rgb(127, 0, 255).","ref":"Fledex.Color.Names.html#violet_color_wheel/1"},{"type":"function","title":"Fledex.Color.Names.violet_color_wheel/2","doc":"","ref":"Fledex.Color.Names.html#violet_color_wheel/2"},{"type":"function","title":"Fledex.Color.Names.violet_crayola/1","doc":"Defines the color rgb(150, 61, 127).","ref":"Fledex.Color.Names.html#violet_crayola/1"},{"type":"function","title":"Fledex.Color.Names.violet_crayola/2","doc":"","ref":"Fledex.Color.Names.html#violet_crayola/2"},{"type":"function","title":"Fledex.Color.Names.violet_red/1","doc":"Defines the color rgb(247, 84, 147).","ref":"Fledex.Color.Names.html#violet_red/1"},{"type":"function","title":"Fledex.Color.Names.violet_red/2","doc":"","ref":"Fledex.Color.Names.html#violet_red/2"},{"type":"function","title":"Fledex.Color.Names.violet_red_perbang/1","doc":"Defines the color rgb(239, 89, 155).","ref":"Fledex.Color.Names.html#violet_red_perbang/1"},{"type":"function","title":"Fledex.Color.Names.violet_red_perbang/2","doc":"","ref":"Fledex.Color.Names.html#violet_red_perbang/2"},{"type":"function","title":"Fledex.Color.Names.violet_ryb/1","doc":"Defines the color rgb(135, 0, 175).","ref":"Fledex.Color.Names.html#violet_ryb/1"},{"type":"function","title":"Fledex.Color.Names.violet_ryb/2","doc":"","ref":"Fledex.Color.Names.html#violet_ryb/2"},{"type":"function","title":"Fledex.Color.Names.violet_web/1","doc":"Defines the color rgb(237, 130, 237).","ref":"Fledex.Color.Names.html#violet_web/1"},{"type":"function","title":"Fledex.Color.Names.violet_web/2","doc":"","ref":"Fledex.Color.Names.html#violet_web/2"},{"type":"function","title":"Fledex.Color.Names.viridian/1","doc":"Defines the color rgb(63, 130, 109).","ref":"Fledex.Color.Names.html#viridian/1"},{"type":"function","title":"Fledex.Color.Names.viridian/2","doc":"","ref":"Fledex.Color.Names.html#viridian/2"},{"type":"function","title":"Fledex.Color.Names.viridian_green/1","doc":"Defines the color rgb(0, 150, 153).","ref":"Fledex.Color.Names.html#viridian_green/1"},{"type":"function","title":"Fledex.Color.Names.viridian_green/2","doc":"","ref":"Fledex.Color.Names.html#viridian_green/2"},{"type":"function","title":"Fledex.Color.Names.vivid_burgundy/1","doc":"Defines the color rgb(158, 28, 53).","ref":"Fledex.Color.Names.html#vivid_burgundy/1"},{"type":"function","title":"Fledex.Color.Names.vivid_burgundy/2","doc":"","ref":"Fledex.Color.Names.html#vivid_burgundy/2"},{"type":"function","title":"Fledex.Color.Names.vivid_sky_blue/1","doc":"Defines the color rgb(0, 204, 255).","ref":"Fledex.Color.Names.html#vivid_sky_blue/1"},{"type":"function","title":"Fledex.Color.Names.vivid_sky_blue/2","doc":"","ref":"Fledex.Color.Names.html#vivid_sky_blue/2"},{"type":"function","title":"Fledex.Color.Names.vivid_tangerine/1","doc":"Defines the color rgb(255, 160, 137).","ref":"Fledex.Color.Names.html#vivid_tangerine/1"},{"type":"function","title":"Fledex.Color.Names.vivid_tangerine/2","doc":"","ref":"Fledex.Color.Names.html#vivid_tangerine/2"},{"type":"function","title":"Fledex.Color.Names.vivid_violet/1","doc":"Defines the color rgb(158, 0, 255).","ref":"Fledex.Color.Names.html#vivid_violet/1"},{"type":"function","title":"Fledex.Color.Names.vivid_violet/2","doc":"","ref":"Fledex.Color.Names.html#vivid_violet/2"},{"type":"function","title":"Fledex.Color.Names.volt/1","doc":"Defines the color rgb(204, 255, 0).","ref":"Fledex.Color.Names.html#volt/1"},{"type":"function","title":"Fledex.Color.Names.volt/2","doc":"","ref":"Fledex.Color.Names.html#volt/2"},{"type":"function","title":"Fledex.Color.Names.warm_black/1","doc":"Defines the color rgb(0, 66, 66).","ref":"Fledex.Color.Names.html#warm_black/1"},{"type":"function","title":"Fledex.Color.Names.warm_black/2","doc":"","ref":"Fledex.Color.Names.html#warm_black/2"},{"type":"function","title":"Fledex.Color.Names.weezy_blue/1","doc":"Defines the color rgb(22, 155, 204).","ref":"Fledex.Color.Names.html#weezy_blue/1"},{"type":"function","title":"Fledex.Color.Names.weezy_blue/2","doc":"","ref":"Fledex.Color.Names.html#weezy_blue/2"},{"type":"function","title":"Fledex.Color.Names.wheat/1","doc":"Defines the color rgb(244, 221, 178).","ref":"Fledex.Color.Names.html#wheat/1"},{"type":"function","title":"Fledex.Color.Names.wheat/2","doc":"","ref":"Fledex.Color.Names.html#wheat/2"},{"type":"function","title":"Fledex.Color.Names.white/1","doc":"Defines the color rgb(255, 255, 255).","ref":"Fledex.Color.Names.html#white/1"},{"type":"function","title":"Fledex.Color.Names.white/2","doc":"","ref":"Fledex.Color.Names.html#white/2"},{"type":"function","title":"Fledex.Color.Names.wild_blue_yonder/1","doc":"Defines the color rgb(163, 173, 209).","ref":"Fledex.Color.Names.html#wild_blue_yonder/1"},{"type":"function","title":"Fledex.Color.Names.wild_blue_yonder/2","doc":"","ref":"Fledex.Color.Names.html#wild_blue_yonder/2"},{"type":"function","title":"Fledex.Color.Names.wild_orchid/1","doc":"Defines the color rgb(211, 112, 163).","ref":"Fledex.Color.Names.html#wild_orchid/1"},{"type":"function","title":"Fledex.Color.Names.wild_orchid/2","doc":"","ref":"Fledex.Color.Names.html#wild_orchid/2"},{"type":"function","title":"Fledex.Color.Names.wild_strawberry/1","doc":"Defines the color rgb(255, 66, 163).","ref":"Fledex.Color.Names.html#wild_strawberry/1"},{"type":"function","title":"Fledex.Color.Names.wild_strawberry/2","doc":"","ref":"Fledex.Color.Names.html#wild_strawberry/2"},{"type":"function","title":"Fledex.Color.Names.wild_watermelon/1","doc":"Defines the color rgb(252, 107, 132).","ref":"Fledex.Color.Names.html#wild_watermelon/1"},{"type":"function","title":"Fledex.Color.Names.wild_watermelon/2","doc":"","ref":"Fledex.Color.Names.html#wild_watermelon/2"},{"type":"function","title":"Fledex.Color.Names.windsor_tan/1","doc":"Defines the color rgb(165, 84, 2).","ref":"Fledex.Color.Names.html#windsor_tan/1"},{"type":"function","title":"Fledex.Color.Names.windsor_tan/2","doc":"","ref":"Fledex.Color.Names.html#windsor_tan/2"},{"type":"function","title":"Fledex.Color.Names.wine/1","doc":"Defines the color rgb(114, 45, 56).","ref":"Fledex.Color.Names.html#wine/1"},{"type":"function","title":"Fledex.Color.Names.wine/2","doc":"","ref":"Fledex.Color.Names.html#wine/2"},{"type":"function","title":"Fledex.Color.Names.wine_dregs/1","doc":"Defines the color rgb(102, 48, 71).","ref":"Fledex.Color.Names.html#wine_dregs/1"},{"type":"function","title":"Fledex.Color.Names.wine_dregs/2","doc":"","ref":"Fledex.Color.Names.html#wine_dregs/2"},{"type":"function","title":"Fledex.Color.Names.winter_sky/1","doc":"Defines the color rgb(255, 0, 124).","ref":"Fledex.Color.Names.html#winter_sky/1"},{"type":"function","title":"Fledex.Color.Names.winter_sky/2","doc":"","ref":"Fledex.Color.Names.html#winter_sky/2"},{"type":"function","title":"Fledex.Color.Names.wintergreen_dream/1","doc":"Defines the color rgb(86, 135, 124).","ref":"Fledex.Color.Names.html#wintergreen_dream/1"},{"type":"function","title":"Fledex.Color.Names.wintergreen_dream/2","doc":"","ref":"Fledex.Color.Names.html#wintergreen_dream/2"},{"type":"function","title":"Fledex.Color.Names.wisteria/1","doc":"Defines the color rgb(201, 160, 219).","ref":"Fledex.Color.Names.html#wisteria/1"},{"type":"function","title":"Fledex.Color.Names.wisteria/2","doc":"","ref":"Fledex.Color.Names.html#wisteria/2"},{"type":"function","title":"Fledex.Color.Names.wood_brown/1","doc":"Defines the color rgb(193, 153, 107).","ref":"Fledex.Color.Names.html#wood_brown/1"},{"type":"function","title":"Fledex.Color.Names.wood_brown/2","doc":"","ref":"Fledex.Color.Names.html#wood_brown/2"},{"type":"function","title":"Fledex.Color.Names.xanadu/1","doc":"Defines the color rgb(114, 135, 119).","ref":"Fledex.Color.Names.html#xanadu/1"},{"type":"function","title":"Fledex.Color.Names.xanadu/2","doc":"","ref":"Fledex.Color.Names.html#xanadu/2"},{"type":"function","title":"Fledex.Color.Names.xanthic/1","doc":"Defines the color rgb(237, 237, 10).","ref":"Fledex.Color.Names.html#xanthic/1"},{"type":"function","title":"Fledex.Color.Names.xanthic/2","doc":"","ref":"Fledex.Color.Names.html#xanthic/2"},{"type":"function","title":"Fledex.Color.Names.xanthous/1","doc":"Defines the color rgb(242, 181, 45).","ref":"Fledex.Color.Names.html#xanthous/1"},{"type":"function","title":"Fledex.Color.Names.xanthous/2","doc":"","ref":"Fledex.Color.Names.html#xanthous/2"},{"type":"function","title":"Fledex.Color.Names.yale_blue/1","doc":"Defines the color rgb(0, 53, 107).","ref":"Fledex.Color.Names.html#yale_blue/1"},{"type":"function","title":"Fledex.Color.Names.yale_blue/2","doc":"","ref":"Fledex.Color.Names.html#yale_blue/2"},{"type":"function","title":"Fledex.Color.Names.yellow/1","doc":"Defines the color rgb(255, 255, 0).","ref":"Fledex.Color.Names.html#yellow/1"},{"type":"function","title":"Fledex.Color.Names.yellow/2","doc":"","ref":"Fledex.Color.Names.html#yellow/2"},{"type":"function","title":"Fledex.Color.Names.yellow_crayola/1","doc":"Defines the color rgb(252, 232, 130).","ref":"Fledex.Color.Names.html#yellow_crayola/1"},{"type":"function","title":"Fledex.Color.Names.yellow_crayola/2","doc":"","ref":"Fledex.Color.Names.html#yellow_crayola/2"},{"type":"function","title":"Fledex.Color.Names.yellow_green/1","doc":"Defines the color rgb(153, 204, 51).","ref":"Fledex.Color.Names.html#yellow_green/1"},{"type":"function","title":"Fledex.Color.Names.yellow_green/2","doc":"","ref":"Fledex.Color.Names.html#yellow_green/2"},{"type":"function","title":"Fledex.Color.Names.yellow_green_color_wheel/1","doc":"Defines the color rgb(48, 178, 25).","ref":"Fledex.Color.Names.html#yellow_green_color_wheel/1"},{"type":"function","title":"Fledex.Color.Names.yellow_green_color_wheel/2","doc":"","ref":"Fledex.Color.Names.html#yellow_green_color_wheel/2"},{"type":"function","title":"Fledex.Color.Names.yellow_green_crayola/1","doc":"Defines the color rgb(196, 226, 132).","ref":"Fledex.Color.Names.html#yellow_green_crayola/1"},{"type":"function","title":"Fledex.Color.Names.yellow_green_crayola/2","doc":"","ref":"Fledex.Color.Names.html#yellow_green_crayola/2"},{"type":"function","title":"Fledex.Color.Names.yellow_munsell/1","doc":"Defines the color rgb(239, 204, 0).","ref":"Fledex.Color.Names.html#yellow_munsell/1"},{"type":"function","title":"Fledex.Color.Names.yellow_munsell/2","doc":"","ref":"Fledex.Color.Names.html#yellow_munsell/2"},{"type":"function","title":"Fledex.Color.Names.yellow_ncs/1","doc":"Defines the color rgb(255, 211, 0).","ref":"Fledex.Color.Names.html#yellow_ncs/1"},{"type":"function","title":"Fledex.Color.Names.yellow_ncs/2","doc":"","ref":"Fledex.Color.Names.html#yellow_ncs/2"},{"type":"function","title":"Fledex.Color.Names.yellow_orange/1","doc":"Defines the color rgb(255, 173, 66).","ref":"Fledex.Color.Names.html#yellow_orange/1"},{"type":"function","title":"Fledex.Color.Names.yellow_orange/2","doc":"","ref":"Fledex.Color.Names.html#yellow_orange/2"},{"type":"function","title":"Fledex.Color.Names.yellow_orange_color_wheel/1","doc":"Defines the color rgb(255, 147, 5).","ref":"Fledex.Color.Names.html#yellow_orange_color_wheel/1"},{"type":"function","title":"Fledex.Color.Names.yellow_orange_color_wheel/2","doc":"","ref":"Fledex.Color.Names.html#yellow_orange_color_wheel/2"},{"type":"function","title":"Fledex.Color.Names.yellow_pantone/1","doc":"Defines the color rgb(255, 221, 0).","ref":"Fledex.Color.Names.html#yellow_pantone/1"},{"type":"function","title":"Fledex.Color.Names.yellow_pantone/2","doc":"","ref":"Fledex.Color.Names.html#yellow_pantone/2"},{"type":"function","title":"Fledex.Color.Names.yellow_process/1","doc":"Defines the color rgb(255, 239, 0).","ref":"Fledex.Color.Names.html#yellow_process/1"},{"type":"function","title":"Fledex.Color.Names.yellow_process/2","doc":"","ref":"Fledex.Color.Names.html#yellow_process/2"},{"type":"function","title":"Fledex.Color.Names.yellow_ryb/1","doc":"Defines the color rgb(255, 255, 51).","ref":"Fledex.Color.Names.html#yellow_ryb/1"},{"type":"function","title":"Fledex.Color.Names.yellow_ryb/2","doc":"","ref":"Fledex.Color.Names.html#yellow_ryb/2"},{"type":"function","title":"Fledex.Color.Names.yellow_sunshine/1","doc":"Defines the color rgb(255, 247, 0).","ref":"Fledex.Color.Names.html#yellow_sunshine/1"},{"type":"function","title":"Fledex.Color.Names.yellow_sunshine/2","doc":"","ref":"Fledex.Color.Names.html#yellow_sunshine/2"},{"type":"function","title":"Fledex.Color.Names.yinmn_blue/1","doc":"Defines the color rgb(45, 79, 142).","ref":"Fledex.Color.Names.html#yinmn_blue/1"},{"type":"function","title":"Fledex.Color.Names.yinmn_blue/2","doc":"","ref":"Fledex.Color.Names.html#yinmn_blue/2"},{"type":"function","title":"Fledex.Color.Names.zaffre/1","doc":"Defines the color rgb(0, 20, 168).","ref":"Fledex.Color.Names.html#zaffre/1"},{"type":"function","title":"Fledex.Color.Names.zaffre/2","doc":"","ref":"Fledex.Color.Names.html#zaffre/2"},{"type":"function","title":"Fledex.Color.Names.zomp/1","doc":"Defines the color rgb(56, 165, 142).","ref":"Fledex.Color.Names.html#zomp/1"},{"type":"function","title":"Fledex.Color.Names.zomp/2","doc":"","ref":"Fledex.Color.Names.html#zomp/2"},{"type":"type","title":"Fledex.Color.Names.color_names_t/0","doc":"The allowed color names","ref":"Fledex.Color.Names.html#t:color_names_t/0"},{"type":"type","title":"Fledex.Color.Names.color_props_t/0","doc":"The different properties that can be interrogated from a named color","ref":"Fledex.Color.Names.html#t:color_props_t/0"},{"type":"type","title":"Fledex.Color.Names.color_struct_t/0","doc":"The structure of a named color with all it's attributes.","ref":"Fledex.Color.Names.html#t:color_struct_t/0"},{"type":"type","title":"Fledex.Color.Names.color_vals_t/0","doc":"The different values that can be returned when interrogating for some named color properties","ref":"Fledex.Color.Names.html#t:color_vals_t/0"},{"type":"module","title":"Fledex.Color.Types","doc":"","ref":"Fledex.Color.Types.html"},{"type":"type","title":"Fledex.Color.Types.color/0","doc":"","ref":"Fledex.Color.Types.html#t:color/0"},{"type":"type","title":"Fledex.Color.Types.color_any/0","doc":"","ref":"Fledex.Color.Types.html#t:color_any/0"},{"type":"type","title":"Fledex.Color.Types.colorint/0","doc":"","ref":"Fledex.Color.Types.html#t:colorint/0"},{"type":"type","title":"Fledex.Color.Types.hsl/0","doc":"","ref":"Fledex.Color.Types.html#t:hsl/0"},{"type":"type","title":"Fledex.Color.Types.hsv/0","doc":"","ref":"Fledex.Color.Types.html#t:hsv/0"},{"type":"type","title":"Fledex.Color.Types.rgb/0","doc":"","ref":"Fledex.Color.Types.html#t:rgb/0"},{"type":"module","title":"Fledex.Color.Utils","doc":"Most functions are reimplementations from FastLED. Here is a detailed\nexplanation of those functions:\nhttps://github.com/FastLED/FastLED/wiki/High-performance-math","ref":"Fledex.Color.Utils.html"},{"type":"function","title":"Fledex.Color.Utils.add_subpixels/1","doc":"This function adds the given subpixels `[{r1, g1, b1}, {r2, g2, b2}, ...]` together.\nThe result {r1+r2+..., g1+g2+..., b1+b2+...} is probably outside of the standard\n8bit range and will have to be rescaled","ref":"Fledex.Color.Utils.html#add_subpixels/1"},{"type":"function","title":"Fledex.Color.Utils.avg/1","doc":"This function calculates the average of the given \"rgb\" values","ref":"Fledex.Color.Utils.html#avg/1"},{"type":"function","title":"Fledex.Color.Utils.cap/2","doc":"This function combines (adds) the given rgb values and caps them to the given range\n(by default 0..255)","ref":"Fledex.Color.Utils.html#cap/2"},{"type":"function","title":"Fledex.Color.Utils.frac8/2","doc":"calculate a fraction mapped to a 8bit range","ref":"Fledex.Color.Utils.html#frac8/2"},{"type":"function","title":"Fledex.Color.Utils.nscale8/3","doc":"same as #scale8, except that it does it for all 3 rgb value\nat the same time.","ref":"Fledex.Color.Utils.html#nscale8/3"},{"type":"function","title":"Fledex.Color.Utils.scale8/3","doc":"This function scales a value into a specific range. the video parameter\nindicates whether the returned value should be correct to not return 0","ref":"Fledex.Color.Utils.html#scale8/3"},{"type":"function","title":"Fledex.Color.Utils.split_into_subpixels/1","doc":"Splits the rgb-integer value into it's subpixels and returns an\n`{r, g, b}` tupel","ref":"Fledex.Color.Utils.html#split_into_subpixels/1"},{"type":"function","title":"Fledex.Color.Utils.to_colorint/1","doc":"This function converts a color to a single (color) integer value","ref":"Fledex.Color.Utils.html#to_colorint/1"},{"type":"function","title":"Fledex.Color.Utils.to_rgb/1","doc":"This function splits a color into it's rgb components","ref":"Fledex.Color.Utils.html#to_rgb/1"},{"type":"extras","title":"Fledex","doc":"# Fledex\n\nFledex is a small [Elixir](https://elixir-lang.org/) library It really is intended for educational purposes.\nIt is written for a RaspberryPi Zero W running [Nerves](https://nerves-project.org/) especially with a [Nerves-Livebook](https://hexdocs.pm/nerves/getting-started.html#nerves-livebook). \nThe intent of the library is to simplify the programming of a programmable LED strip (currently based on a [WS2801 chip](https://cdn-shop.adafruit.com/datasheets/WS2801.pdf)) and thereby to make it accessible even for kids.\n\nThe idea is to introduce similarly easy concepts for the programming of LEDs as [SonicPi](https://sonic-pi.net/) did for music. The library was developped in collaboration with my son and hopefully we can push it to become better over time. For my son the goal will be to connect the LEDs to some music and to animate the LEDs depending on the beat.\n\nQuite a lot of inspiration came from the [FastLED project](http://fastled.io/) and quite a few of their functions got reimplemented in Elixir. If you look at the implementation of some of those functions you might want to look at their comments.","ref":"readme-1.html"},{"type":"extras","title":"Installation - Fledex","doc":"The library is [available in Hex](https://hex.pm/packages/fledex), the package can be installed\nby adding `:fledex` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:fledex, \"~> 0.2.0\"}\n  ]\nend\n```\n\nOnce in you have installed the library and run your usual `mix deps.get` you can start the LedDriver Server by calling:\n```elixir\nconfig = %{\n  # here comes your configuration\n}\n{:ok, pid} = LedStrip.start_link(config)\n```\n\nThe `Fledex.LedStrip` should have quite reasonable defaults to get you started (a `Fledex.Driver.Impl.Null` driver is used by default)\n\nYour interaction with the LedDriver should mainly happen through the Leds module. To set the first 3 LEDs (of a 50 LED strip) to red, green and blue you would do the following (here the [color names](https://www.ditig.com/256-colors-cheat-sheet) are used, but you could have used the hex values `0xFF0000`, `0x00FF00`, and `0x0000FF` too):\n```elixir\nLedStrip.define_namespace(:default)\nLeds.leds(50)\n  |> Leds.light(:red)\n  |> Leds.light(:green1) \n  |> Leds.light(:blue)\n  |> Leds.send() # :default namespace is used as default\n```\nAll other LEDs would be set to off\n\nThe above approach is rather cumbersome with a lot of LEDs, and would be even more difficult if you want to animate it. Thus, instead of managing the LED strip yourself, you should use the Fledex DSL.\n\nTake a look at the [Livebook examples](README.md#livebook) on how to use the DSL","ref":"readme-1.html#installation"},{"type":"extras","title":"Livebook - Fledex","doc":"You can find some [livebooks](livebooks/README.md) files that show you how to use the library in a notebook (with and without hardware). You should be able to do most of your development on a computer (emulating the LED strip with a `Fledex.Driver.Impl.Kino`) before adjusting it to the real hardware (with the `Fledex.Driver.Impl.Spi`). On real hardware you can even run it with serveral drivers at the same time.","ref":"readme-1.html#livebook"},{"type":"extras","title":"Known Limitations - Fledex","doc":"If you want to run this library in nerves-livebook, you currently have to compile your own livebook with the library included in your `mix.exs` file, since you can't add any libraries that are not already bundled.","ref":"readme-1.html#known-limitations"},{"type":"extras","title":"Overview","doc":"# Overview\nThis document gives a rough overview over the architecture of Fledex. We first will \nlook at the low level aspects (the different drivers) and then work our way up the \nstack.\n\n![Architecture Diagram](./architecture.drawio.png)\n\n# The drivers\nThe main interface to talk to the \"hardware\" is the `Fledex.LedStrip`. It takes the\n`Fledex.Leds` definitions merges them and then passes the result to the actual \nhardware drivers. It plays about the same role as a window server in operating system.\n\nThe `Fledex.LedStrip` allows to define serveral namespaces that can have their own \nled definitions and that are only merged together at \"display\" time. This is similar \nin defining several windows in a window server. They all end up on the same display.\n\nThe `Fledex.LedStrip` does not really know how to talk to the actual hardware, but \nleaves this to the hardware spectific `Fledex.Driver.Driver`s. It's possible to \nregister several drivers at the same time.\n\nCurrently there are 4 drivers available:\n* `Spi` is the main driver for talking to a real \n  [led strip with a ws2801 chip](https://www.amazon.com/s?k=ws2801) over the spi bus\n* `Kino` is a driver that is very convenient when working with a \n  [Livebook](https://livebook.dev/) to emulate an led strip.\n* `Logger` is a driver that dumps the data to a logger.\n* `Null` is a driver that acts similar to `/dev/null`, i.e. doesn't do anyting with the\n  data. This can be very convenient for running some tests.\n\n# The Leds\nThe `Leds` is an easy way to define a set of Leds. This module provides the \npossibility to specify individual leds by integer/name/rgb-values, by a generator \nfunction (like `rainbow/2`, or `gradient/2`), or by combining various `Leds` \ndefinitions into a single definition.\n\nThe `Leds` are not bound to a specific led strip (and namespace), but can be send \nto one by calling the `send()` function with the appropriate parameters. For \nconvenience it's possible to bind it already during creation time to a specific \nled strip and namespace.\n\n# The Animations\nTo define individual `Leds` is nice, but it would be even nicer, if it would be \npossible to animate the `Leds`. This is where the `Animator` comes in. It allows \nto define `Leds` and vary them through some triggers (like a timer/counter). \n\nIt's possible to define this simply through a sequence of `Leds` definitions \nfollowed by a `send()` and some `Process.sleep()`, but that approach would have \nseveral limitations.\n\nThe `Animator` is a `GenServer` that loops through the animation function and allows\nto modify the animation between loops.\n\nThe various `Fledex.Animation.Animator`s can be managed through a \n`Fledex.Animation.Manager`. It allows to create, redefine, and destroy animations \n(i.e.`Fledex.Animation.Animator`s) through a single configuration.\n\n# The Fledex DSL\nThe ultimate goal is to define a `Fledex` DSL that can configure the \n`Fledex.Animation.Manager` and update annimations on the fly.\n\nIn the above diagram an example is shown on how such a DSL might look like. \n\n# The Triggers\n\nThe `Fledex.LedStrip` is publishing via `Fledex.Util.PubSub` an event (a trigger) \nthat gets picked up by the `Fledex.Animation.Animator`s to change their animation. \nThe trigger can not only be created by the driver, but also by external events. The\ndifference is that only the triggers from the driver is used by the `Fledex.Animation.\nAnimator`s to redefine the animation. All other triggers are collected over time and\ncan be used when updating the animation. \n\nFor example: we want to be able to check the current temperature in regular interval \nand trigger a re-animation to adjust the \"display\" depending on the temperature.\n\n# Final Notes","ref":"architecture.html"},{"type":"extras","title":"Naming - Overview","doc":"The led naming, the namespace naming, and the `Fledex.LedStrip` server naming should \nall be driven by the `Fledex`  DSL. Even though it would be possible to have different\nnames it helps to align them. The `led_strip` name becomes the `Fledex.LedStrip` server\nname. The `animation` name becomes the namespace name and combined with the `led_strip`\nname the `Fledex.Animation.Animator` server name.","ref":"architecture.html#naming"},{"type":"extras","title":"Intro","doc":"# Intro\nThis is a description of the livebooks in this folder. The examples are structured in such a way that we slowly walk up the abstraction stack. From very low level to a high level language. If are not interested in the technical details, the motivations, and the decisions then you probably want to only look livebook [#1](livebooks/README.md#1-first-steps-with-an-led-strip) (to set up your LED strip correctly) and [#6](livebooks/README.md#6-fledex-dsl) (to define your animations). Only the whole set will give you, however, a good overview.\n\nIt is recommended that you look at the different livebooks in parallel to the [Architecture Overview](../docs/architecture.md).\n\n# 1. First steps with an LED strip\nThe first livebook has nothing to do with the Fledex library, but describes on how to set up the [RaspberryPi](https://www.raspberrypi.org/), how to connect the LED strip to it and how we can communicate with it via the SPI bus. It also shows how easy it is to communicate to an LED strip. At the same time it is cumbersome, due the sheer number of LEDs that can be addressed. This example is good to\n\n- ensure that everything everything is set up correctly (before we bring the complexity of a library in)\n- get an understanding on why Fledex was created in the first place to make the definition of the strip easier\n\nWe don't really want to work on this level\n\n# 2. Fledex: First steps\nThe first steps with the Fledex library. The example shows how the LED strip can be emulated with\nthe Kino driver, but it does contain commented out code for the SPI driver too to send it to a\nreal LED strip.\nIn the driver configs we define an error correction, since the 5050 chips have too intensive green\nand blue LEDs that need to be compensated to have a more natural look. The Kino driver does not\nrequire such a compensation, even though it is possible to define one too.\nBy changing the definition of our LEDs we can also create some simple animations\n\nThis example works still on a very low level, one that we do not want use. \n\n# 2b. Fledex: How to define LEDs\nIn this livebook we take a closer look how we can define sequences of leds. We start with a brief look at how we can define colors, but we'll take a more detailed look at colors\nin __3b. Fledex: More about colors__. Then we'll look at sub-sequences and how to\ngenerate sequences with functions.\n\n# 3. Fledex: Animations\nIn this livebook we look how animations can be defined, this is the next step(s) above the `Fledex.LedStrip`. The `Fledex.Animation.Manager` is the level that we want to operate on and the following examples will use what we have explored here and will create some concrete examples:\n\n* a clock (using local information) and \n* a weather indicator (collecting data via the internet)\n\n# 3b. Fledex: More about colors\nHere we talk a bit more about colors and even color corrections\n\n# 4. Fledex: Clock example\nThis is the first \"meaningful\" example that displays the current time on the LED strip. We define 4 \"animations\" for:\n\n* the indicators (otherwise it becomes hard to read the time), \n* the seconds (red), \n* the minutes (green), and \n* the hours (blue).\n\nThis example demonstrates how easy we do things when we can pull the information whenever needed. The current time is something that is readily available on the device and can be called as often as we want. Hence we can call this function every time we paint the strip.\n\n**CAUTION:** we repaint the LED strip very frequent and therefore it's nothing you want to do with data that is expensive to retrieve.\n\n# 5. Fledex: Weather example\nThis is an example where we **CANNOT** fetch the information every time we want to paint the strip (which could be serveral times per second), since we are calling a public API. The API would surely block us if we would try to attempt to call it that often.\n\nTherefore we fetch the information at regular intervals, outside of our animation loop. For that we define a small GenServer which makes the API call, and publishes the data via pubsub to then be picked up by the animation loop.\n\n# 6. Fledex: DSL\nIn this example we will look at the Fledex DSL that removes a lot of the boilerplate and therefore makes the definition of an LED strip even easier. Under the hood it uses the same principles as the ones we have encountered in the examples 3-5.\n\nIn this example we will reimplement the Clock, but this time with our DSL.\n\n# 7. Fledex: Effects\nIn this chapter we take a look at the effect functionality. An animation can be \"spiced\" with an effect. This also exists as part of the Fledex DSL.\n\nWe won't look at all possible effects, but at some examples. It is quite easy to create your own effect and we'll take a look on how to do that.","ref":"readme-2.html"},{"type":"extras","title":"1. First steps with an LED strip","doc":"# 1. First steps with an LED strip\n\n```elixir\nMix.install([\n  {:circuits_spi, \"~> 2.0\"}\n])\n```","ref":"1_first_steps_with_an_led_strip.html"},{"type":"extras","title":"Search and open the SPI bus - 1. First steps with an LED strip","doc":"First of all we try to figure out what kind of SPI buses exist on the device\n\n```elixir\n_ = Circuits.SPI.bus_names()\n```\n\nAs a next step we open the first SPI bus and close it again. Let's make sure this works without any error\n\n```elixir\n{:ok, ref} =\n  Circuits.SPI.open(\"spidev0.0\",\n    mode: 0,\n    bits_per_word: 8,\n    speed_hz: 1_000_000,\n    delay_us: 10,\n    lsb_first: false\n  )\n\n:ok = Circuits.SPI.close(ref)\n```","ref":"1_first_steps_with_an_led_strip.html#search-and-open-the-spi-bus"},{"type":"extras","title":"Define a data structure - 1. First steps with an LED strip","doc":"Mext we define a data structure as required by the LED strip. The documentation states that we simply\nhave to send the bytes for the different LEDs in a row. If it's too short only a couple of LEDs will be \naddressed and the rest will not get any info. If the data structure is longer all LEDs will receive their\nupdate and the rest of the data will be ignored.\n\nTo start with we define 3 LEDs with the color red\n\n```elixir\nrange = Enum.to_list(1..3)\n\ndata =\n  Enum.reduce(range,  >, fn _index, leds ->\n    leds    >\n  end)\n```","ref":"1_first_steps_with_an_led_strip.html#define-a-data-structure"},{"type":"extras","title":"Send the data to the LED strip - 1. First steps with an LED strip","doc":"For this we need to combine the above steps, i.e.\n\n1. We open the SPI bus\n2. We define a datastructure with only zeros (to delete the strip, make it completely black)\n3. We send the binary to the SPI bus\n4. We define our data structure with some colors (see above)\n5. We send the binary to the SPI bus\n6. We close teh SPI bus\n\nLet's see what the result will be\n\n```elixir\n# 1\n{:ok, ref} =\n  Circuits.SPI.open(\"spidev0.0\",\n    mode: 0,\n    bits_per_word: 8,\n    speed_hz: 1_000_000,\n    delay_us: 10,\n    lsb_first: false\n  )\n\n# 2 (we got a 3m strup with 96 LEDs, 3x 32 LEDs)\ndata_black =\n  Enum.reduce(Enum.to_list(1..96),  >, fn lindex, leds ->\n    leds    >\n  end)\n\n# 3\n{:ok, _} = Circuits.SPI.transfer(ref, data_black)\n\n# 4\ndata_3red =\n  Enum.reduce(Enum.to_list(1..3),  >, fn _index, leds ->\n    leds    >\n  end)\n\n# 5\n{:ok, _} = Circuits.SPI.transfer(ref, data_3red)\n\n# 6\n:ok = Circuits.SPI.close(ref)\n```","ref":"1_first_steps_with_an_led_strip.html#send-the-data-to-the-led-strip"},{"type":"extras","title":"2. Fledex: Some simple tests","doc":"# 2. Fledex: Some simple tests\n\n```elixir\n# We start to define some libraries we need. If you are running on a laptop\n# the libraries will be loaded, but on a nerves_livebook you can only use\n# what has been compiled in.\nMix.install([\n  {:fledex, \"~>0.3\"}\n])\n\n# we define a couple of aliases to not have to type that much\nalias Fledex.Leds\nalias Fledex.LedStrip\nalias Fledex.Driver.Impl.Kino\nalias Fledex.Driver.Impl.Spi\nalias Fledex.Color.Correction\n\n:ok\n```","ref":"2_fledex_first_steps.html"},{"type":"extras","title":"Section - 2. Fledex: Some simple tests","doc":"Fledex has several drivers which can also be used in parallel. It's probably best to only use\na single driver to start with. The Kino driver does not have any hardware dependency and therefore\nis probably a good start to ensure that the library is loaded correctly.\n\n```elixir\n# frame = Kino.Frame.new() |> Kino.render()\n\n{:ok, pid} =\n  LedStrip.start_link(%{\n    timer: %{only_dirty_update: false},\n    led_strip: %{\n      merge_strategy: :cap,\n      # [Kino, Spi],\n      driver_modules: [Kino],\n      config: %{\n        Kino => %{\n          update_freq: 1,\n          color_correction: Fledex.Color.Correction.no_color_correction()\n          # frame: frame\n        }\n        #        Spi => %{\n        #          color_correction:\n        #            Correction.define_correction(\n        #              Correction.Color.typical_smd5050(),\n        #              Correction.Temperature.uncorrected_temperature()\n        #            )\n        #        }\n      }\n    }\n  })\n```\n\nWe now define a couple of helper functions. The first 2 functions are talking binaries directly\nwith the LED driver, the latter two are making use of the Leds client module that helps to\ncreate nice effects like a rainbow.\n\n```elixir\ndefmodule Helpers do\n  def red(namespace) do\n    Enum.each(1..10, fn _index ->\n      LedStrip.set_leds(namespace, [0xFF0000, 0x000000, 0x000000, 0x000000, 0x00000])\n      Process.sleep(600)\n      LedStrip.set_leds(namespace, [0x000000, 0xFF0000, 0x000000, 0x000000, 0x00000])\n      Process.sleep(600)\n      LedStrip.set_leds(namespace, [0x000000, 0x000000, 0xFF0000, 0x000000, 0x00000])\n      Process.sleep(600)\n      LedStrip.set_leds(namespace, [0x000000, 0x000000, 0x000000, 0xFF0000, 0x00000])\n      Process.sleep(600)\n      LedStrip.set_leds(namespace, [0x000000, 0x000000, 0x000000, 0x000000, 0xFF0000])\n      Process.sleep(600)\n    end)\n  end\n\n  def blue(namespace) do\n    Enum.each(1..10, fn _index ->\n      LedStrip.set_leds(namespace, [0x000000, 0x000000, 0x000000, 0x000000, 0x0000FF, 0x00FF00])\n      Process.sleep(600)\n      LedStrip.set_leds(namespace, [0x000000, 0x000000, 0x000000, 0x0000FF, 0x000000, 0x00FF00])\n      Process.sleep(600)\n      LedStrip.set_leds(namespace, [0x000000, 0x000000, 0x0000FF, 0x000000, 0x000000, 0x00FF00])\n      Process.sleep(600)\n      LedStrip.set_leds(namespace, [0x000000, 0x0000FF, 0x000000, 0x000000, 0x000000, 0x00FF00])\n      Process.sleep(600)\n      LedStrip.set_leds(namespace, [0x0000FF, 0x000000, 0x000000, 0x000000, 0x000000, 0x00FF00])\n      Process.sleep(600)\n    end)\n  end\n\n  def rainbow(namespace) do\n    Enum.each(0..10000, fn index ->\n      config = %{\n        num_leds: 50,\n        reversed: true\n      }\n\n      Leds.leds(50)\n      |> Leds.rainbow(config)\n      |> Leds.send(%{namespace: namespace, offset: index})\n\n      # before sending the next update we sleep a bit\n      Process.sleep(100)\n    end)\n  end\n\n  def gradient(namespace) do\n    Enum.each(0..10000, fn index ->\n      Leds.leds(50)\n      |> Leds.gradient(0xff0000, 0x0000ff, %{num_leds: 50})\n      |> Leds.send(%{namespace: namespace, offset: index, rotate_left: true})\n\n      # before sending the next update we sleep a bit\n      Process.sleep(100)\n    end)\n  end\nend\n```\n\nNow use the above functions. We can run the functions by spawning a new thread. This allows to also see what happens if another thread works in parallel. Here we create a rainbow effect that will be send with an changing offset so that the rainbow rotates through the LEDs\n\n```elixir\nLedStrup.define_namespace(:default)\nspawn(fn -> Helpers.rainbow(:default) end)\n```\n\nHere we create a gradient between red and blue. Also this one we let rotate through\n\n```elixir\nLedStrip.define_namespace(:gradient)\nspawn(fn -> Helpers.gradient(:gradient) end)\n```\n\nWe can drop the namespaces to see what happens\n\n```elixir\nLedStrip.drop_namespace(:john)\nLedStrip.drop_namespace(:jane)\nLedStrip.drop_namespace(:default)\nLedStrip.drop_namespace(:gradient)\n```\n\nThis test is running a couple of different ligth definitions in parallel.\n\n```elixir\nLedStrip.define_namespace(:john)\nLedStrip.define_namespace(:jane)\nLedStrip.define_namespace(:default)\n\nspawn(fn -> Helpers.blue(:jane) end)\nspawn(fn -> Helpers.red(:john) end)\nspawn(fn -> Helpers.rainbow(:default) end)\n```\n\nOnce we are done we should stop our GenServer (even thoguh I rarely run this one ;-))\n\n```elixir\nGenServer.stop(pid)\n```","ref":"2_fledex_first_steps.html#section"},{"type":"extras","title":"2b Fledex: How to define LEDs","doc":"# 2b Fledex: How to define LEDs\n\n```elixir\nMix.install(\n  [\n    {:fledex, \"~>0.3\"}\n  ],\n  # necessary to enable the nicer rendering\n  consolidate_protocols: false\n)\n```","ref":"2b_fledex_how_to_define_leds.html"},{"type":"extras","title":"Intro - 2b Fledex: How to define LEDs","doc":"The `Fledex.Leds` module allows you to easily define a sequence of LEDs. In this livebook we will look at the following aspects:\n\n* the different color concepts\n* defining individual LEDs (in sequence and out of sequence)\n* merging LED sequences\n* repeating an LED sequence\n* defining LEDs though a function (gradient & rainbow)\n* sending leds to a `Fledex.LedStrip`","ref":"2b_fledex_how_to_define_leds.html#intro"},{"type":"extras","title":"Color concepts - 2b Fledex: How to define LEDs","doc":"Fledex allows to define colors in many different ways.\n\nOne very common one is to work with an integer (as defined in `Types.colorint`) with a representation of the color similar to the [html notation](https://www.w3schools.com/colors/default.asp) It's best to write the color as hexadecimal, since each color has a range from 0 to 255 (i.e gets 2 digits), i.e 0xrrggbb (rr=red, gg=green, bb=blue).\n\n**Example:**  `0x2cafe4`  where red has a value of  `0x2c`  (44), green of  `0xaf`  (175), and blue  of  `0xe4`  (228)\n.This is equivalent to the decimal `2 928 612`.\n\n```elixir\n# we define our own color\nmy_color1 = 0x2CAFE4\nmy_color2 = 2_928_612\n\nFledex.Color.KinoRender.new([my_color1, my_color2])\n```\n\nFledex does also allow to specify an `{r, g, b}` triple (as defined in `Types.rgb`). Each color is again in the 0 to 255 range.\n\n```elixir\nmy_color3 = {0x2C, 0xAF, 0xE4}\nmy_color4 = {44, 175, 228}\n\nFledex.Color.KinoRender.new([my_color3, my_color4])\n```\n\nThe next most convenient way is to defined a color through its name (see `Fledex.Color.Names`). \nWe will look at this in more detail in a [later chapter](./3b_fledex_more_about_colors.livemd)\n\n```elixir\nalias Fledex.Color.Names\n# note, this is a slightly different color compared to the above one, since the exact color \n# does not exist. \"Cerulean (Crayola): {28, 170, 214} is roughly the same color\nmy_color5 = :cerulean_crayola\nmy_color6 = Names.info(my_color5)\nmy_color7 = Names.cerulean_crayola()\n\nFledex.Color.KinoRender.new([my_color5, my_color6, my_color7])\n```\n\nFrom the color names you can also get more information, but as mentioned above we'll look at this in a later chapter.\n\nIn addition, you might encounter, in some cases, other color encodings like `Type.hsv` or `Typee.hsl`. But they are in general not so important.","ref":"2b_fledex_how_to_define_leds.html#color-concepts"},{"type":"extras","title":"Defining individual Led - 2b Fledex: How to define LEDs","doc":"In Fledex you define a sequence of LEDs (and their colors) through the `Leds` module.\nYou first define the size of the sequence. Let us define a sequence of 30 LEDs (by calling `Leds.leds`):\n\n```elixir\nalias Fledex.Leds\n\nleds = Leds.leds(30)\n```\n\nEach LED in that sequence does not have any color assigned to it and therefore is (by definition) switched off (black).\n\nIt is now possble to define individual LEDs in that sequence by simply specifying the color (through `Leds.light()` functions and chaining them together:\n\n```elixir\nleds =\n  leds\n  |> Leds.light(0xFF0000)\n  |> Leds.light(:green)\n  |> Leds.light(255)\n```\n\nAs can be seen by calling the `light` function we move an `index` to know which one we defined as last and we can thereby simply define the light one after the next. It should be noted that the leds are one-indexed.\n\nIt is possible to define specific LEDs by specifying an offset. Let's extend our leds:\n\n```elixir\nalias Fledex.Color.Names\n\nleds =\n  leds\n  |> Leds.light(:red, 10)\n  |> Leds.light(Names.green())\n  |> Leds.light({0, 0, 0xFF})\n```\n\nAs seen, if we specify the offset of `10` and we continue to define colors without offset the next LED in the sequence will be defined (i.e `11`)\n\nAt the `Raw` result you can see how the deta is encoded.\n\n \n\n```elixir\n%Fledex.Leds{\n  ...\n  leds: %{1 => 16711680, 2 => 65280, 3 => 255, 10 => 16711680, 11 => 65280, 12 => 255},\n  ...\n}\n```\n\nWe have a `map` (`%{}`) with the `offset` as key and the color as value.\n\nIt is possble to define a color with an invalid offset. i.e. which is outside the allowed range. This is not a problem. The information will be carried around, but will be ignored (take a look at the `Raw` data)\n\n```elixir\nleds =\n  leds\n  |> Leds.light(:green, 40)\n```","ref":"2b_fledex_how_to_define_leds.html#defining-individual-led"},{"type":"extras","title":"Merging LED sequences - 2b Fledex: How to define LEDs","doc":"Quite commonly there comes up the need to define an LED sequence as a combination of serveral sequences. This can easily be done by passing `Leds` as if it were a single LED\n\n```elixir\nleds_sub =\n  Leds.leds(2)\n  |> Leds.light(0xFF0000)\n  |> Leds.light(0x00FF00)\n\nleds =\n  Leds.leds(30)\n  |> Leds.light(leds_sub)\n  |> Leds.light(leds_sub, 5)\n```","ref":"2b_fledex_how_to_define_leds.html#merging-led-sequences"},{"type":"extras","title":"Repeating an LED sequence - 2b Fledex: How to define LEDs","doc":"It is possble to define a sequence of LEDs by repeating it. If you want to have 5 red LEDs you define a single LED and insturct it to be repeated 5 times. This would look like this (note the first 5 is the offset which needs to be specified and the second specifies the repetition factor):\n\n```elixir\nleds =\n  Leds.leds(30)\n  |> Leds.light(:red, 5, 5)\n```\n\nYou can also use this to repeat a sub-sequence. This will will repeat the whole subsequence as many times in a row as specified.\n\n```elixir\nleds_sub =\n  Leds.leds(2)\n  |> Leds.light(0xFF0000)\n  |> Leds.light(0x00FF00)\n\nleds =\n  Leds.leds(30)\n  |> Leds.light(leds_sub, 5, 3)\n```","ref":"2b_fledex_how_to_define_leds.html#repeating-an-led-sequence"},{"type":"extras","title":"Definining LEDs through a function - 2b Fledex: How to define LEDs","doc":"When you want to create a color sequence that is more complex, then this can also be achieved through some definition functions.\n\nIf, for example, you want to create a rainbow pattern over 10 LEDs, you can do so by using the `rainbow/2` function.\n\n```elixir\nleds =\n  Leds.leds(30)\n  |> Leds.rainbow()\n```\n\nAnother function is the `gradient/3` function that allows a transition from one color to another.\n\n```elixir\nleds =\n  Leds.leds(30)\n  |> Leds.gradient(:red, :blue)\n```\n\n`repeat/2` is another function that will take the already defined sequence (and `Leds` size `x`) and repeats it `y` times. Hence, the returned strip size will be: `size = x * y`.\n\n```elixir\nLeds.leds(10)\n|> Leds.gradient(:red, :blue)\n|> Leds.repeat(3)\n```","ref":"2b_fledex_how_to_define_leds.html#definining-leds-through-a-function"},{"type":"extras","title":"Sending LEDs to a led-strip - 2b Fledex: How to define LEDs","doc":"Once we have defined our Leds, we can send them to our `Fledex.LedS`. This is not\ndifficult, but it's such a common task that the Leds module provides the convenience\nfunction `send/2`. and some supporting functions (`set_driver_info/3`, `rotate/2`,\n`to_list/1`).\n\nThe send function has a couple of checks that the `Fledex.LedStrip` is set up correctly.\nWe won't discuss the send function in detail, since we'll work a bit more in \nother chapters.","ref":"2b_fledex_how_to_define_leds.html#sending-leds-to-a-led-strip"},{"type":"extras","title":"3. Fledex: Animations","doc":"# 3. Fledex: Animations\n\n```elixir\n# In this example we'll use the simple setup (experiments are inteded to not run on real\n# hardware but on a normal livebook, This makes it easier to stay up-to-date and experiment\n# We start to define our fledex library, directly linking to the latest version on github\nMix.install([\n  {:fledex, \"~>0.3\"}\n])\n\n# we define a couple of aliases to not have to type that much\nalias Fledex.Animation.Manager\nalias Fledex.Leds\nalias Fledex.LedStrip\nalias Fledex.Driver.Impl.Kino\nalias Fledex.Color.Correction\n\n{:ok, pid} = Manager.start_link()\n\n:ok\n```","ref":"3_fledex_animations.html"},{"type":"extras","title":"Preparation - 3. Fledex: Animations","doc":"To start with, we define a couple of aliases to make our life easier and more importantly, we start our `Fledex.Animation.Manager`. We will use it to create animations. The animations are actually maintained by the `Fledex.Animation.Animator`, but we will interact with it only through the `Fledex.Animation.Manager`.","ref":"3_fledex_animations.html#preparation"},{"type":"extras","title":"Helper functions - 3. Fledex: Animations","doc":"We define a bit of helper functions that we will use when we define our animations. Those helper functions are the actual definitions of how the ledstrip will look.\n\nNote that the functions get in a map (here called triggers) that can contain serveral\ntriggers. It will definitely contain one trigger (caused by the `Fledex.LedStrip`) with\nthe name of the led strip. The structure does not need to be used, but can be used in\norder to change the animation based on the trigger. Here we use the trigger in the send\nconfiguration to specify an offset to the leds and thereby create a movement.\n\n```elixir\ndefmodule HelperFunctions do\n  @rainbow Leds.leds(50) |> Leds.rainbow(%{\n    num_leds: 50, \n    reversed: true\n  })\n  def rainbow(_triggers) do\n    @rainbow\n  end\n\n  def send_config(triggers) do\n    %{offset: triggers[:john]}\n  end\nend\n```","ref":"3_fledex_animations.html#helper-functions"},{"type":"extras","title":"Creating a first animation - 3. Fledex: Animations","doc":"Now it's time to define our first animation by using the `Fledex.Animation.Manager`. Before we can define our animations we first have to define (and configure) our led strip. The `Fledex.Animation.Manager` can manage serveral strips at the same time.\n\nWe call our led strip `:john` (it has to be an atom). In this example we will only use the simple kino driver (and configure it with defaults) and thereby display the result within our livebook.\n\n```elixir\nManager.register_strip(:john, :kino)\n\nManager.register_animations(:john, %{\n  caine: %{\n    def_func: &HelperFunctions.rainbow/1,\n    send_config_func: &HelperFunctions.send_config/1\n  }\n})\n```","ref":"3_fledex_animations.html#creating-a-first-animation"},{"type":"extras","title":"Replacing our animation - 3. Fledex: Animations","doc":"We can now redefine our animation by regisetering different functions. Here we define a 3 led wide red dot that moves slowly from right to left.\n\nNote: we are starting to use color names instead of defining it through an integer. If you want to learn more, then take a small detour to the [Color livebook](./3b_fledex_more_about_colors.livemd)\n\n```elixir\nimport Bitwise\n\ndefmodule HelperFunctions2 do\n  @red_leds Leds.leds(50) |> Leds.light(:red) |> Leds.light(:red) |> Leds.light(:red)\n  def red_leds(_triggers) do\n    @red_leds\n  end\n\n  def send_config(triggers) do\n    slow_offset = rem(triggers[:john] >>> 5, 50)\n    %{offset: slow_offset}\n  end\nend\n\nManager.register_animations(:john, %{\n  caine: %{\n    def_func: &HelperFunctions2.red_leds/1,\n    send_config_func: &HelperFunctions2.send_config/1\n  }\n})\n```","ref":"3_fledex_animations.html#replacing-our-animation"},{"type":"extras","title":"Defining serveral animations - 3. Fledex: Animations","doc":"It's also possible to define serveral animations. Here we continue with our previous animation (we do have to explicitly specify it again, otherwise it would be removed) and add a new animation with 3 leds that move faster from right to left.\n\n```elixir\nimport Bitwise\n\ndefmodule HelperFunctions3 do\n  @rgb_leds Leds.leds(50) |> Leds.light(:red) |> Leds.light(:green) |> Leds.light(:blue)\n  def rgb_leds(_triggers) do\n    @rgb_leds\n  end\n\n  def send_config(triggers) do\n    faster_offset = 50 - rem(triggers[:john] >>> 2, 50)\n    %{offset: faster_offset}\n  end\nend\n\nManager.register_animations(:john, %{\n  caine: %{\n    def_func: &HelperFunctions2.red_leds/1,\n    send_config_func: &HelperFunctions2.send_config/1\n  },\n  doe: %{\n    def_func: &HelperFunctions3.rgb_leds/1,\n    send_config_func: &HelperFunctions3.send_config/1\n  }\n})\n```","ref":"3_fledex_animations.html#defining-serveral-animations"},{"type":"extras","title":"Use of anonymous functions - 3. Fledex: Animations","doc":"It is also possible to use an anonymous function during the definition which avoids to create a separate module. Here we redefine our above definition, but this time we define `:doe` with an anonymous function. To really see that we have changed the definition we define the leds  as all blue. In addition we change the `send_config_func` to animate the dots even faster.\n\nThe advantage of using the anonymous functions is that you don't get any compilation error, that occures if you recompile the module. Try it out by reevaluating the below definition several times and then doing the same thing with the previous definition.\n\nThis allows for a smooth replacement of definitions.\n\n```elixir\nManager.register_animations(:john, %{\n  caine: %{\n    def_func: &HelperFunctions2.red_leds/1,\n    send_config_func: &HelperFunctions2.send_config/1\n  },\n  doe: %{\n    def_func: fn _triggers ->\n      Leds.leds(50) |> Leds.light(:blue) |> Leds.light(:blue) |> Leds.light(:blue)\n    end,\n    send_config_func: fn triggers ->\n      faster_offset = 50 - rem(triggers[:john] >>> 1, 50)\n      %{offset: faster_offset}\n    end\n  }\n})\n```\n\nFrom now on we will _only_ define our definitions through the use of anonymous functions.","ref":"3_fledex_animations.html#use-of-anonymous-functions"},{"type":"extras","title":"3b Fledex: Everything about Colors","doc":"# 3b Fledex: Everything about Colors\n\n```elixir\nMix.install([\n  {:fledex, \"~>0.3\"}\n])\n```","ref":"3b_fledex_more_about_colors.html"},{"type":"extras","title":"Colors and different drivers - 3b Fledex: Everything about Colors","doc":"Different drivers have different color characteristics. Therefore you might have to adjust the colors when migrating from one output to another. Some drivers allow some color correction to try to adjust for those issues (see also the 'Color Correction' section.","ref":"3b_fledex_more_about_colors.html#colors-and-different-drivers"},{"type":"extras","title":"Color Information - 3b Fledex: Everything about Colors","doc":"Fledex has an extensive set of predefined colors from [Wikipedia](https://en.wikipedia.org/wiki/List_of_colors:_A%E2%80%93F). You can retrieve those names by calling\n\n \n\n```elixir\nFledex.Color.Names.names()\n```\n\nYou can also retrieve the complete data set by calling\n\n \n\n```elixir\nFledex.Color.Names.colors()\n```\n\nHere a list of all the colors:\n\n```elixir\nKino.DataTable.new(Fledex.Color.Names.colors(),\n  keys: [:descriptive_name, :name, :rgb, :hex, :hsv, :hsl, :source],\n  sorting_enabled: true\n)\n```\n\nYou can also retrieve the information from a specific color, like `:almond` in the following way\n\n* `almond/0`: Every color has it's own function and the :hex value (represented as integer) will be returned\n* `almond/1`: This allows the retrieve a specific representation. It should be noted, that the color functions (that are oftne just approximations), do not provide the same results. The values returned here are the ones as defined on the Wikipedia page:\n  * `:all`: This retrieves the full data set\n  * `:hex`: This is the same as `almond/0`\n  * `:rgb`: This retrieves an RGB struct, i.e. `{r, g, b}`\n  * `:hsv`: This retrieves an HSV struct, i.e. `{h, s, v}`\n  * `:hsl`: This retrieves an HSL struct, i.e. `{h, s, l}`\n  * `:index`: The index of this color in the list of all colors\n  * `:desriptive_name`: a string with name (from this the Atom is derived)\n  * `:source`: Information where the color comes from, see Wikipedia for more details\n* `info/1` and `info/2`: They are convenience functions when you only have an atom as the color name. They map to the functions, thus `info(:almond)` is equal to `almond()` and `info(:almond, what)` is equal to `almond(what)`.\n\nIn addition each color can also be used directly in an `Leds` sequence since it provides to convenience functions:\n\n* `almond(leds)` which takes an `Leds` sequence and adds the `:almond` color to it (at the next position). This is equivalent to:\n  ```elixir\n  leds |> Leds.light(almond(:hex))\n  ```\n* `almond(leds, offset)` which takes an `Leds` sequence and an offset to specify where the led should be positioned. This is equivalent to:\n  ```elixir\n  leds |> Leds.light(almond(:hex), offset)\n  ```\n\nThis allows for a very natural way to define an led sequence. especially if we import the `Fledex.Leds` and `Fledex.Color.Names` modules.\n\n```elixir\nimport Fledex.Leds\nimport Fledex.Color.Names\n\nleds(5) |> almond |> red |> green |> blue(5)\n```","ref":"3b_fledex_more_about_colors.html#color-information"},{"type":"extras","title":"Color Correction - 3b Fledex: Everything about Colors","doc":"More info to follow","ref":"3b_fledex_more_about_colors.html#color-correction"},{"type":"extras","title":"4. Fledex: Clock Example","doc":"# 4. Fledex: Clock Example\n\n```elixir\nMix.install([\n  {:fledex, \"~>0.3\"}\n])\n\n# we define a couple of aliases to not have to type that much\nalias Fledex.Animation.Manager\nalias Fledex.Leds\nalias Fledex.LedStrip\n\n{:ok, pid} = Manager.start_link()\n\n:ok\n```","ref":"4_fledex_clock_example.html"},{"type":"extras","title":"Intro - 4. Fledex: Clock Example","doc":"The goal of this project is to create a clock that displays its hour, minute and second on the trip. We use the kino driver as output and we limit the amount of leds to a reasonable number.\nTherefore we can't really display every second and every minute. We can get a bit creative in how we display it.\n\nBut before we get there, we first initiate our led strip.","ref":"4_fledex_clock_example.html#intro"},{"type":"extras","title":"Preparational steps - 4. Fledex: Clock Example","doc":"First we register a strip (we name it `:clock`) with our `Fledex.Animation.Manager` and we use the default settings for the `:kino` driver.\n\nThen we modify the led strip to update with a very low frequency. Our clock only updates every second and therefore it's unnecessary that we update it more often than that. To avoid any issues due to some runtime delays, we update it twice every second. Thereby the second indicator will never jump an led.\n\n```elixir\n# we start with the default configuration\n:ok = Manager.register_strip(:clock, :kino)\n# and then we modify the timer update frequency to 500ms\n{:ok, _old_value} = LedStrip.change_config(:clock, [:timer, :update_timeout], 500)\n\n:ok\n```","ref":"4_fledex_clock_example.html#preparational-steps"},{"type":"extras","title":"Defining our clock - 4. Fledex: Clock Example","doc":"We now register our animations for the `:clock` led strip. We define 4 animations. One for the seconds, minutes, and hours and one as help to make it easier to read the lock by having an indicator in every 5 intervals.\n\nEach animation consists of two elements:\n\n* `def_func` this defines a function that will be called to define a sequence of LEDs (how many LEDs and which colors). The function receives a `trigger` (a `map`) that can contain various information, but at least contains a counter with the name of the led strip (i.e. in our case with the name `:counter`). We will use this to define a sequence of the correct length and color the fist led. In this function we don't use the `trigger`\n* `send_config_func` this defines a function that will be called after the LED strip has been defined (see `Fledex.Leds.send/2` for more details and options). We will use this to rotatae the led sequence (dependent on the `trigger` that we also get here as input) in such a way that the colored dot will come to the correct position in the sequence. We also explicitly specify the direction of our rotation. We can rotate to the left or the right.\n\nNote: we get the time by simply making a call to `Time.utc_now/0` and adjusting it to our timezone (UTC+1) (`Time.add/2`). We then extract (through pattern matching) the information we are intersted in (second, minute, hour)\n\nOur `:help` \"animation\" defines an led sequence of 5 leds (the first one being colored) and repeats that pattern 12 times. This is not a real animation, since we output a static pattern every time.\n\n```elixir\nconfig = %{\n  seconds: %{\n    def_func: fn _triggers ->\n      Leds.leds(60) |> Leds.light(:red)\n    end,\n    send_config_func: fn _triggers ->\n      # we work with utc times and adjust, so we don't need to load a timezone library\n      %{hour: _hour, minute: _minute, second: second} = Time.utc_now() |> Time.add(1, :hour)\n      # Logger.info(\"#{second}\")\n      %{offset: second, rotate_left: false}\n    end\n  },\n  minutes: %{\n    def_func: fn _triggers ->\n      Leds.leds(60) |> Leds.light(:green)\n    end,\n    send_config_func: fn _triggers ->\n      # we work with utc times and adjust, so we don't need to load a timezone library\n      %{hour: _hour, minute: minute, second: _second} = Time.utc_now() |> Time.add(1, :hour)\n      # Logger.info(\"#{second}\")\n      %{offset: minute, rotate_left: false}\n    end\n  },\n  hours: %{\n    def_func: fn _triggers ->\n      Leds.leds(60) |> Leds.light(:blue)\n    end,\n    send_config_func: fn _triggers ->\n      # we work with utc times and adjust, so we don't need to load a timezone library\n      %{hour: hour, minute: _minute, second: _second} = Time.utc_now() |> Time.add(1, :hour)\n      # Logger.info(\"#{second}\")\n      %{offset: hour, rotate_left: false}\n    end\n  },\n  help: %{\n    def_func: fn _triggers ->\n      Leds.leds(5)\n      |> Leds.light(:ash_gray)\n      |> Leds.repeat(12)\n    end\n  }\n}\n```","ref":"4_fledex_clock_example.html#defining-our-clock"},{"type":"extras","title":"Starting our animation - 4. Fledex: Clock Example","doc":"Now that we have defined our configuration we can start our animation, by registering our animations-configuration to our `Fledex.Animation.Manager` by calling `register_animations/2`. That's it!\n\n```elixir\nManager.register_animations(:clock, config)\n```\n\nIf you are searching for your led strip then scoll up. It's displayed where you have registered your led strip with the `Fledex.Animation.Manager`.","ref":"4_fledex_clock_example.html#starting-our-animation"},{"type":"extras","title":"5. Fledex: Weather example","doc":"# 5. Fledex: Weather example\n\n```elixir\nMix.install([\n  {:fledex, \"~>0.3\"},\n  {:jason, \"~>1.2\"}\n])\n\n# we define a couple of aliases to not have to type that much\nalias Fledex.Animation.Manager\nalias Fledex.Leds\nalias Fledex.LedStrip\nalias Fledex.Driver.Impl.Kino\nalias Fledex.Color.Correction\nalias Fledex.Utils.PubSub\n\n{:ok, pid} = Manager.start_link()\n\n:ok\n```","ref":"5_fledex_weather_example.html"},{"type":"extras","title":"Intro - 5. Fledex: Weather example","doc":"In the last project we created a clock. We could make a call to get the current time in every redraw loop. This approach is not possible for data that we are fetching from an external source. In this example we will create a weather display. We will get the information from an API.\n\nIf we would take the same approach as in the clock example, we would make an API call every 500ms which probably will result in us getting blocked. It is completely unnecessary to make that many call, since the wheather is not changing that frequently.\n\nWhat we will do is to check every 15 min what the latest weather news is.\n\nThere are plenty of Weather APIs on the internet, but most of them require to register which is not ideal for a public example. Therefore I decided to use [Open-Meteo](https://open-meteo.com/) which provides all we need.\n\nWe need to decide for which location we want to get the weather. We use the coordinate for Budapest (`47.4729344`,`19.0468802`). Then we can make the call [`https://api.open-meteo.com/v1/forecast?latitude=47.4729344&longitude=19.0468802&current=temperature_2m`](https://api.open-meteo.com/v1/forecast?latitude=47.4729344&longitude=19.0468802&current=temperature_2m) to get data like the following:\n\n```json\n{\n  \"latitude\": 47.5,\n  \"longitude\": 19.0625,\n  \"generationtime_ms\": 0.04100799560546875,\n  \"utc_offset_seconds\": 0,\n  \"timezone\": \"GMT\",\n  \"timezone_abbreviation\": \"GMT\",\n  \"elevation\": 113,\n  \"current_units\": {\n    \"time\": \"iso8601\",\n    \"interval\": \"seconds\",\n    \"temperature_2m\": \"°C\"\n  },\n  \"current\": {\n    \"time\": \"2023-10-30T13:30\",\n    \"interval\": 900,\n    \"temperature_2m\": 22.1\n  }\n}\n```\n\nAs can be seen we get the information we are interested in, the current temperature (in °C)","ref":"5_fledex_weather_example.html#intro"},{"type":"extras","title":"Configuring the led strip - 5. Fledex: Weather example","doc":"Now it's time to prepare our led strip. First we define our strip and we set a very low refresh rate. An update every 10 sec is enough.\n\n```elixir\n# we start with the default configuration\n:ok = Manager.register_strip(:weather, :kino)\n# and then we modify the timer update frequency to 10 sec\n{:ok, _old_value} = LedStrip.change_config(:weather, [:timer, :update_timeout], 10_000)\n\n:ok\n```\n\nNow we define two animations, the first one creates blue (below zero), green (zero), or red (above zero) indicators. The indicators have the length of the temperature and start from zero to either go to the left (negative) or the right (positive).\n\nThe temperature will be delivered to us as part of the trigger. We'll look at how we will get  this information in the section below.\n\nAs and additional bonus, the thermometer is showing the full scale, if no proper measurement is received (arbitrarily high value of 100).\n\n```elixir\nManager.register_animations(:weather, %{\n  temperature: %{\n    def_func: fn triggers ->\n      temp = triggers[:temperature] || 100\n      temp = round(temp)\n\n      temp =\n        if temp == 100 do\n          100\n        else\n          temp = min(temp, 40)\n          max(temp, -20)\n        end\n\n      {leds, offset} =\n        case temp do\n          temp when temp == 100 ->\n            {Leds.leds(61)\n             |> Leds.light(:blue, 1, 20)\n             |> Leds.light(:may_green)\n             |> Leds.light(:red, 22, 40), 1}\n\n          temp when temp  \n            {Leds.leds(1) |> Leds.light(:blue) |> Leds.repeat(temp), 21 + temp}\n\n          temp when temp == 0 ->\n            {Leds.leds(1) |> Leds.light(:may_green), 21}\n\n          temp when temp > 0 ->\n            {Leds.leds(1) |> Leds.light(:red) |> Leds.repeat(temp), 22}\n        end\n\n      Leds.leds(61) |> Leds.light(leds, offset)\n    end\n  },\n  help: %{\n    # we allow temperatures down to -20C and up to +40C\n    def_func: fn _triggers ->\n      negative_scale =\n        Leds.leds(5)\n        |> Leds.light(:ash_gray)\n        |> Leds.repeat(4)\n\n      positive_scale =\n        Leds.leds(5)\n        |> Leds.light(:ash_gray, 5)\n        |> Leds.repeat(8)\n\n      Leds.leds(61)\n      |> Leds.light(negative_scale)\n      |> Leds.light(:ash_gray)\n      |> Leds.light(positive_scale)\n    end\n  }\n})\n```\n\nFor testing we can send an arbitrary temperature value to our strip in the following way. This allows us to also see whether the strip has the correct behavior when the temperature is at zero (or even below) degree. It wouldn't be really practical if we need to wait until the outside temperature reaches those levels.\n\nHere we send a temperature value of -15.2 degree (which the strip should round to 15 degree)\n\n```elixir\nFledex.Utils.PubSub.broadcast(:fledex, \"trigger\", {:trigger, %{temperature: -15.2}})\n```","ref":"5_fledex_weather_example.html#configuring-the-led-strip"},{"type":"extras","title":"Getting the weather data - 5. Fledex: Weather example","doc":"Before we can start with the weather data, we need to make sure that we can make http client calls (also over https) and therefore we start the two services.\n\n```elixir\n:inets.start()\n:ssl.start()\n```\n\nNow we can make the actual call. We do want to make this call in regular intervals (every 15 min), parse the response and publish the temperature through pubsub. To do this we create a small server. We start it with our URL (note, the parsing in the server is URL specific, so you can't simply change it to another site) and with our 15min refresh interval (specified in ms).\n\nThe server will extract the temperature and send it via pubsub to our update functions.\n\n```elixir\ndefmodule CallUrlPeriodic do\n  use GenServer\n\n  def start_link(url, interval_ms) do\n    pid = Process.whereis(__MODULE__)\n\n    if pid == nil do\n      GenServer.start_link(__MODULE__, %{url: url, interval_ms: interval_ms}, name: __MODULE__)\n    else\n      # server is already running. We could reconfigure it, but we don't do this here.\n      {:ok, pid}\n    end\n  end\n\n  @impl true\n  def init(state) do\n    :timer.send_interval(state.interval_ms, :work)\n    # we send ourselve immediately a request\n    send(self(), :work)\n    {:ok, state}\n  end\n\n  @impl true\n  def handle_info(:work, state) do\n    {:ok, resp} =\n      :httpc.request(:get, {String.to_charlist(state.url), []}, [], body_format: :binary)\n\n    {{_, 200, ~c\"OK\"}, _headers, body} = resp\n    json = Jason.decode!(body)\n    temperature = json[\"current\"][\"temperature_2m\"]\n    PubSub.broadcast(:fledex, \"trigger\", {:trigger, %{temperature: temperature}})\n\n    {:noreply, state}\n  end\nend\n\n{:ok, pid} =\n  CallUrlPeriodic.start_link(\n    \"https://api.open-meteo.com/v1/forecast?latitude=47.4729344&longitude=19.0468802&current=temperature_2m\",\n    900_000\n  )\n```","ref":"5_fledex_weather_example.html#getting-the-weather-data"},{"type":"extras","title":"Annotations - 5. Fledex: Weather example","doc":"* To decode wmo codes: https://www.nodc.noaa.gov/archive/arc0021/0002199/1.1/data/0-data/HTML/WMO-CODE/WMO4677.HTM","ref":"5_fledex_weather_example.html#annotations"},{"type":"extras","title":"6. Fledex: DSL","doc":"# 6. Fledex: DSL\n\n```elixir\n# In this example we'll use the simple setup (experiments are inteded to not run on real\n# hardware but on a normal livebook, This makes it easier to stay up-to-date and experiment\n# We start to define our fledex library, directly linking to the latest version on github\nMix.install([\n  {:fledex, \"~>0.3\"}\n])\n```","ref":"6_fledex_dsl.html"},{"type":"extras","title":"Intro - 6. Fledex: DSL","doc":"We now define our animations with our DSL with the following steps:\n\n* First we have to `use Fledex` in order to import `Fledex`, to load our DSL macros (`led_strip` and `animation`), and to import `Fledex.Leds`. This means we won't write `Leds` in fron of functions. By default this will also start the `Fledex.Animation.Manager` if it's not already running which will take care of all the animation coordinations.\n\n```elixir\nuse Fledex\n```","ref":"6_fledex_dsl.html#intro"},{"type":"extras","title":"The clock - 6. Fledex: DSL","doc":"* We define a new strip with a name (`:clock`), and configure it (we use the `:kino`\n  default driver for display). This will internally create a new `Fledex.LedStrip` \n  server (if it's not already running) that will control the strip. Its server name will\n  be identical to the `led_strip` name.\n* Then within this strip we define several `animation`s that correspond to an animatio\n  (and will use internally the `Fledex.Animation.Animator`). Each animation is identified\n  by its own name (`:help`, `:hour`, `:minute`, `:second`).\n* Within each animation we define a function that will be executed repeatedly.\n* Inside that function we can define one or several `Leds`, either directly or through \n  an led sequence (like a rainbow function) and animate those leds depending on some\n  trigger data (data that comes into the animation function). An explanation of what \n  we are doing in our example here will be given after the code.\n\nIt is also possble to define some other configurations (like the `send_config_func` as we have done in the \"[Fledex Clock Example](./4_fledex_clock_example.livemd)\") but we will look at this a bit later.\n\n```elixir\nled_strip :clock, :kino do\n  static :help do\n    leds(5) |> light(davy_s_grey()) |> repeat(12)\n  end\n\n  animation :hour do\n    _triggers ->\n      %{hour: hour, minute: _minute, second: _second} = Time.utc_now() |> Time.add(1, :hour)\n      leds(24) |> light(blue(), hour + 1)\n  end\n\n  animation :minute do\n    _triggers ->\n      %{hour: _hour, minute: minute, second: _second} = Time.utc_now() |> Time.add(1, :hour)\n      leds(60) |> light(:may_green, minute + 1)\n  end\n\n  animation :second do\n    _triggers ->\n      %{hour: _hour, minute: _minute, second: second} = Time.utc_now() |> Time.add(1, :hour)\n      leds(60) |> light(:red, second + 1)\n  end\nend\n```\n\nThe above code should result in an animation displaying the clock.Now it's time to look at the different animation parts and how they work.\n\nWe first define a `static` animation (one that doesn't animate). This animation does not get any triggers and will only be called once during the initalization (since it's static). Notice that this function gets no argument (we don't have the trailing `_triggers ->` part). It is used to make it easier to read the time by having a dash every 5 steps and those do not change over time. The markers are repeating in a regular pattern, so we only define the first one and then repeat it with the `repeat/2` function 12 times.\n\nFor all other animations we make a call to the system time (`Time.utc_now()`) and therefore don't require the `_trigger` information. We shift the result to the right timezone (we add 1 hour, for UTC+1).\n\nWe pattern match the result, depending on the animation into `hour`, `minute`, or `second`. Note: the code is a bit extra bloated to pattern match it every time into all 3 and to comment out the ones we don't need, but that is just to highlight that we have all 3 elements but we are only interested in one of them.\n\nExapmle: For the second indicator the following would have been enough:\n\n \n\n```elixir\n  animation :second do\n    _triggers ->\n      %{second: second} = Time.utc_now() |> Time.add(1, :hour)\n      leds(60) |> light(:red, second + 1)\n  end\n```\n\nWe then define a sequence of `Leds` of the right length (`24` for `hour`, and `60` for `minute` and `second`). We switch-on only a single light in some color at the correct position (with the offset corresponding to `hour`, `minute` or `second`)\n\nNote: in the clock example we defined a static sequence of `Leds` and offsetted it. This requires the definition of a `send_config_func`. We will look on how to do it with the DSL as a next step.","ref":"6_fledex_dsl.html#the-clock"},{"type":"extras","title":"Clock (with send function) - 6. Fledex: DSL","doc":"We are now implementing the above example, but demonstrating on how the `:second`, `:minute`, and `:hour` indicators can be implemented in exactly the same way as we did in chapter 4, i.e. with a send function that shifts the red marker depending on the time.\n\nWe also take the ocasion to demonstrate on how you can define a second strip, by giving it a new name (`:clock2`). To demonstrate that it's really a new stip this clock here displays the time in UTC (we don't add the extra hour of offset). Look carefully at the blue hour indicator.\n\nAlso, the above strip should continue to run and a new strip will appear below the code. Had we called the strip the same as above (i.e. `:clock`), then the above output would have stopped updating and a new one would appear here.\n\nTry it out and modify any of the two animations. They should be fully independent.\n\n```elixir\nled_strip :clock2, :kino do\n  static :help do\n    leds(5) |> light(davy_s_grey()) |> repeat(12)\n  end\n\n  animation :hour,\n    send_config: fn _triggers ->\n      %{hour: hour, minute: _minute, second: _second} = Time.utc_now()\n      %{offset: hour, rotate_left: false}\n    end do\n    _triggers ->\n      leds(24) |> light(blue())\n  end\n\n  animation :minute,\n    send_config: fn _triggers ->\n      %{hour: _hour, minute: minute, second: _second} = Time.utc_now()\n      %{offset: minute, rotate_left: false}\n    end do\n    _triggers ->\n      leds(60) |> light(:may_green)\n  end\n\n  animation :second,\n    send_config: fn _triggers ->\n      %{hour: _hour, minute: _minute, second: second} = Time.utc_now()\n      %{offset: second, rotate_left: false}\n    end do\n    _triggers ->\n      leds(60) |> light(:red)\n  end\nend\n```","ref":"6_fledex_dsl.html#clock-with-send-function"},{"type":"extras","title":"The weather app - 6. Fledex: DSL","doc":"We now implement the [weather app](./5_fledex_weather_example.livemd) (indicating the temperature) we implemented in chapter 5.\n\n```elixir\nled_strip :weather, :kino do\n  animation :temperature do\n    triggers ->\n      temp = triggers[:temperature] || 100\n      temp = round(temp)\n\n      temp =\n        if temp == 100 do\n          100\n        else\n          temp = min(temp, 40)\n          max(temp, -20)\n        end\n\n      {leds, offset} =\n        case temp do\n          temp when temp == 100 ->\n            {leds(61)\n             |> light(:blue, 1, 20)\n             |> light(:may_green)\n             |> light(:red, 22, 40), 1}\n\n          temp when temp  \n            {leds(1) |> light(:blue) |> repeat(temp), 21 + temp}\n\n          temp when temp == 0 ->\n            {leds(1) |> light(:may_green), 21}\n\n          temp when temp > 0 ->\n            {leds(1) |> light(:red) |> repeat(temp), 22}\n        end\n\n      leds(61) |> light(leds, offset)\n  end\n\n  static :help do\n    # we allow temperatures down to -20C and up to +40C\n    negative_scale =\n      leds(5)\n      |> light(davy_s_grey())\n      |> repeat(4)\n\n    positive_scale =\n      leds(5)\n      |> light(davy_s_grey(), 5)\n      |> repeat(8)\n\n    leds(61)\n    |> light(negative_scale)\n    |> light(davy_s_grey())\n    |> light(positive_scale)\n  end\nend\n```\n\nThis time we don't implement the connection to the weather API, but we only fake it.\n\n```elixir\nFledex.Utils.PubSub.broadcast(:fledex, \"trigger\", {:trigger, %{temperature: 17.2}})\n```","ref":"6_fledex_dsl.html#the-weather-app"},{"type":"extras","title":"7. Fledex: effects","doc":"# 7. Fledex: effects\n\n```elixir\nMix.install([\n  {:fledex, \"~>0.3\"}\n])\n\n:ok\n```","ref":"7_fledex_effects.html"},{"type":"extras","title":"Introduction - 7. Fledex: effects","doc":"In this chapter we will look at some effects that we can apply to an animation. Effects are simply applied by wrapping the `animation` marco into an `effect` macro. But before we do so we firs need to load our framework (and we define some aliases that will come in handy a bit later).\n\n```elixir\nalias Fledex.Effect.Rotation\nalias Fledex.Effect.Wanish\n\nuse Fledex\n```\n\nThere is already a standard set of effects available all under the `Fledex.Effect` (like the ones we aliased above), but you can create your own effects. by simply implementing the behaviour `Fledex.Effect.Interface`. We'll take a look on how to do this below.\n\nIn the following we'll take a closer look at two of the standard effects:\n\n* The Wanish effect\n* The Rotation effect\n\nThe latter one we have already encountered under the hood, without realizing it. It provided the functionality of the `send_config_func` to rotate the pixels","ref":"7_fledex_effects.html#introduction"},{"type":"extras","title":"The Wanish effect - 7. Fledex: effects","doc":"The wanish effect makes some leds vanish starting from one end and extending to infity. The effect can be controled through a couple of conig parameters:\n\n* `:trigger_name`: this is the name that will be used as the steering factor for the effect. If nothing is specified the animation will use the `led_strip`name as trigger name (in this case `:john` will be used, so we don't need to specify it).\n* `:divisor`: the trigger might come with a too high frequency and you want to slow down the wanishing effect. The Divisor will slow it down with that factor. (default: 1, i.e. no slow down)\n* `:direction`: the direction specifies whether the wanishing should happen from the start (`:left`) or from the end (`:right`) of the led_strip\n* `:circulate`: indicates whether we want to warp around and redo the wanishing once the first round has finished. In that case the full led sequence will be visible and will wanish again. Note: if you use `:reappear` this will automatically be set.\n* `:reappear`: this will enable the `:circulate` and instead of all leds appearing at the same time, they will first slowly reappear (one by one) and only once they are all visible again will they disappear again. This setting comes with an extra `:reappear_key`, but in most cases you don't need to worry about it, because the default will be just fine.\n* `:switch_on_off_func`: There is also a possibility to control when you want the effect to be switched on or off, but this is outside the scope of this description.\n\nHere is an example on such an effect on a simple led sequence\n\n```elixir\nled_strip :john, :kino do\n  effect Wanish, divisor: 2, direction: :right, reappear: true do\n    animation :test do\n      _triggers ->\n        leds(50) |> rainbow\n    end\n  end\nend\n```","ref":"7_fledex_effects.html#the-wanish-effect"},{"type":"extras","title":"The Rotation effect - 7. Fledex: effects","doc":"As mentioned above, we have used the functionality of the rotation effect already. It is only a very simple version and it can't be combined with other effects. Therefore let's look at the rotation once more, this time as an effect.\n\nThe available configuration parameters are:\n\n* `:trigger_name`: This is again the trigger that will drive the animation. If nothing is specified, the `Fledex.Animation.Animator` will set the `led_strip` name as the default. Therefore you rarely have to set it manually.\n* `:direction`: The rotation can be applied into two directions: `:left` (default) and `:right`\n* `:divisor`: As before this allows to slow down the animation, by not updating it on every trigger event.\n\nLet's see how this looks if we rely on the default values:\n\n```elixir\nled_strip :rotation, :kino do\n  effect Rotation do\n    animation :rainbow do\n      _triggers -> leds(50) |> rainbow\n    end\n  end\nend\n```","ref":"7_fledex_effects.html#the-rotation-effect"},{"type":"extras","title":"Combining effects - 7. Fledex: effects","doc":"It is possble to combine several effects. The order of the effects can be imporant, so make sure you apply them in the correct order.\n\nLet's try it out by combining our rotation and wanishing effect on a rainbow color spectrum.\n\n \n\n\n\n```elixir\nled_strip :rotation_and_wanish, :kino do\n  effect Rotation do\n    effect Wanish, divisor: 4, direction: :right, reappear: true do\n      animation :rainbow do\n        _triggers -> leds(50) |> rainbow\n      end\n    end\n  end\nend\n```","ref":"7_fledex_effects.html#combining-effects"},{"type":"extras","title":"BYOE: Bring Your Own Effect - 7. Fledex: effects","doc":"It is maybe nice to use pre-exisiting effects, but it's much more exciting to create your own effect. In this example we are looking on how to do that.\n\nYou might be wondering what an effect is. It's simply a module with a `@behaviour Fledex.Effect.Interface` implementing the simple `apply/4` function. The function takes 4 parameters\n\n* a `list` of `colorint`s, e.g. `[0xff0000, 0x00ff00, 0x0000ff]`\n* a length of the list passed in as first argument. This is to avoid to walk through the list to figure this out.\n* a keyword list with `config`uration parameters. They are the ones you specified in the `effect` macro. As an effect implementer, you can decide what kind of parameters are permitted. There is one parameter that will be populated by the `Fledex.Animation.Animator` if it's not specified, which is the `:trigger_name`. It is the trigger that drives your effect.\n* a `triggers` map containing the various triggers (like the strip counter, or some other triggers as we have seen in our weather example)\n\nLet's start to define our own module and the function. The simplest implementation is to simply return the leds array.\n\n```elixir\ndefmodule LivebookEffect1 do\n  @behaviour Fledex.Effect.Interface\n\n  @impl true\n  @spec apply(\n          leds :: [Types.colorint()],\n          count :: non_neg_integer,\n          config :: keyword,\n          triggers :: map\n        ) ::\n          list(Types.colorint()) | {list(Types.colorint()), map}\n  def apply(leds, _count, _config, _triggers) do\n    leds\n  end\nend\n```\n\nThis is of course not very exciting, since effect has no effect and is thereby useless. But it's a good starting point.\n\nFrom the `@spec` we can see that we have two alternative return values, either just the leds or a tuple with leds and a map. The map is the trigger map, that can be used to carry state between different execution rounds. In this example we won't make use of this though.\n\nNow let's create a new effect. What about going crazy and to randomize the leds?\n\nThis is very easy to accomplish, we only need to call the `Enum.shuffle/1` function.\n\n```elixir\ndefmodule LivebookEffect2 do\n  @behaviour Fledex.Effect.Interface\n\n  @impl true\n  @spec apply(\n          leds :: [Types.colorint()],\n          count :: non_neg_integer,\n          config :: keyword,\n          triggers :: map\n        ) ::\n          list(Types.colorint()) | {list(Types.colorint()), map}\n  def apply(leds, _count, _config, _triggers) do\n    Enum.shuffle(leds)\n  end\nend\n```\n\nThat's it already, now we can already use our own effect as we have used an effect above. Let's see how crazy this looks.\n\n```elixir\nled_strip :merry, :kino do\n  effect LivebookEffect2 do\n    animation :xmas do\n      _triggers -> leds(50) |> rainbow\n    end\n  end\nend\n```\n\n```elixir\n\n```","ref":"7_fledex_effects.html#byoe-bring-your-own-effect"}],"content_type":"text/markdown"}